@@ -1,3 +1,23 @@
+///
+/// This file is part of Rheolef.
+///
+/// Copyright (C) 2000-2018 Pierre Saramito <Pierre.Saramito@imag.fr>
+///
+/// Rheolef is free software; you can redistribute it and/or modify
+/// it under the terms of the GNU General Public License as published by
+/// the Free Software Foundation; either version 2 of the License, or
+/// (at your option) any later version.
+///
+/// Rheolef is distributed in the hope that it will be useful,
+/// but WITHOUT ANY WARRANTY; without even the implied warranty of
+/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+/// GNU General Public License for more details.
+///
+/// You should have received a copy of the GNU General Public License
+/// along with Rheolef; if not, write to the Free Software
+/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+/// 
+/// =========================================================================
 #include "rheolef.h"
 using namespace rheolef;
 using namespace std;
@@ -22,7 +42,7 @@ int main(int argc, char**argv) {
       meas_omega = integrate(omega);
       have_meas_omega = true;
     }
-    quadrature_option_type qopt;
+    quadrature_option qopt;
     qopt.set_order (2*uh.get_space().degree()+1);
     field pi_h_u = interpolate (uh.get_space(), u_exact(epsilon,t));
     Float err_linf = field(uh - pi_h_u).max_abs();
