@@ -19,8 +19,8 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
 TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR="${TOP_SRCDIR}/doc/pexamples"
 GEODIR="${TOP_SRCDIR}/nfem/ptst"
 SBINDIR="../../nfem/sbin"
 BINDIR="../../nfem/pbin"
@@ -31,7 +31,7 @@ status=0
 
 run "${SBINDIR}/mkgeo_grid_1d 500 -a -4 -b 4 -v4 2>/dev/null | ${BINDIR}/geo -upgrade - > mesh-1d.geo 2>/dev/null"
 run "${SBINDIR}/mkgeo_grid_2d  20 -a -2 -b 2 -c -2 -d 2 -v4 2>/dev/null | ${BINDIR}/geo -upgrade - > mesh-2d.geo 2>/dev/null"
-run "${SBINDIR}/mkgeo_grid_3d  10 -a -2 -b 2 -c -2 -d 2 -f -2 -g 2 -v4 2>/dev/null | ${BINDIR}/geo -upgrade - > mesh-3d.geo 2>/dev/null"
+run "${SBINDIR}/mkgeo_grid_3d   9 -a -2 -b 2 -c -2 -d 2 -f -2 -g 2 -v4 2>/dev/null | ${BINDIR}/geo -upgrade - > mesh-3d.geo 2>/dev/null"
 
 loop_mpirun "./convect mesh-1d.geo > tmp.branch 2>/dev/null && \$RUN ./convect_error 1.6e-3 < tmp.branch >/dev/null 2>/dev/null"
 if test $? -ne 0; then status=1;  fi
@@ -39,7 +39,7 @@ if test $? -ne 0; then status=1;  fi
 loop_mpirun "./convect mesh-2d.geo > tmp.branch 2>/dev/null && \$RUN ./convect_error 0.33 >/dev/null < tmp.branch 2>/dev/null"
 if test $? -ne 0; then status=1;  fi
 
-loop_mpirun "./convect mesh-3d.geo > tmp.branch 2>/dev/null && \$RUN ./convect_error 0.46 < tmp.branch >/dev/null 2>/dev/null"
+loop_mpirun "./convect mesh-3d.geo > tmp.branch 2>/dev/null && \$RUN ./convect_error 0.49 < tmp.branch >/dev/null 2>/dev/null"
 if test $? -ne 0; then status=1;  fi
 
 run "/bin/rm -f mesh-1d.geo mesh-2d.geo mesh-3d.geo tmp.log tmp.branch"
