@@ -19,8 +19,8 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/doc/pexamples"}
 GEODIR="${TOP_SRCDIR}/nfem/ptst"
 SBINDIR="../../nfem/sbin"
 BINDIR="../../nfem/pbin"
@@ -51,7 +51,7 @@ fi
 
 for mesh in mesh-2d mesh-3d; do
  for inv_lambda in 0 1; do
-  loop_mpirun "./incompressible-elasticity $mesh $inv_lambda 2>/dev/null| ./incompressible-elasticity-check >/dev/null 2>/dev/null"
+  loop_mpirun "./incompressible-elasticity $mesh $inv_lambda 2>/dev/null| \$RUN ./incompressible-elasticity-check >/dev/null 2>/dev/null"
   if test $? -ne 0; then status=1; fi
  done
 done
