@@ -42,7 +42,7 @@ psi_max="2.72867435237797e-05"; # diag() was buggy
 psi_max="2.43408263903391e-05"; # diag(ab) inversion
 psi_max="1.96922159307387e-05"; # true block-diag inv of ab
 tol="1e-6";
-loop_mpirun "./stokes_contraction_bubble ${SRCDIR}/contraction-small.geo 2>/dev/null | RHEOPATH=${SRCDIR} ./streamf_contraction 2>/dev/null | RHEOPATH=${SRCDIR} $BINDIR/field -max - 2>/dev/null > tmp.log && cat tmp.log | awk '{ exit (int((\$1-${psi_max})/${tol}) == 0)?0:1;}'"
+loop_mpirun "./stokes_contraction_bubble ${SRCDIR}/contraction-small.geo 2>/dev/null | RHEOPATH=${SRCDIR} ./streamf_contraction 2>/dev/null | RHEOPATH=${SRCDIR} $BINDIR/field -max - 2>/dev/null > tmp.log && cat tmp.log | awk '{ err=int((\$1-${psi_max})/${tol}); have_value=1;} END { exit (have_value==1 && err==0 ?0:1);}'"
 if test $? -ne 0; then status=1; fi
 
 exit $status
