@@ -19,12 +19,12 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/doc/pexamples"}
 GEODIR=${TOP_SRCDIR}/nfem/ptst
 SBINDIR="../../nfem/sbin"
 BINDIR="../../nfem/pbin"
-NPROC_MAX=${NPROC_MAX-"2"}
+NPROC_MAX=${NPROC_MAX-"3"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 #echo "      not yet (skipped)"
