@@ -1,3 +1,23 @@
+///
+/// This file is part of Rheolef.
+///
+/// Copyright (C) 2000-2018 Pierre Saramito <Pierre.Saramito@imag.fr>
+///
+/// Rheolef is free software; you can redistribute it and/or modify
+/// it under the terms of the GNU General Public License as published by
+/// the Free Software Foundation; either version 2 of the License, or
+/// (at your option) any later version.
+///
+/// Rheolef is distributed in the hope that it will be useful,
+/// but WITHOUT ANY WARRANTY; without even the implied warranty of
+/// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+/// GNU General Public License for more details.
+///
+/// You should have received a copy of the GNU General Public License
+/// along with Rheolef; if not, write to the Free Software
+/// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+/// 
+/// =========================================================================
 #include "rheolef.h"
 using namespace rheolef;
 using namespace std;
@@ -6,14 +26,17 @@ int main(int argc, char**argv) {
   environment rheolef(argc, argv);
   Float err_linf_expected = (argc > 1) ? atof(argv[1]) : 1e+38;
   bool dump = (argc > 2);
-  field uh, ph; din >> uh >> ph;
-  space Xh = uh.get_space(),
-        Qh = ph.get_space();
+  field uh;
+  din >> uh;
+  space Xh = uh.get_space();
   geo omega = Xh.get_geo();
+  space Qh (omega, Xh.get_approx());
+  field ph(Qh);
+  din >> ph;
   size_t k = Xh.degree();
   size_t d = omega.dimension();
-  quadrature_option_type qopt;
-  qopt.set_family(quadrature_option_type::gauss);
+  quadrature_option qopt;
+  qopt.set_family(quadrature_option::gauss);
   qopt.set_order(2*k+1);
   Float meas_omega = integrate (omega);
   Float moy_ph = integrate (omega, ph, qopt);
