@@ -20,7 +20,7 @@
 #
 # -------------------------------------------------------------------------
 SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 status=0
