@@ -20,7 +20,7 @@
 /// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ///
 /// =========================================================================
-#include "rheolef/numbering_rep.h"
+#include "rheolef/numbering_rep_v1.h"
 
 namespace rheolef { 
 class numbering_P2d : public numbering_rep {
