@@ -329,8 +329,9 @@ put_text (bool select_all, bool do_round, const set<string>& field_name,
     if (select_all || field_name.size() >= 2) {
        os << "#!mfield" << endl;
     }
+    bool partial_match = false;
     while (is) {
-        if (!scatch (is, "\n#")) {
+        if (!scatch (is, "\n#", partial_match)) {
            continue;
         }
         string target;
