@@ -47,18 +47,18 @@ EXAMPLE:
 INPUT FILE SPECIFICATION:
     @table @code
 
-    @itemx -I@var{dir}
+    @item -I@var{dir}
 	add @var{dir} to the RHEOPATH search path.
     	See also @ref{geo class} for RHEOPATH mechanism. 
 
-    @itemx @var{filename}
+    @item @var{filename}
 	specifies the name of the file containing
       	the input field.
 
-    @itemx -
+    @item -
 	read field on standard input instead on a file.
 
-    @itemx -name
+    @item -name
         when field data comes from standard input, the field name
         is not known and is set to "output" by default.
         This option allows to change this default.
@@ -69,14 +69,14 @@ INPUT FILE SPECIFICATION:
 
 INPUT FORMAT OPTIONS:
   @table @code
-  @itemx -input-field
+  @item -input-field
         read the data in the @file{.field} format.
         This is the default.
 
 @fiindex @file{.cemagref} cemagref topographic mesh
 @cindex  @code{cemagref} topographic mesh
 
-  @itemx -input-cemagref
+  @item -input-cemagref
         input data in cemagref file format.
         The field represents the topographic elevation
 	and is assumed to be a @code{P1} approximation.
@@ -84,37 +84,37 @@ INPUT FORMAT OPTIONS:
 
 OUTPUT FORMAT OPTIONS:
     @table @code
-    @itemx -field
-    @itemx -text
+    @item -field
+    @item -text
 	output field on standard output stream in field text file format.
 
 @fiindex @file{.bb} bamg field
-    @itemx -bamg
+    @item -bamg
         output field on standard output stream in bamg file format.
 
 @fiindex @file{.bb} mmg3d field
-    @itemx -mmg3d
+    @item -mmg3d
         output field on standard output stream in mmg3d file format.
 
 @fiindex @file{.mshdat} gmsh field
-    @itemx -gmsh
+    @item -gmsh
         output field on standard output stream in gmsh file format.
 
 @fiindex @file{.cemagref} cemagref topographic mesh
 @cindex  @code{cemagref} topographic mesh
 
-    @itemx -cemagref
+    @item -cemagref
         output field on standard output stream in cemagref file format.
         The field represents
         the topographic elevation and is assumed to be a @code{P1} approximation.
 	This option is suitable for file format conversion:
 
-    @itemx -ndigit @var{int}
+    @item -ndigit @var{int}
 	number of digits used to print floating point values.
 	Default depends upon the machine precision associated to the
 	@code{Float} type.
 
-    @itemx -round
+    @item -round
         Round the output, in order for the non-regression tests to
         be portable across platforms. Floating point are machine-dependent.
 
@@ -134,26 +134,26 @@ FILE FORMAT CONVERSIONS:
 
 GETTING INFORMATION:
     @table @code
-    @itemx -min
-    @itemx -max
+    @item -min
+    @item -max
     	print the min (resp. max) value of the scalar field and then exit.
     @end table
 RENDER OPTIONS:
     The default render could also specified by using the RHEOLEF_RENDER environment variable.
     @table @code
 
-    @itemx -gnuplot
+    @item -gnuplot
 	use @code{gnuplot} tool.
 	This is the default for monodimensional geometries.
 
-    @itemx -mayavi
+    @item -mayavi
 	use @code{mayavi} tool.
 	This is the default for bi- and tridimensional geometries.
     
-    @itemx -plotmtv
+    @item -plotmtv
 	use @code{plotmtv} plotting command, for bidimensional geometries.
 
-    @itemx -vtk
+    @item -vtk
 	use @code{vtk} tool.
 	This is the old (no more supported) tool for tridimensional geometries.
 	Could be used in 2d also.
@@ -162,54 +162,54 @@ RENDER OPTIONS:
 
 RENDERING OPTIONS:
     @table @code
-    @itemx -color
+    @item -color
     @itemx -gray
     @itemx -black-and-white
 	Use (color/gray scale/black and white) rendering.
 	Color rendering is the default.
     @cindex anaglyph 3D stereo rendering
-    @itemx -stereo
+    @item -stereo
     @itemx -nostereo
   	rendering mode: suitable for red-blue anaglyph 3D stereoscopic glasses.
-    @itemx -fill
+    @item -fill
 	isoline intervals are filled with color.
 	This is the default.
-    @itemx -nofill
+    @item -nofill
 	draw isolines by using lines.
 
-    @itemx -grid
+    @item -grid
 	mesh edges appear also.
 
-    @itemx -nogrid
+    @item -nogrid
 	prevent mesh edges drawing.
 	This is the default.
 
 @cindex projection
-    @itemx -proj
+    @item -proj
         Convert all selected fields to P1-continuous approximation by using a L2 projection.
 	Usefull when input is a discontinuous field (e.g. P0 or P1d).
 
-    @itemx -iso @var{float}
+    @item -iso @var{float}
 	extract an iso-value set of points (1d), lines (2d) 
 	or surfaces (3d) for a specified value. Output
 	the surface in text format (with @code{-text} option)
 	or using a graphic driver.
 	This option requires the @code{vtk} code.
 
-    @itemx -noiso
+    @item -noiso
 	do not draw isosurface.
 
-    @itemx -volume
+    @item -volume
     @itemx -novolume
 	This is an experimental volume representation by using ray cast (mayavi and vtk graphics).
    
-    @itemx -n-iso @var{int}
+    @item -n-iso @var{int}
 	For 2D visualizations, the isovalue table contains
 	regularly spaced values from fmin to fmax, the bounds
         of the field.
 @cindex vorticity
 @cindex stream function
-    @itemx -n-iso-negative @var{int}
+    @item -n-iso-negative @var{int}
 	The isovalue table is splitted into negatives and positives values.
 	Assume there is n_iso=15 isolines: if 4 is requested by this option,
 	then, there will be 4 negatives isolines, regularly spaced
@@ -218,57 +218,57 @@ RENDERING OPTIONS:
 	This option is usefull when plotting e.g. vorticity or stream
 	functions, where the sign of the field is representative.
 
-    @itemx -label
+    @item -label
     @itemx -nolabel
     	Write or do not write labels for values on isolines on
 	2d contour plots when using  @code{plotmtv} output.
 @cindex elevation
-    @itemx elevation
+    @item elevation
 	For two dimensional field, represent values as elevation
 	in the third dimension.
 
-    @itemx noelevation
+    @item noelevation
 	Prevent from the @code{elevation} representation.
 	This is the default.
 
-    @itemx -scale @var{float}
+    @item -scale @var{float}
 	applies a multiplicative factor to the field.
 	This is useful e.g. in conjonction with the @code{elevation} option.
 	The default value is 1.
 
-    @itemx -cut
+    @item -cut
 	show a cut by a specified plane.
 	The cutting plane is specified by its origin point and normal vector.
 	This option requires the @code{vtk} code.
 
-    @itemx -origin @var{float} [@var{float} [@var{float}]]
+    @item -origin @var{float} [@var{float} [@var{float}]]
 	set the origin of the cutting plane.
 	Default is (0.5, 0.5, 0.5).
     
-    @itemx -normal @var{float} [@var{float} [@var{float}]]
+    @item -normal @var{float} [@var{float} [@var{float}]]
 	set the normal of the cutting plane.
 	Default is (1, 0, 0).
 
     @end table
 OTHERS OPTIONS:
     @table @code
-    @itemx -verbose
+    @item -verbose
 	print messages related to graphic files created and
        command system calls (this is the default).
 
-    @itemx -noverbose
+    @item -noverbose
 	does not print previous messages.
 
-    @itemx -clean
+    @item -clean
 	clear temporary graphic files (this is the default).
     
-    @itemx -noclean
+    @item -noclean
 	does not clear temporary graphic files.
 
-    @itemx -execute
+    @item -execute
 	execute graphic command (this is the default).
     
-    @itemx -noexecute
+    @item -noexecute
 	does not execute graphic command. Generates only 
 	graphic files. This is usefull in conjuction with the
 	@code{-noclean} command.
