@@ -211,8 +211,7 @@ OUTPUT FORMAT OPTIONS:
 	of the @code{Float} type.
   @item -output-as-double
         Avoid variation of output float formats
-        when using high precision @code{doubledouble} or 
-	@code{bigfloat} classes.
+        when using high precision such as the @code{bigfloat} class.
 	This option is used for non-regression test purpose.
 
   @end table
