@@ -28,7 +28,7 @@ namespace rheolef {
 
 template <class T, class M>
 bool
-point_belongs_to_e (const array<point_basic<T>,M>& node, const geo_element& K, const point_basic<T>& x) 
+point_belongs_to_e (const disarray<point_basic<T>,M>& node, const geo_element& K, const point_basic<T>& x) 
 {
   const point_basic<T>& p0 = node.dis_at(K[0]);
   const point_basic<T>& p1 = node.dis_at(K[1]);
@@ -36,7 +36,7 @@ point_belongs_to_e (const array<point_basic<T>,M>& node, const geo_element& K, c
 }
 template <class T, class M>
 bool
-point_belongs_to_t (const array<point_basic<T>,M>& node, const geo_element& K, const point_basic<T>& x) 
+point_belongs_to_t (const disarray<point_basic<T>,M>& node, const geo_element& K, const point_basic<T>& x) 
 {
   static const T eps = 1e3*std::numeric_limits<T>::epsilon();
   const point_basic<T>& p0 = node.dis_at(K[0]);
@@ -49,7 +49,7 @@ point_belongs_to_t (const array<point_basic<T>,M>& node, const geo_element& K, c
 }
 template <class T, class M>
 bool
-point_belongs_to_q (const array<point_basic<T>,M>& node, const geo_element& K, const point_basic<T>& x) 
+point_belongs_to_q (const disarray<point_basic<T>,M>& node, const geo_element& K, const point_basic<T>& x) 
 {
   static const T eps = 1e3*std::numeric_limits<T>::epsilon();
   const point_basic<T>& p0 = node.dis_at(K[0]);
@@ -64,7 +64,7 @@ point_belongs_to_q (const array<point_basic<T>,M>& node, const geo_element& K, c
 }
 template <class T, class M>
 bool
-point_belongs_to_T (const array<point_basic<T>,M>& node, const geo_element& K, const point_basic<T>& x) 
+point_belongs_to_T (const disarray<point_basic<T>,M>& node, const geo_element& K, const point_basic<T>& x) 
 {
   static const T eps = 1e3*std::numeric_limits<T>::epsilon();
   const point_basic<T>& p0 = node.dis_at(K[0]);
@@ -79,7 +79,7 @@ point_belongs_to_T (const array<point_basic<T>,M>& node, const geo_element& K, c
 }
 template <class T, class M>
 bool
-point_belongs_to_H (const array<point_basic<T>,M>& node, const geo_element& K, const point_basic<T>& x) 
+point_belongs_to_H (const disarray<point_basic<T>,M>& node, const geo_element& K, const point_basic<T>& x) 
 {
   typedef reference_element::size_type           size_type;
   static const T eps = 1e3*std::numeric_limits<T>::epsilon();
@@ -102,7 +102,7 @@ point_belongs_to_H (const array<point_basic<T>,M>& node, const geo_element& K, c
 }
 template <class T, class M>
 bool
-point_belongs_to_P (const array<point_basic<T>,M>& node, const geo_element& K, const point_basic<T>& x) 
+point_belongs_to_P (const disarray<point_basic<T>,M>& node, const geo_element& K, const point_basic<T>& x) 
 {
   typedef reference_element::size_type           size_type;
   static const T eps = 1e3*std::numeric_limits<T>::epsilon();
@@ -123,7 +123,7 @@ point_belongs_to_P (const array<point_basic<T>,M>& node, const geo_element& K, c
 }
 template <class T, class M>
 bool
-geo_element::contains (const array<point_basic<T>,M>& node, const point_basic<T>& x)  const
+geo_element::contains (const disarray<point_basic<T>,M>& node, const point_basic<T>& x)  const
 {
   switch (variant()) {
     case reference_element::e: return point_belongs_to_e (node, *this, x);
@@ -138,9 +138,9 @@ geo_element::contains (const array<point_basic<T>,M>& node, const point_basic<T>
 // ----------------------------------------------------------------------------
 // instanciation in library
 // ----------------------------------------------------------------------------
-template bool geo_element::contains (const array<point_basic<Float>,sequential>&, const point_basic<Float>&) const;
+template bool geo_element::contains (const disarray<point_basic<Float>,sequential>&, const point_basic<Float>&) const;
 #ifdef _RHEOLEF_HAVE_MPI
-template bool geo_element::contains (const array<point_basic<Float>,distributed>&, const point_basic<Float>&) const;
+template bool geo_element::contains (const disarray<point_basic<Float>,distributed>&, const point_basic<Float>&) const;
 #endif // _RHEOLEF_HAVE_MPI
 
 } // namespace rheolef
