@@ -518,7 +518,7 @@ struct geo_element_permuted_put {
   std::ostream& operator() (std::ostream& os, const geo_element& K) {
     static const bool do_verbose = true;
     if (do_verbose || K.size() > 2 || K.order() > 1) { os << K.name() << "\t"; }
-    if (do_verbose || K.order() > 1) { os << "p" << K.order() << " "; }
+    if (K.order() > 1) { os << "p" << K.order() << " "; }
     for (geo_element::size_type iloc = 0; iloc < K.n_node(); iloc++) {
       os << perm [K[iloc]];
       if (iloc < K.n_node() - 1) os << " ";
