@@ -297,7 +297,7 @@ protected:
 
 /*Class:hack_array
 NAME:  hack_array - container in distributed environment (@PACKAGE@-@VERSION@)
-SYNOPSYS:       
+SYNOPSIS:       
 @noindent
 STL-like vector container for a distributed memory machine model.
 Contrarily to disarray<T>, here T can have a size only known at compile time.
