@@ -23,7 +23,7 @@
 namespace rheolef {
 using namespace std;
 
-static const char* static_family_name[quadrature_option_type::max_family+1] = {
+static const char* static_family_name[quadrature_option::max_family+1] = {
 	"gauss"           ,
 	"gauss_lobatto"   ,
 	"gauss_radau"	  ,
@@ -33,24 +33,24 @@ static const char* static_family_name[quadrature_option_type::max_family+1] = {
 	"undefined"
 };
 static 
-quadrature_option_type::family_type
+quadrature_option::family_type
 family_name2type (string name)
 {
-  for (size_t i =  0; i < quadrature_option_type::max_family; ++i) {
+  for (size_t i =  0; i < quadrature_option::max_family; ++i) {
     if (static_family_name[i] == name) {
-      return (quadrature_option_type::family_type) (i);
+      return (quadrature_option::family_type) (i);
     }
   }
   error_macro ("unexpected quadrature family name `" << name << "'");
-  return quadrature_option_type::max_family;
+  return quadrature_option::max_family;
 }
 void
-quadrature_option_type::set_family (string name)
+quadrature_option::set_family (string name)
 {
   set_family (family_name2type (name));
 }
 string
-quadrature_option_type::get_family_name() const
+quadrature_option::get_family_name() const
 {
   check_macro (_family >= 0 && _family <= max_family,
 	"unexpected quadrature family number = " << _family);
@@ -59,7 +59,7 @@ quadrature_option_type::get_family_name() const
 // ----------------------------------------------------------------------------
 template<class T>
 void
-quadrature_on_geo<T>::initialize (reference_element hat_K,  quadrature_option_type opt)
+quadrature_on_geo<T>::initialize (reference_element hat_K,  quadrature_option opt)
 {
     base::resize (0);
     switch (hat_K.variant()) {
@@ -77,7 +77,7 @@ quadrature_on_geo<T>::initialize (reference_element hat_K,  quadrature_option_ty
 }
 // ----------------------------------------------------------------------------
 template<class T>
-quadrature_rep<T>::quadrature_rep (quadrature_option_type opt)
+quadrature_rep<T>::quadrature_rep (quadrature_option opt)
  : _options(opt),
    _quad(),
    _initialized           (reference_element::max_variant, false)
