@@ -43,22 +43,22 @@ using namespace std;
  */
 template<class T>
 void
-quadrature_on_geo<T>::init_square  (quadrature_option_type opt)
+quadrature_on_geo<T>::init_square  (quadrature_option opt)
 {
-  quadrature_option_type::family_type f = opt.get_family();
+  quadrature_option::family_type f = opt.get_family();
   // -------------------------------------------------------------------------
   // special case : equispaced, for irregular (e.g. Heaviside) functions
   // -------------------------------------------------------------------------
-  if (f == quadrature_option_type::equispaced) {
+  if (f == quadrature_option::equispaced) {
     size_type r = opt.get_order();
     if (r == 0) {
       wx (x(0,0), 4);
     } else {
       size_type n = (r+1)*(r+1);
-      T w = 4/T(n);
+      T w = 4/T(int(n));
       for (size_type i = 0; i <= r; i++) {
         for (size_type j = 0; j <= r; j++) {
-          wx (x(2*T(i)/r-1,2*T(j)/r-1), w);
+          wx (x(2*T(int(i))/r-1,2*T(int(j))/r-1), w);
         }
       }
     }
@@ -71,7 +71,7 @@ quadrature_on_geo<T>::init_square  (quadrature_option_type opt)
   // -------------------------------------------------------------------------
   // default: gauss
   // -------------------------------------------------------------------------
-  check_macro (f == quadrature_option_type::gauss,
+  check_macro (f == quadrature_option::gauss,
         "unsupported quadrature family \"" << opt.get_family_name() << "\"");
  
   // Gauss-Legendre quadrature formulae 
@@ -88,7 +88,7 @@ quadrature_on_geo<T>::init_square  (quadrature_option_type opt)
 // instanciation in library
 // ----------------------------------------------------------------------------
 #define _RHEOLEF_instanciation(T)                                             	\
-template void quadrature_on_geo<T>::init_square (quadrature_option_type);
+template void quadrature_on_geo<T>::init_square (quadrature_option);
 
 _RHEOLEF_instanciation(Float)
 
