@@ -27,7 +27,7 @@ NAME: @code{tensor} - a N*N tensor, N=1,2,3
 @clindex tensor
 @clindex point
 @clindex field
-SYNOPSYS:
+SYNOPSIS:
 @noindent
 The @code{tensor} class defines a 3*3 tensor, as the value of
 a tensorial valued field. Basic algebra with scalars, vectors
