@@ -105,7 +105,7 @@ void
 cad_rep::get_qmg (istream& is)
 {
 	p_data = this;
-  	input_cad = yyFlexLexer(&is);
+  	input_cad.yyrestart (is);
 	cad_qmg_line_no = 1;
 	cad_qmg_n_error = 0;
 	if (cad_qmg_parse() != 0 || cad_qmg_n_error != 0) {
