@@ -152,8 +152,8 @@ field
 riesz_representer (const space& Vh, const field_o_characteristic& foX)
 {
   field_element field_e;
-  quadrature_option_type qopt;
-  qopt.set_family (quadrature_option_type::gauss_lobatto);
+  quadrature_option qopt;
+  qopt.set_family (quadrature_option::gauss_lobatto);
   field_e.initialize (Vh, qopt);
   field mgh (Vh, 0.);
 #ifdef TODO
