@@ -63,8 +63,8 @@ operator << (ostream& os, const domain& d)
     typedef domain::size_type size_type;
     os << "domain" << endl;
     if (d.name().length() == 0) {
-        os << "unamed" << endl;
-	warning_macro ("unamed domain has been be named `unamed' for output");
+        os << "unnamed" << endl;
+	warning_macro ("unnamed domain has been be named `unnamed' for output");
     } else {
         os << d.name()  << endl;
     }
