@@ -59,7 +59,7 @@ field postprocessing_prol2 (const field& grad_uh) {
 // NOTE: the choice of quadrature node on superconvergent points
 //  does not leads to a good L2 projection with P2
 // and this method is not usefull
-field postprocessing_prol2 (const field& grad_uh, quadrature_option_type qopt) {
+field postprocessing_prol2 (const field& grad_uh, quadrature_option qopt) {
     const geo& omega = grad_uh.get_geo();
     size_t d = omega.dimension();
     string grad_approx = grad_uh.get_approx();
@@ -235,8 +235,8 @@ warning_macro ("post macro");
   size_t ndof = Hkh_scalar.size();
   field wh (Hkh_scalar, 0.0);
   field rh (Hkh, 0.0);
-  quadrature_option_type qopt;
-  qopt.set_family (quadrature_option_type::superconvergent);
+  quadrature_option qopt;
+  qopt.set_family (quadrature_option::superconvergent);
   qopt.set_order  (Hkh.degree() );
   quadrature<Float> quad (qopt);
   basis phi = Hkh_scalar.get_basis();
