@@ -1006,18 +1006,10 @@ field::put_scalar (ostream& s) const
     s << endl;
     for (size_type i = 0; i < size() && s.good(); i++) {
 	Float value = at(i);
-
-#ifndef _RHEOLEF_HAVE_DOUBLEDOUBLE
 	// TODO: use default n = numeric_limits<Float>::digit10
 	// and: stream << setrheoprecision(n) << field_u;
 	//  => stream.precision(min(n,numeric_limits<Float>::digit10))
 	s << value << endl;
-#else
-	// avoid variable format in non-regression test...
-	// doubledouble does not head stream.precision(n) and such
-	s << double(value) << endl;
-#endif // _RHEOLEF_HAVE_DOUBLEDOUBLE
-    
     }
     s << endl;
     return s;
