@@ -26,10 +26,10 @@ namespace rheolef {
 
 // cstor by specifying the quadrature formulae
 void
-field_element::initialize (const space& X, const quadrature_option_type& qopt) const {
+field_element::initialize (const space& X, const quadrature_option& qopt) const {
   _X = X;
   _X.freeze();
-  if (qopt.get_order() != std::numeric_limits<quadrature_option_type::size_type>::max()) {
+  if (qopt.get_order() != std::numeric_limits<quadrature_option::size_type>::max()) {
     _quad.set_order (qopt.get_order());
   } else {
     size_type k = X.degree();
