@@ -28,7 +28,7 @@ NAME: @code{form_element} - bilinear form on a single element
 @clindex basis
 @clindex numbering
 @clindex geo_element
-SYNOPSYS:
+SYNOPSIS:
   @noindent
   The @code{form_element} class defines functions that compute
   a bilinear form defined between two polynomial basis on a single
