@@ -89,7 +89,7 @@ get_nodes_bamg (
       vertice_domain_bamg_number[i_dom] = (*iter_domain_map).first;
       const vector<tiny_element>& dom      = (*iter_domain_map).second;
       if (dom.size() == 0) continue;
-      (*iter_domain).set(dom.begin(), dom.size(), 0, "unamed_vertice"+itos(i_dom));
+      (*iter_domain).set(dom.begin(), dom.size(), 0, "unnamed_vertice"+itos(i_dom));
   }
   return s;
 }
@@ -124,7 +124,7 @@ get_boundary_edges_bamg (istream& is, vector<domain>& domains,
       edge_domain_bamg_number[i_dom] = (*iter_domain_map).first;
       const vector<pair<size_type,size_type> >& dom = (*iter_domain_map).second;
       if (dom.size() == 0) continue;
-      (*iter_domain).set(dom.begin(), dom.size(), "unamed"+itos(i_dom));
+      (*iter_domain).set(dom.begin(), dom.size(), "unnamed"+itos(i_dom));
   }
   return is;
 }
