@@ -88,7 +88,7 @@ get_nodes_mmg3d (
       vertice_domain_mmg3d_number[i_dom] = (*iter_domain_map).first;
       const vector<tiny_element>& dom      = (*iter_domain_map).second;
       if (dom.size() == 0) continue;
-      (*iter_domain).set(dom.begin(), dom.size(), 0, "unamed_vertice"+itos(i_dom));
+      (*iter_domain).set(dom.begin(), dom.size(), 0, "unnamed_vertice"+itos(i_dom));
   }
   return s;
 }
@@ -125,7 +125,7 @@ get_boundary_edges_mmg3d (istream& is, vector<domain>& domains,
       edge_domain_mmg3d_number[i_dom] = (*iter_domain_map).first;
       const vector<pair<size_type,size_type> >& dom = (*iter_domain_map).second;
       if (dom.size() == 0) continue;
-      (*iter_domain).set(dom.begin(), dom.size(), "unamed"+itos(i_dom));
+      (*iter_domain).set(dom.begin(), dom.size(), "unnamed"+itos(i_dom));
   }
   return is;
 }
@@ -164,7 +164,7 @@ warning_macro ("n_tri = " << n_bdr_triangles);
       triangle_domain_mmg3d_number[i_dom] = (*iter_domain_map).first;
       const vector<tiny_element>& dom = (*iter_domain_map).second;
       if (dom.size() == 0) continue;
-      (*iter_domain).set(dom.begin(), dom.size(), 2, "unamed"+itos(i_dom));
+      (*iter_domain).set(dom.begin(), dom.size(), 2, "unnamed"+itos(i_dom));
   }
   return is;
 }
