@@ -81,7 +81,7 @@ istream&
 rheolef::operator >> (istream& is, qmg& data)
 {
 	p_data = &data;
-  	input_qmg = yyFlexLexer(&is);
+  	input_qmg.yyrestart(is);
 	qmg_line_no = 1;
 	qmg_n_error = 0;
 	if (qmg_parse() != 0 || qmg_n_error != 0) {
