@@ -116,7 +116,7 @@ get_boundary_triangles_tetgen (istream& is,
       triangle_domain_tetgen_number[i_dom] = (*iter_domain_map).first;
       const vector<tiny_element>& dom = (*iter_domain_map).second;
       if (dom.size() == 0) continue;
-      (*iter_domain).set(dom.begin(), dom.size(), 2, "unamed"+itos(i_dom));
+      (*iter_domain).set(dom.begin(), dom.size(), 2, "unnamed"+itos(i_dom));
   }
 }
 istream&
