@@ -1014,8 +1014,8 @@ operator >> (istream& s, georep& m)
     if (basename.length() != 0) {
 	m._name = basename;
     } else {
-	m._name = "unamed";
-	warning_macro ("unamed input mesh has been named `" << m._name << "'");
+	m._name = "unnamed";
+	warning_macro ("unnamed input mesh has been named `" << m._name << "'");
     }
     m.reset_counters ();
     iorheo::flag_type fmt = iorheo::flags(s) & iorheo::format_field;
