@@ -29,7 +29,7 @@ NAME: @code{geo} - the finite element mesh class
 @fiindex @file{.geo} mesh
 @fiindex @file{.gz} gzip
 @toindex @code{gzip}
-SYNOPSYS:       
+SYNOPSIS:       
 @noindent
 The @code{geo} class defines a container for a finite element
 mesh. This describes the nodes coordinates and the connectivity.
