@@ -189,7 +189,7 @@ geo_tree::geo_tree (const geo_tree& x)
    _fvertex(0),
    _initialized(false)
 {
-  fatal_macro ("copy of geo_tree should not happend !");
+  fatal_macro ("copy of geo_tree should not happened !");
 }
 void
 geo_tree::initialize (
