@@ -475,13 +475,12 @@ hazel::hit_boundary_element (const geo_element& e,
             Float D = vect2d(u,v);
             inward = (D >= Float(0));
         
-            if (fabs(D)<tol) //==0) 
-             {  // Then check alignment
+            if (fabs(D)<tol) {  // Then check alignment
                  
                 return false;
                 // We want to slide !!
                 
-                if ( fabs(vect2d(w,u)) <tol)
+                if (fabs(vect2d(w,u)) <tol) {
                     // Then check overlapping : 
                     // if x0 is in e0e1, it's x0.
                     // if not, it may be e0 (or e1) iff x1 is on the
@@ -504,9 +503,9 @@ hazel::hit_boundary_element (const geo_element& e,
                         t = dot(w_dash,v)/dot(v,v);
                         return true;
                      }
-             }
-            else
-            // If not, check that intersection occurs within [s0_s1_] :
+                }
+            } else {
+                // If not, check that intersection occurs within [s0_s1_] :
                 if ( (-tol <=vect2d(w,v)/D) && (-tol <=vect2d(w_dash,v)/D) )
                  {
                     t=vect2d(w,u)/D;
@@ -515,6 +514,7 @@ hazel::hit_boundary_element (const geo_element& e,
                     if ( Float(0) <=t && t-1 <= Float(0))
                     return true;
                  }
+            }
             return false;
           }
         default: error_macro("Not yet implemented");
