@@ -29,6 +29,7 @@
 #include "rheolef/tiny_matvec.h"
 #include "rheolef/tensor.h"
 #include "rheolef/piola_v1.h"
+#include "rheolef/banded_level_set.h"
 #include "../basis/P1pw_numbering.h"
 using namespace std;
 namespace rheolef { 
@@ -98,8 +99,7 @@ spacerep::get_valued () const
 
 // space();
 spacerep::spacerep()
-  : occurence(),
-    _g(), 
+  : _g(), 
     _is_frozen(false),
     _has_locked(false),
     _b(),
@@ -131,8 +131,7 @@ spacerep::spacerep()
 
 // space(e);
 spacerep::spacerep(const spacerep& e)
-  : occurence(),
-    _g(e._g), 
+  : _g(e._g), 
     _is_frozen(e._is_frozen),
     _has_locked(e._has_locked),
     _b(e._b),
@@ -166,8 +165,7 @@ spacerep::spacerep(const spacerep& e)
 // space(g, "P1", "vector");
 // space(g, "P1", "scalar"); <==> space(g, "P1")
 spacerep::spacerep(const geo& g, const string& approx_name, const string& valued)
-  : occurence(),
-    _g(g),
+  : _g(g),
     _is_frozen(false),
     _has_locked(false),
     _b(),
@@ -271,8 +269,7 @@ spacerep::spacerep(const geo& g, const string& approx_name, const string& valued
 
 spacerep::spacerep(const geo& g, const std::string& approx_name, 
 	const domain& interface, const domain& region, const std::string& valued)
-  : occurence(),
-    _g(g),
+  : _g(g),
     _is_frozen(false),
     _has_locked(false),
     _b(),
@@ -378,8 +375,7 @@ spacerep::spacerep(const geo& g, const std::string& approx_name,
 // --------------------------------------------------------------------------
 // space(g, g["bottom"], "P1")
 spacerep::spacerep(const geo& g, const domain& d, const string& approx_name)
-  : occurence(),
-    _g(geo(g,d)), 
+  : _g(geo(g,d)), 
     _is_frozen(false),
     _has_locked(false),
     _b(1),
@@ -428,12 +424,63 @@ spacerep::spacerep(const geo& g, const domain& d, const string& approx_name)
   resize(_boundary_dof, nglobaldof, numeric_limits<size_type>::max());
   _build_global_dof_mapping();
 }
+
+// dirty hack for banded level set 
+spacerep::spacerep(const field& phi, const string& tag, const string& approx_name)
+  : _g(), 
+    _is_frozen(false),
+    _has_locked(false),
+    _b(1),
+    _numbering(1),
+    _tr_p1("P1"),
+    _tr_p1_value(1),
+    _name(1),
+    _start(2),
+    _start_blocked(2,numeric_limits<size_type>::max()),
+    _start_unknown(2,numeric_limits<size_type>::max()),
+    _is_blocked(),
+    _is_periodic(),
+    _period_assoc(),
+    _num(),
+    _dof_oriented_as_element(),
+    _dof_orientation_initialized(false),
+    _is_locked (),
+    _locked_dir           (),
+    _is_on_boundary_domain(true),
+    _boundary_domain(),
+    _global_geo(phi.get_geo()),
+    _global_dof(),
+    _boundary_dof(),
+    _start_global_dof(2),
+    _valued(fem_helper::scalar)
+{
+  check_macro(tag=="banded_level_set", "This constructor is for banded level set only");
+  banded_level_set(phi, _g, _boundary_domain);
+  string basis_name = fem_helper::basis_name     (approx_name);
+  string num_name   = fem_helper::numbering_name (approx_name);
+  _g.may_have_version_2();
+  _name[0] = approx_name; 
+  _b[0] = basis(basis_name) ; 
+  _numbering[0] = numbering(num_name) ; 
+  _tr_p1_value[0].set (_b[0], _tr_p1); 
+  size_type ndof = _n_dof(0);
+  _start[0] = 0;
+  _start[1] = ndof;
+  resize(_num, ndof, numeric_limits<size_type>::max()) ;
+  resize(_period_assoc, ndof, numeric_limits<size_type>::max()) ;
+  resize(_is_blocked, ndof, false) ;
+  resize(_is_periodic, ndof, false) ;
+  resize(_global_dof, ndof, numeric_limits<size_type>::max()) ;
+  size_type nglobaldof = _n_global_dof(0);
+  resize(_boundary_dof, nglobaldof, numeric_limits<size_type>::max());
+  _build_global_dof_mapping();
+  block("isolated");
+}
 // --------------------------------------------------------------------------
 
 // X*Y
 spacerep::spacerep(const spacerep& X, const spacerep& Y)
-  : occurence(),
-    _g(X.get_geo()),
+  : _g(X.get_geo()),
     _is_frozen(true),
     _has_locked(false),
     _b             (X.n_component()  + Y.n_component()),
@@ -554,8 +601,7 @@ spacerep::spacerep(const spacerep& X, const spacerep& Y)
 
 // space Xi = X[i];
 spacerep::spacerep(const spacerep& X, size_type i_comp)
-  : occurence(),
-    _g(X.get_geo()),
+  : _g(X.get_geo()),
     _is_frozen(false),
     _has_locked(false),
     _b             (1),
@@ -596,7 +642,7 @@ spacerep::spacerep(const spacerep& X, size_type i_comp)
   for (size_type p = X.start(i_comp); p < X.start(i_comp+1); p++) {
     _is_blocked  [p - X.start(i_comp)] = X._is_blocked   [p];
     _is_periodic [p - X.start(i_comp)] = X._is_periodic  [p];
-    _period_assoc[p - X.start(i_comp)] = X._period_assoc [p];
+    _period_assoc[p - X.start(i_comp)] = X._period_assoc [p] - X.start(i_comp);
   }
   _build_global_dof_mapping();
   freeze();
@@ -605,7 +651,6 @@ spacerep::spacerep(const spacerep& X, size_type i_comp)
 
 spacerep::~spacerep()
 {
-  if (_dof_orientation_initialized) cerr << "DOFOR";
 }
 // ==========================================================================
 //  dofs
@@ -624,7 +669,7 @@ internal_set_dof(
         geo::size_type                 first)
 {
   typedef spacerep::size_type size_type;
-  size_type ndof = b.size(K.type());
+  size_type ndof = b.size(K.variant());
   for (size_type i = 0; i < ndof; i++) {	
       idx[i] = first + numb.idof (mesh_n_geo, mesh_n_element, K, i);
     }
@@ -640,19 +685,19 @@ internal_set_dof(
 	const geo::size_type*          mesh_n_geo,
         const geo::size_type*          mesh_n_element,
         geo::size_type                 first,
-	reference_element::dof_family_type family)
+	element_constant::dof_family_type family)
 {
   typedef spacerep::size_type size_type;
-  if (family==reference_element::dof_family_max)
+  if (family == element_constant::dof_family_max)
     {
-    	size_type ndof = b.size(K.type());
+    	size_type ndof = b.size(K.variant());
   	for (size_type i = 0; i < ndof; i++) {	
 	      idx[i] = first + numb.idof (mesh_n_geo, mesh_n_element, K, i);
 	  }
     }
   else 
     {
-    	size_type ndof = b.size(K.type(), family);
+    	size_type ndof = b.size(K.variant(), family);
   	for (size_type i = 0; i < ndof; i++) {	
 	      if (b.dof_family(K, i)==family)
 	      	idx[i] = first + numb.idof (mesh_n_geo, mesh_n_element, K, i);
@@ -665,7 +710,7 @@ spacerep::set_dof(
 	tiny_vector<size_type>& idx ,
 	spacerep::size_type     i_comp) const
 {
-    size_type ndof = get_basis(i_comp).size(K.type());
+    size_type ndof = get_basis(i_comp).size(K.variant());
     idx.resize (ndof);
     internal_set_dof(get_geo(), get_basis(i_comp), get_numbering(i_comp),
 		        K, idx, 
@@ -678,9 +723,9 @@ spacerep::set_dof(
 	const geo_element&      K,
 	tiny_vector<size_type>& idx ,
 	spacerep::size_type     i_comp,
-	reference_element::dof_family_type family) const
+	element_constant::dof_family_type family) const
 {
-    size_type ndof = get_basis(i_comp).size(K.type(), family);
+    size_type ndof = get_basis(i_comp).size(K.variant(), family);
     idx.resize (ndof);
     internal_set_dof(get_geo(), get_basis(i_comp), get_numbering(i_comp),
 		        K, idx, 
@@ -698,7 +743,7 @@ spacerep::set_global_dof (
 	tiny_vector<size_type>& idx,
 	spacerep::size_type     i_comp) const
 {
-    size_type ndof = get_basis(i_comp).size(K.type());
+    size_type ndof = get_basis(i_comp).size(K.variant());
     idx.resize (ndof);
     internal_set_dof (get_global_geo(), get_basis(i_comp), get_numbering(i_comp),
 		        K, idx,
@@ -711,7 +756,7 @@ spacerep::set_dof(const geo_element& K, tiny_vector<size_type>& idx) const
 {
     size_type ndof = 0;
     for (size_type i_comp = 0; i_comp < n_component(); i_comp++) {
-	ndof += get_basis(i_comp).size(K.type());
+	ndof += get_basis(i_comp).size(K.variant());
     }
     idx.resize (ndof);
 
@@ -723,7 +768,7 @@ spacerep::set_dof(const geo_element& K, tiny_vector<size_type>& idx) const
 			get_geo().get_geo_counter(),
   			get_geo().get_element_counter(), 
 			start(i_comp));
-	shift += get_basis(i_comp).size(K.type());
+	shift += get_basis(i_comp).size(K.variant());
     }
     idx.set_origin(0);
 }
@@ -732,7 +777,7 @@ spacerep::set_global_dof(const geo_element& K, tiny_vector<size_type>& idx) cons
 {
     size_type ndof = 0;
     for (size_type i_comp = 0; i_comp < n_component(); i_comp++) {
-	ndof += get_basis(i_comp).size(K.type());
+	ndof += get_basis(i_comp).size(K.variant());
     }
     idx.resize (ndof);
 
@@ -744,7 +789,7 @@ spacerep::set_global_dof(const geo_element& K, tiny_vector<size_type>& idx) cons
   			get_global_geo().get_geo_counter(),
   			get_global_geo().get_element_counter(),
 			start_global_dof(i_comp));
-	shift += get_basis(i_comp).size(K.type());
+	shift += get_basis(i_comp).size(K.variant());
     }
     idx.set_origin(0);
 }
@@ -781,7 +826,7 @@ spacerep::block_Lagrange (size_type i_comp) const
   geo::const_iterator last_side = get_geo().end(); 
   for (geo::const_iterator iter_side = get_geo().begin(); iter_side != last_side; iter_side++) {
     const geo_element& S = *iter_side ;
-    set_dof (S, idx, i_comp, reference_element::Lagrange);
+    set_dof (S, idx, i_comp, element_constant::Lagrange);
     for (size_type i = 0 ; i < idx.size(); i++) {
       _is_blocked [idx(i)] = true;
     }
@@ -854,6 +899,7 @@ spacerep::set_periodic (const domain& d1, const domain& d2, size_type i_comp) co
   }
   tiny_vector<size_type> dof1;
   tiny_vector<size_type> dof2;
+  list<pair<size_type, size_type> > double_periodic;
   domain::const_iterator last_side1 = d1.end(); 
   domain::const_iterator iter_side1 = d1.begin();
   domain::const_iterator iter_side2 = d2.begin();
@@ -866,10 +912,32 @@ spacerep::set_periodic (const domain& d1, const domain& d2, size_type i_comp) co
       size_t i2;
       if (i1==0 || i1==1) { i2 = 1-i1; }
       else { i2 = dof1.size()+1-i1; }
-      _is_periodic  [dof1(i1)] = true;
-      _period_assoc [dof1(i1)] = dof2(i2);
+      if (!_is_periodic[dof1(i1)])
+        {
+         _is_periodic  [dof1(i1)] = true;
+	 if (!_is_periodic[dof2(i2)])
+	         _period_assoc [dof1(i1)] = dof2(i2);
+	 else // target dof is periodic (from a previous call), reach directly for its own target
+	         _period_assoc [dof1(i1)] = _period_assoc [dof2(i2)];
+	 	
+	}
+      else // dof is already mapped to another one: store it for re-examination
+	double_periodic.insert(double_periodic.begin(), pair<size_type,size_type>(dof1(i1),dof2(i2)));
     }
-  }
+   }
+  if (double_periodic.size()!=0)
+   {
+      typedef list<pair<size_type, size_type> > mylist;
+      mylist::const_iterator i = double_periodic.begin();
+      mylist::const_iterator end = double_periodic.end();
+      for ( ; i!=end; i++)
+        {
+	  if (!_is_periodic[(*i).second])
+	         _period_assoc [(*i).first] = (*i).second;
+	 else // target dof is periodic (from a previous call), reach directly for its own target
+	         _period_assoc [(*i).first] = _period_assoc [(*i).second];
+	}
+   }
 }
 void
 spacerep::set_periodic (const domain& d1, const domain& d2) const
@@ -878,6 +946,38 @@ spacerep::set_periodic (const domain& d1, const domain& d2) const
      set_periodic (d1, d2, i_comp);
   }
 }
+//! On a uniform boundary, all dofs have the same value.
+//! Useful e.g. for solid boundaries with translation only.
+void
+spacerep::set_uniform (const domain& d, size_type i_comp) const
+{
+  if (_is_frozen) {
+    error_macro("numbering already done -- cannot set_periodic any pair of domains anymore");
+  }
+  tiny_vector<size_type> dof;
+  domain::const_iterator last_side = d.end(); 
+  domain::const_iterator iter_side = d.begin();
+  bool single_dof_set = false;
+  size_t single_dof = 0;
+  for (; iter_side != last_side; iter_side++) {
+    const geo_element& S = *iter_side ;
+    set_dof (S, dof, i_comp);
+    for (size_type i = 0 ; i < dof.size(); i++) {
+      // the first dof encountered will not be blocked, all others will
+      // be bound to it.
+      if (!single_dof_set)
+       {
+       	single_dof = dof(i);
+	single_dof_set = true;
+       }
+      if (dof(i)!=single_dof) 
+       {
+        _is_periodic  [dof(i)] = true;
+        _period_assoc [dof(i)] = single_dof;
+       }
+    }
+  }
+}
 // ==========================================================================
 //  lock components
 // ==========================================================================
@@ -1045,6 +1145,50 @@ spacerep::x_dof(const geo_element& K, size_type iloc) const
     }
     return x;
 }
+
+// ==========================================================================
+// Space on a 1D domain: returns the orientation of positive curvilinear 
+// coordinates
+// ==========================================================================
+/*
+int
+spacerep::element_orientation(const geo_element& K) const
+{
+  if (!_element_orientation_initialized) initialize_element_orientation(); 
+  return (element_positively_oriented[K.index()])?1:-1;
+}
+void
+spacerep::initialize_element_orientation() const
+{
+  check_macro(_is_on_boundary_domain && (get_geo().map_dimension()==1),
+  	"Only 1D boundary domains can be oriented");
+  interface bc;
+  get_global_geo().sort_interface(_boundary_domain, bc, element_positively_oriented);
+  iter_K = bc.begin();
+  last_K = bc.end();
+  const geo_element& e0 = _boundary_domain.at(*iter_K++);
+  const geo_element& e1 = _boundary_domain.at(*iter_K);
+  previous_pos_or = (e0[1]==e1[0] || e0[1]==e1[1]);
+  element_positively_oriented[(*iter_K).index()] = previous_pos_or;
+  for (; iter_K!=last_K; iter_K++)
+   {
+  	e1 = _boundary_domain.at(*iter_K);
+	if (previous_pos_or)
+	{
+	  previous_pos_or = (e1[0] == e0[1]);
+	  check_macro( (e1[0]==e0[1])||(e1[1]==e0[1]), "error");
+	}
+	else
+	{
+	  previous_pos_or = (e1[0] == e0[0]);
+	  check_macro( (e1[0]==e0[1])||(e1[1]==e0[1]), "error");
+	}
+	element_positively_oriented[(*iter_K).index()] = previous_pos_or;
+	e0 = e1; 
+   }
+  _dof_orientation_initialized=true;
+}
+*/
 // ==========================================================================
 // Hermite/Argyris: returns 1 if the global dof contains the derivative along 
 // outward normal of K, -1 else  
@@ -1054,27 +1198,47 @@ spacerep::dof_orientation(const geo_element& K, tiny_vector<int>& orientation) c
 {
   if (!_dof_orientation_initialized) initialize_dof_orientation(); 
   tiny_vector<size_type> idx;
-  set_dof (K, idx);
+  set_global_dof (K, idx);
   orientation.resize(idx.size());
   for (size_t i=0; i<idx.size(); i++)
-   	orientation[i] = (_dof_oriented_as_element[idx[i]]==K.index())?1:-1;
+   {
+   	size_t idof=domain_dof(idx(i));
+	check_macro(_dof_oriented_as_element[idof]!=numeric_limits<size_t>::max(),
+		"Error!");
+   	orientation[i] = (_dof_oriented_as_element[idof]==K.index())?1:-1;
+   }
 }
+
 // ==========================================================================
 // Hermite/Argyris: the element of lowest index number sets the orientation
 // ==========================================================================
 void
 spacerep::initialize_dof_orientation() const
 {
-  geo::const_iterator iter_K = get_geo().begin();
+  geo::const_iterator iter_K;
+  geo::const_iterator last_K;
+  if (_is_on_boundary_domain)
+   {
+     iter_K = _boundary_domain.begin();
+     last_K = _boundary_domain.end();
+   }
+  else
+   {
+     iter_K = get_geo().begin();
+     last_K = get_geo().end();
+   }
   _dof_oriented_as_element.resize(size(), numeric_limits<size_t>::max());
-  for (; iter_K!=get_geo().end(); iter_K++)
+  for (; iter_K!=last_K; iter_K++)
    {
 	const geo_element& K=*iter_K;
   	tiny_vector<size_type> idx;
-   	set_dof(K, idx);
+   	set_global_dof(K, idx);
 	for (size_t i=0; i<idx.size(); i++)
-		if (K.index()<_dof_oriented_as_element[idx[i]])
-			_dof_oriented_as_element[idx[i]]=K.index();
+	 {
+	 	size_t i_dof = domain_dof(idx[i]); 
+		if (K.index()<_dof_oriented_as_element[i_dof])
+			_dof_oriented_as_element[i_dof]=K.index();
+	 }
    }
   _dof_orientation_initialized=true;
 }
@@ -1232,6 +1396,10 @@ spacerep::dump (ostream& os) const
     os << "num.size " << _num.size() << endl;
     for (size_type i = 0; i < _num.size(); i++) os << "num["<<i<<"]="<<_num[i] << endl;
 
+    os << "is_periodic.size " << _is_periodic.size() << endl;
+    for (size_type i = 0; i < _is_periodic.size(); i++) 
+    	if (_is_periodic[i]) os << "period_assoc["<<i<<"]="<<_period_assoc[i] << endl;
+
     os << "global_dof.size " << _global_dof.size() << endl;
     for (size_type i = 0; i < _global_dof.size(); i++) os << "global_dof["<<i<<"]="<<_global_dof[i] << endl;
 
@@ -1376,7 +1544,7 @@ spacerep::operator == (const spacerep& y) const
 meshpoint 
 spacerep::hatter (const point& x, size_type K_idx) const {
     const geo_element& K = _g.element (K_idx);
-    switch(K.type()) {
+    switch(K.variant()) {
         case geo_element::e: {
             Float a = _g.vertex(K[0]) [0];
             Float b = _g.vertex(K[1]) [0];
@@ -1424,7 +1592,7 @@ spacerep::dehatter (const meshpoint& hat_xe, bool is_a_vector) const
     const point&       hat_x = hat_xe.hat();
     size_t             K_idx = hat_xe.element();
     const geo_element& K     = _g.element (K_idx);
-    switch(K.type()) {
+    switch(K.variant()) {
         case geo_element::e: {
             Float a = _g.vertex(K[0]) [0];
             Float b = _g.vertex(K[1]) [0];
