@@ -160,7 +160,7 @@ OTHER OPTIONS:
     @item -proj
 	performs a @code{P1} projection on the fly.
 	This option is useful when rendering @code{P0} data
-	while @code{vtk} render requieres @code{P1} description.
+	while @code{vtk} render requires @code{P1} description.
 
 @cindex elevation
     @item -elevation
@@ -193,7 +193,7 @@ OTHER OPTIONS:
    
     @item -noexecute
         does not execute graphic command. Generates only
-        graphic files. This is usefull in conjuction with the
+        graphic files. This is useful in conjunction with the
         @code{-noclean} command.
 
     @end table
@@ -395,6 +395,7 @@ int main(int argc, char**argv)
     std::pair<Float,Float> u_range;
     u_range.first  =  std::numeric_limits<Float>::max();
     u_range.second = -std::numeric_limits<Float>::max();
+    dout.os() << label;
 
     for (int i = 1; i < argc; i++) {
 
