@@ -49,23 +49,25 @@ INPUT FILE SPECIFICATION:
     @item -name
         when the field comes from standard input, the file base name
         is not known and is set to "output" by default.
-        This option allows to change this default.
+        This option allows one to change this default.
         Useful when dealing with output formats (graphic, format conversion)
-        that creates auxilliary files, based on this name.
+        that creates auxiliary files, based on this name.
 @cindex RHEOPATH environment variable
     @item -I@var{dir} 
     @itemx -I @var{dir} 
         Add @var{dir} to the rheolef file search path.
-	This option is usefull e.g. when the mesh .geo and the .field fikes are in
+	This option is useful e.g. when the mesh .geo and the .field fikes are in
 	different directories.
         This mechanism initializes a search path given by the environment variable @samp{RHEOPATH}.
         If the environment variable @samp{RHEOPATH} is not set, the default value is the current directory.
 
 
 @clindex catchmark
-    @item -catchmark @var{string}
-	Jump accross the file to the specifield @var{string}.
-        Label start at the begining of a line, preceded by a @file{#} mark (see @pxref{catchmark algorithm}).
+    @item  -mark @var{string}
+    @itemx -catch @var{string}
+    @itemx -catchmark @var{string}
+	Jump across the file to the specifield @var{string}.
+        Label start at the beginning of a line, preceded by a @file{#} mark (see @pxref{catchmark algorithm}).
     @end table
 
 OUTPUT FILE FORMAT OPTIONS:
@@ -120,6 +122,8 @@ GETTING INFORMATION:
     @item -min
     @itemx -max
         print the min (resp. max) value of the scalar field and then exit.
+    @item -get-geo
+        print the name of the mesh associated to the field and exit.
     @end table
 
 RENDER OPTIONS:
@@ -128,15 +132,16 @@ RENDER OPTIONS:
 @toindex @code{gnuplot}
   @item -gnuplot
 	use @code{gnuplot} tool.
-	This is the default in one and two dimension.
-@toindex @code{mayavi}
-  @item -mayavi
-        use @code{mayavi} tool.
-        This is the default for tridimensional geometries.
+	This is the default in one dimension.
 @toindex @code{paraview}
   @item -paraview
         use @code{paraview} tool.
-        This is feature is under development.
+        This is the default for two- and tri-dimensional geometries.
+@toindex @code{mayavi}
+  @item -mayavi
+        use @code{mayavi} tool.
+        This is maintained for backward compatibility purpose:
+	it has been supersetted by the paraview render.
   @end table
 
 RENDERING OPTIONS:
@@ -202,21 +207,21 @@ RENDERING OPTIONS:
     @item -lumped-proj
         Force P1 approximation for L2 projection and use a lumped mass matrix for it.
     @item -round [@var{float}]
-        Round the input up to the specifiexd precision.
+        Round the input up to the specified precision.
         This option, combined with @code{-field}, leads to a round filter.
-        Usefull for non-regression test purpose, in order
+        Useful for non-regression test purpose, in order
   	to compare numerical results between files with a limited precision,
         since the full double precision is machine-dependent.
 
 @cindex vorticity
 @cindex stream function
     @item -n-iso-negative @var{int}
-        The isovalue table is splitted into negatives and positives values.
+        The isovalue table is split into negatives and positives values.
         Assume there is n_iso=15 isolines: if 4 is requested by this option,
         then, there will be 4 negatives isolines, regularly spaced
         from fmin to 0 and 11=15-4 positive isolines, regularly spaced
         from 0 to fmax.
-        This option is usefull when plotting e.g. vorticity or stream
+        This option is useful when plotting e.g. vorticity or stream
         functions, where the sign of the field is representative.
     @item -subdivide int
         When using a high order geometry, the number of points per edge used to draw
@@ -261,7 +266,7 @@ OTHERS OPTIONS:
     
     @item -noexecute
 	does not execute graphic command. Generates only 
-	graphic files. This is usefull in conjuction with the
+	graphic files. This is useful in conjunction with the
 	@code{-noclean} command.
     @end table
 FIELD FILE FORMAT:
@@ -271,7 +276,7 @@ The header contains the @code{field}
 keyword followed by a line containing a format version number (presently 1),
 the number of degrees of freedom (i.e. the number of values listed),
 the mesh file name without the @file{.geo} extension
-the approximation (e.g. P1, P2, etc), and finaly the list of values:
+the approximation (e.g. P1, P2, etc), and finally the list of values:
 @noindent
 A sample field file (compatible with the sample mesh example presented in
 command manual; see @ref{geo command}) writes:
@@ -304,22 +309,13 @@ EXAMPLES:
   This command generates the isosurface as a 3d surface mesh in
   @file{.geo} format. This is suitable for others treatments.
 
-INPUT FILE FORMAT OPTIONS:
-  TODO
-
-FILE FORMAT CONVERSIONS:
- TODO
-
-GETTING INFORMATION:
- TODO
- 
 AUTHOR: Pierre.Saramito@imag.fr
 DATE:
     last change: 11 oct 2011. initial version: 7 july 1997
 End:
 */
 
-# include "rheolef.h"
+# include "rheolef_seq.h"
 # include "rheolef/iofem.h"
 using namespace rheolef;
 using namespace std;
@@ -328,10 +324,10 @@ void usage() {
            << "field "
            << "{-|file[.field[.gz]]}"
            << "[-Idir|-I dir] "
-           << "[-catchmark string] "
-           << "[-min|-max] "
+           << "[-[catch]mark string] "
+           << "[-min|-max|-get-geo] "
            << "[-field|-text|-gmsh|-gmsh-pos|-bamg-bb] "
-           << "[-gnuplot|-mayavi|-paraview] "
+           << "[-gnuplot|-paraview|-mayavi] "
            << "[-image-format string] "
            << "[-resolution int [int]] "
            << "[-name string] "
@@ -349,7 +345,7 @@ void usage() {
            << "[-domain string] "
            << "[-proj [string]] "
            << "[-lumped-proj] "
-           << "[-round float] "
+           << "[-round [float]] "
            << "[-velocity|-deformation] "
            << "[-elevation] "
            << "[-scale float] "
@@ -389,11 +385,26 @@ typedef enum {
         show_none,
         show_min,
         show_max,
+        show_geo,
 } show_type;
 
 int main(int argc, char**argv) {
-    environment distributed(argc, argv);
+    environment_option_type eopt;
+    //eopt.thread_level = environment_option_type::no_thread;
+    environment rheolef (argc, argv, eopt);
     check_macro (communicator().size() == 1, "field: command may be used as mono-process only");
+    // ----------------------------
+    // NEW: for child processes (TODO: move in environment)
+    // ----------------------------
+#ifdef TO_CLEAN
+    MPI_Comm parent_comm;
+    MPI_Comm_get_parent (&parent_comm);
+    if (parent_comm == MPI_COMM_NULL) { // no upstream mpi process: create new_np=1 more processes
+      cerr << "field: I'm NOT a child..." << endl;
+    } else {
+      cerr << "field: I'm a child..." << endl;
+    }
+#endif // _RHEOLEF_HAVE_MPI
     // ----------------------------
     // default options
     // ----------------------------
@@ -419,6 +430,7 @@ int main(int argc, char**argv) {
     std::string reduce_to_domain = "";
     Float round_prec = sqrt(std::numeric_limits<Float>::epsilon());
     show_type show = show_none;
+    dout.os() << label;
     // ----------------------------
     // scan the command line
     // ----------------------------
@@ -466,6 +478,7 @@ int main(int argc, char**argv) {
         // inquire option
         else if (strcmp (argv[i], "-min") == 0)       { show = show_min; }
         else if (strcmp (argv[i], "-max") == 0)       { show = show_max; }
+        else if (strcmp (argv[i], "-get-geo") == 0)   { show = show_geo; }
 
 	// render options:
         else if (strcmp (argv[i], "-velocity") == 0)        { dout.os() << velocity;    vector_style = velocity_style; }
@@ -538,9 +551,9 @@ int main(int argc, char**argv) {
             size_t ny = (i < argc-1 && isdigit(argv[i+1][0])) ? atoi(argv[++i]) : nx;
 	    dout.os() << setresolution(point_basic<size_t>(nx,ny));
         }
-        else if (strcmp (argv[i], "-catchmark") == 0)       {
+        else if (strcmp (argv[i], "-mark") == 0 || strcmp (argv[i], "-catch") == 0 || strcmp (argv[i], "-catchmark") == 0) {
             if (i == argc-1) {
-                cerr << "field -catchmark: option argument missing" << endl;
+                cerr << "field -mark: option argument missing" << endl;
                 usage();
             }
 	    mark = argv[++i];
@@ -635,7 +648,8 @@ int main(int argc, char**argv) {
     }
     if (render == no_render) {
         // try to choose the best render from dimension
-        if (uh.get_geo().map_dimension() == 3) {
+        if (uh.get_geo().map_dimension() >= 2 ||
+            uh.get_geo().dimension() == 3) {
           dout.os() << paraview;
         } else {
           dout.os() << gnuplot;
@@ -699,7 +713,7 @@ int main(int argc, char**argv) {
       space_basic<Float,sequential> Vh (uh.get_geo(), approx, uh.valued());
       test_basic<Float,sequential,details::vf_tag_10> u (Uh), v (Vh);
       test_basic<Float,sequential,details::vf_tag_01> vt (Vh);
-      form_option_type fopt;
+      integrate_option fopt;
       fopt.lump = do_lumped_mass;
       form_basic<Float,sequential> m, p;
       switch (Uh.valued_tag()) {
@@ -747,6 +761,10 @@ int main(int argc, char**argv) {
            << uh.max() << endl;
       return 0;
     }
+    if (show == show_geo) {
+      cout << uh.get_geo().name() << endl;
+      return 0;
+    }
     if (do_iso3d) {
       geo_basic<Float,sequential> iso_surface = paraview_isosurface (uh);
       dout << iso_surface;
@@ -772,4 +790,13 @@ int main(int argc, char**argv) {
     }
     // final output:
     dout << uh;
+    // ----------------------------
+    // NEW: for child processes (TODO: move in environment)
+    // ----------------------------
+#ifdef TO_CLEAN
+    if (parent_comm != MPI_COMM_NULL) {
+      cerr << "field: I'm a child and I send signal to parents" << endl;
+      MPI_Barrier (parent_comm);
+    }
+#endif // _RHEOLEF_HAVE_MPI
 }
