@@ -51,7 +51,7 @@ EXAMPLES:
   The old file format does not contains edges and faces connectivity in 3d geometries,
   or edges connectivity in 2d geometries.
   The converter add it automatically into the upgraded file format.
-  Conversely, the old file format is usefull when combined with a
+  Conversely, the old file format is useful when combined with a
   translator from another file format that do not provides edges and faces connectivity.
 
 INPUT FILE SPECIFICATION:
@@ -65,9 +65,9 @@ INPUT FILE SPECIFICATION:
   @item -name
         when mesh comes from standard input, the mesh name
         is not known and is set to "output" by default.
-        This option allows to change this default.
+        This option allows one to change this default.
         Useful when dealing with output formats (graphic, format conversion)
-        that creates auxilliary files, based on this name.
+        that creates auxiliary files, based on this name.
 @cindex RHEOPATH environment variable
   @item -I@var{dir} 
   @itemx -I @var{dir} 
@@ -97,14 +97,18 @@ RENDER SPECIFICATION:
 @toindex @code{gnuplot}
   @table @code
   @item -gnuplot
-        use gnuplot tool.
-        This is the default.
-@toindex @code{mayavi}
+        Use gnuplot tool.
+        This is the default for 1D and 2D geometries.
 @toindex @code{paraview}
-  @item -mayavi
-        use @code{mayavi} tool.
   @item -paraview
-        use @code{paraview} tool.
+        Use @code{paraview} tool.
+        This is the default for 3D geometries.
+@toindex @code{mayavi}
+  @item -mayavi
+        Use @code{mayavi} tool.
+        This tool has been supersetted by @code{paraview}
+	for 3D geometries. 
+	It its maintained for backward compatibility purpose.
   @end table
 
 RENDER OPTIONS:
@@ -128,6 +132,12 @@ RENDER OPTIONS:
   @item -[no]label
         Show or hide labels, boundary domains and various annotations.
         By default, domains are showed with a specific color.
+  @item -round [@var{float}]
+        Round the input up to the specified precision.
+        This option, combined with @code{-geo}, leads to a round filter.
+        Useful for non-regression test purpose, in order
+        to compare numerical results between files with a limited precision,
+        since the full double precision is machine-dependent.
   @end table
 
 OUTPUT FILE FORMAT OPTIONS:
@@ -188,13 +198,13 @@ OTHERS OPTIONS:
   	does not exists, extract the boundary of the geometry
 	and append it to the domain list.
 @toindex @code{bamg}
-	This command is usefull for mesh converted from 
+	This command is useful for mesh converted from 
 	generators, as @code{bamg}, that cannot have more than
 	one domain specification per boundary edge.
 
     @item -rz
     @itemx -zr
-	Specifies the coordinate system. Usefull when converting
+	Specifies the coordinate system. Useful when converting
 	from bamg or gmsh format,.
 
     @item -verbose
@@ -215,7 +225,7 @@ OTHERS OPTIONS:
     
     @item -noexecute
         does not execute graphic command. Generates only 
-        graphic files. This is usefull in conjuction with the
+        graphic files. This is useful in conjunction with the
         "-noclean" command.
 
   @item -check
@@ -226,18 +236,174 @@ OTHERS OPTIONS:
 INQUIRE OPTIONS:
   @table @code
   @item -size
-  @itemx -n-vertex
-        print the mesh size, i.e. the number of elements (resp. of vertices) and then exit.
+  @itemx -n-element
+        print the mesh size, i.e. the number of elements and then exit.
+  @item -n-vertex
+        print the number of elements and then exit.
+  @item -sys-coord
+        print the coordinate systemm and then exit.
   @item  -hmin
   @itemx -hmax
         print the smallest (resp. largest) edge length and then exit.
-  @item -min-element-measure
+  @item  -xmin
+  @itemx -xmax
+        print the bounding box lower-left (resp. top-right) corner and exit.
+  @item  -min-element-measure
   @itemx -max-element-measure
         print the smallest (resp. largest) element measure and then exit.
   @end table
 
 GEO FILE FORMAT:       
-	TODO
+  @noindent
+  This is the default mesh file format.
+  It contains two entities, namely a mesh and a list of domains.
+  The mesh entity starts with the @code{mesh} keyword,
+  that should be at the beginning of a line.
+  It is followed by the geo format version number:
+  the current mesh format version number is 4.
+  Next comes the header, containing global information:
+  the space dimension (e.g. 1, 2 or 3), the number of nodes
+  and the number of elements, for each type of element (tetrahedra, etc).
+  When dimension is three, the number of faces (triangles, quadranggles) is specified,
+  and then, when dimension is two or three, the number of edges is also specified.
+  Follows the node coordinates list and the elements connectivity list.
+  Each element starts with a letter indicating the element type:
+  @table @samp
+       	@item p
+       		point 
+       	@item e
+       		edge 
+	@item t
+		triangle
+	@item q
+		quadrangle
+	@item T
+		tetrahedron
+        @item P
+		prism
+	@item H
+		hexaedron
+  @end table
+  @noindent
+  Then, for each element, comes the vertex indexes.
+  A vertex index is numbered in the C-style,
+  i.e. the first index started at 0 and the larger one
+  is the number of vertices minus one.
+  A sample mesh writes:
+  @example
+   mesh
+   4
+   header
+    dimension 2
+    nodes     4
+    triangles 2
+    edges     5
+   end header
+   0 0
+   1 0
+   1 1
+   0 1
+   t   0 1 3
+   t   1 2 3
+   e   0 1
+   e   1 2
+   e   2 3
+   e   3 0
+   e   1 3
+  @end example
+
+  @noindent
+  Note that information about edges for 2d meshes and faces for 3d one
+  are required for maintaining P2 and higher order approximation fields in a consistent way:
+  degrees of freedom associated to sides requires that sides are well defined.
+
+  @noindent
+  The second entity is a list of domains, that finishes with the end of file.
+  A domain starts with the @code{domain} keyword,
+  that should be at the beginning of a line.
+  It is followed by the domain name, a simple string.
+  Then, comes the domain format version:
+  the current domain version number is 2.
+  Next, the domain dimension and its number of elements.
+  Finally, the list of elements: they are specified by
+  the element index in the mesh, preceded by its orientation.
+  A minus sign specifies that the element (generaly a side)
+  has the opposite orientation, while the plus sign is omitted.
+  A sample domain list writes:
+  @example
+   domain
+   bottom
+   2 1 1
+   0
+   
+   domain
+   top
+   2 1 1
+   2
+  @end example
+  Copy and paste the previous sample mesh data in a file, e.g. "square.geo".
+  Be carreful for the "mesh" and "domain" to be at the beginning of a line.
+  Then enter:
+  @example
+    geo square.geo
+  @end example
+  and the mesh is displayed.
+
+FILE FORMAT CONVERSION AND SIMPLIFIED GEO FILE FORMAT:       
+@toindex @code{gmsh}
+@toindex @code{bamg}
+  Information about edges for 2d meshes and faces for 3d one is not
+  provided by most mesh generators (e.g. gmsh or bamg).
+  It could be complex to build this list, so a simplified file format is 
+  also supported, without faces and/or edges connectvity,
+  and the geo command proposes to build it automatically and save it
+  in a more complete, upgraded geo file. 
+
+  @noindent
+  The simplified version of the previous mesh is:
+  @example
+   mesh
+   4
+   header
+    dimension 2
+    nodes     4
+    triangles 2
+   end header
+   0 0
+   1 0
+   1 1
+   0 1
+   t   0 1 3
+   t   1 2 3
+  @end example
+  The domain list is no more able to refer to existing sides:
+  edges are simply listed by their complete connectivity, thanks
+  to the domain format version number 1.
+  For the previous example, we have:
+  @example
+   domain
+   bottom
+   1 1 1
+   e 0 1
+   
+   domain
+   top
+   1 1 1
+   e 2 3
+  @end example
+  Copy and paste the previous simplified sample mesh data in a file, e.g. "square0.geo".
+  Be carreful for the "mesh" and "domain" to be at the beginning of a line.
+  Then enter:
+  @example
+    geo -upgrade -geo square0.geo
+  @end example
+  and the previous mesh with its complete conectivity is displayed:
+  edges has been automatically identified and numbered,
+  and domains now refers to edge indexes.
+
+  Note that, for the @code{gms} and @code{bamg} mesh generators,
+  automatic file conversion is provided by 
+  the @code{msh2geo} and @code{bamg2geo} commands.
 
 AUTHOR: Pierre.Saramito@imag.fr
 DATE: 16 september 2011
@@ -268,6 +434,7 @@ void usage() {
            << "[-size] [-n-vertex] "
            << "[-hmin] [-hmax] "
            << "[-[min|max]-element-measure] "
+           << "[-round [float]] "
            << "[-[no]clean] [-[no]execute] [-[no]verbose] "
            << std::endl;
       exit (1);
@@ -337,10 +504,15 @@ int main(int argc, char**argv) {
     bool do_stereo   = false ;
     bool show_n_element = false ;
     bool show_n_vertex = false ;
+    bool show_sys_coord = false ;
     bool show_hmin = false ;
     bool show_hmax = false ;
+    bool show_xmin = false ;
+    bool show_xmax = false ;
     bool show_min_element_measure = false ;
     bool show_max_element_measure = false ;
+    bool do_round  = false ;
+    Float round_prec = pow(10., -std::numeric_limits<Float>::digits10/2);
     std::string name = "output";
     dout.os() << verbose; bool bverbose = true;
     render_type render = no_render;
@@ -372,9 +544,13 @@ int main(int argc, char**argv) {
         else if (strcmp (argv[i], "-rz") == 0)        { sys_coord = "rz"; }
         else if (strcmp (argv[i], "-zr") == 0)        { sys_coord = "zr"; }
         else if (strcmp (argv[i], "-size") == 0)      { show_n_element = true; }
+        else if (strcmp (argv[i], "-n-element") == 0) { show_n_element = true; }
         else if (strcmp (argv[i], "-n-vertex") == 0)  { show_n_vertex = true; }
+        else if (strcmp (argv[i], "-sys-coord") == 0) { show_sys_coord = true; }
         else if (strcmp (argv[i], "-hmin") == 0)      { show_hmin = true; }
         else if (strcmp (argv[i], "-hmax") == 0)      { show_hmax = true; }
+        else if (strcmp (argv[i], "-xmin") == 0)      { show_xmin = true; }
+        else if (strcmp (argv[i], "-xmax") == 0)      { show_xmax = true; }
         else if (strcmp (argv[i], "-min-element-measure") == 0)  { show_min_element_measure = true; }
         else if (strcmp (argv[i], "-max-element-measure") == 0)  { show_max_element_measure = true; }
         else if (strcmp (argv[i], "-I") == 0)         {
@@ -424,6 +600,13 @@ int main(int argc, char**argv) {
             size_t ny = (i < argc-1 && isdigit(argv[i+1][0])) ? atoi(argv[++i]) : nx;
 	    dout.os() << setresolution(point_basic<size_t>(nx,ny));
         }
+        else if (strcmp (argv[i], "-round") == 0)   {
+
+	    do_round = true;
+            if (i+1 < argc && is_float(argv[i+1])) {
+              round_prec = to_float (argv[++i]);
+            }
+        }
 	// input options:
         else if (strcmp (argv[i], "-upgrade") == 0)   { do_upgrade = true; dout.os() << rheo; render = file_render; }
         else if (strcmp (argv[i], "-check") == 0)   { do_check = true; }
@@ -490,12 +673,19 @@ int main(int argc, char**argv) {
     if (do_check) {
         check_macro (omega.check(bverbose), "geo check failed");
     }
-    bool show = show_min_element_measure || show_max_element_measure || show_hmin || show_hmax || show_n_element || show_n_vertex;
+    bool show = show_min_element_measure
+             || show_max_element_measure
+             || show_hmin || show_hmax
+             || show_xmin || show_xmax
+	     || show_n_element || show_n_vertex || show_sys_coord;
     if (show) {
       if (show_hmin)      { dout << "hmin = " << omega.hmin() << std::endl; }
       if (show_hmax)      { dout << "hmax = " << omega.hmax() << std::endl; }
+      if (show_xmin)      { dout << "xmin = " << omega.xmin() << std::endl; }
+      if (show_xmax)      { dout << "xmax = " << omega.xmax() << std::endl; }
       if (show_n_element) { dout << "size = " << omega.dis_size()  << std::endl; }
       if (show_n_vertex)  { dout << "n_vertex  = " << omega.dis_size(0) << std::endl; }
+      if (show_sys_coord) { dout << "sys_coord = " << omega.coordinate_system_name() << std::endl; }
       if (show_min_element_measure) {
         dout << "min_element_measure = " << extrema_element_measure (omega, true) << std::endl;
       }
@@ -504,11 +694,15 @@ int main(int argc, char**argv) {
       }
       return 0;
     }
-    if (render == no_render) { 
-      if (!do_stereo) {
-         dout.os() << gnuplot;
+    if (do_round) {
+      dout.os() << setrounding_precision(round_prec);
+    }
+    if (render == no_render) {
+      // try to choose the best render from dimension
+      if (do_stereo || omega.dimension() == 3) {
+        dout.os() << paraview;
       } else {
-         dout.os() << paraview;
+        dout.os() << gnuplot;
       }
     }
     dout << omega;
