@@ -29,11 +29,11 @@ NAME: @code{adapt} - mesh adaptation
 @findex  adapt
 @clindex field
 @clindex geo
-@clindex adapt_option_type
+@clindex adapt_option
 
-SYNOPSYS:
+SYNOPSIS:
  geo adapt (const field& phi);
- geo adapt (const field& phi, const adapt_option_type& opts);
+ geo adapt (const field& phi, const adapt_option& opts);
 DESCRIPTION:
 @toindex  bamg
 @toindex  gmsh
@@ -104,17 +104,17 @@ BAMG ANISOTROPIC METRIC:
  divides by quantities that can be very large  and the mesh adaptation
  can diverges when focusing on the singularities.
  In that case, the local normalization is preferable.
- Moreover, the focus on singularities can also be controled 
+ Moreover, the focus on singularities can also be controlled 
  by setting @code{opts.hmin} not too small.
 
- The local normalization has been choosen as the default since it is 
+ The local normalization has been chosen as the default since it is 
  more robust. When your field @code{phi} does not present singularities,
  then you can swith to the global numbering that leads to a best
  equirepartition of the error over the domain.
 End: */
 
 //<adapt:
-struct adapt_option_type {
+struct adapt_option {
     typedef std::vector<int>::size_type size_type;
     std::string generator;
     bool isotropic;
@@ -135,7 +135,7 @@ struct adapt_option_type {
     bool double_precision;
     Float anglecorner;	// angle below which bamg considers 2 consecutive edge to be part of
     			// the same spline
-    adapt_option_type() :
+    adapt_option() :
         generator(""),
 	isotropic(true), err(1e-2), errg(1e-1), hcoef(1), hmin(0.0001), hmax(0.3), ratio(0), cutoff(1e-7),
 	n_vertices_max(50000), n_smooth_metric(1), 
@@ -148,8 +148,11 @@ template <class T, class M>
 geo_basic<T,M>
 adapt (
   const field_basic<T,M>& phi,
-  const adapt_option_type& options = adapt_option_type());
+  const adapt_option& options = adapt_option());
 //>adapt:
 
+// backward compatibility:
+using adapt_option_type = adapt_option;
+
 }// namespace rheolef
 #endif // _RHEO_ADAPT_OPTION_H
