@@ -31,7 +31,7 @@ template<class T, class M>
 field_basic<T,M>
 hessian_criterion (
     const field_basic<T,M>&  uh0,
-    const adapt_option_type& opts);
+    const adapt_option& opts);
 
 // -----------------------------------------
 // adapt
@@ -40,13 +40,13 @@ template<class T, class M>
 geo_basic<T,M>
 adapt_gmsh (
     const field_basic<T,M>&  uh,
-    const adapt_option_type& opts)
+    const adapt_option& opts)
 {
   using namespace std;
   typedef typename geo_basic<T,M>::size_type size_type;
   bool do_verbose  = iorheo::getverbose(clog);
   bool do_clean    = iorheo::getclean(clog);
-  string command;
+  string command, clean_files;
   // -----------------------------------------
   // 1a) sortie du maillage : nom-<i>.geo
   // -----------------------------------------
@@ -57,23 +57,17 @@ adapt_gmsh (
   odiststream out;
   if (! dis_file_exists(geo_name) &&
       ! dis_file_exists(geo_name + ".gz")) {
-    out.open (geo_name);
+    out.open (geo_name, io::nogz);
     out << omega;
     check_macro (out.good(), "adapt: file \"" << geo_name << "\"creation failed");
     out.close();
+    clean_files += " " + geo_name;
   }
-#ifdef TO_CLEAN
-  // ----------------------------------------
-  // 1b) conversion geo : nom-<i>.msh
-  // ----------------------------------------
-  command = "geo -noverbose -gmsh " + geo_name + " > " + i_name + ".msh";
-  if (do_verbose) derr << "! " << command << endl;
-  check_macro (dis_system (command) == 0, "adapt: unix command failed");
-#endif // TO_CLEAN
   // -----------------------------------------
   // 2a) sortie du critere : nom-crit-<i>.field
   // -----------------------------------------
   string crit_name = i_name + "-crit.field";
+  clean_files += " " + crit_name + ".gz";
   out.open (crit_name, "field");
   out << hessian_criterion(uh,opts);
   check_macro (out.good(), "adapt: file \"" << crit_name << "\"creation failed");
@@ -82,19 +76,25 @@ adapt_gmsh (
   // 2b) conversion field : nom-crit-<i>.pos
   // --------------------------------------------
   string pos_name = i_name + "-crit.pos";
-  command = "field -noverbose -gmsh-pos " + crit_name + " > " + pos_name;
+  clean_files += " " + pos_name;
+  string bindir = string(_RHEOLEF_RHEOLEF_LIBDIR) + "/rheolef";
+  command = "zcat " + crit_name + ".gz | " + bindir + "/field2gmsh_pos > " + pos_name;
   if (do_verbose) derr << "! " << command << endl;
   check_macro (dis_system (command) == 0, "adapt: unix command failed");
   // ----------------------------------------
   // 3) run gmsh in adapt mode with bamg:
   //     => nom-<i+1>.msh
   // ----------------------------------------
+  // TODO: use a "cad" header entry in the .geo file
+  // => get "mshcad_file" from omega.cad_filename();
   string mshcad_file = omega.familyname() + ".mshcad";
   check_macro (dis_file_exists(mshcad_file), "adapt: missing \""<<mshcad_file<<"\" file");
   string options  =  "-clmin " + ftos(opts.hmin)
                   + " -clmax " + ftos(opts.hmax)
                   + " -clscale " + ftos(opts.hcoef);
-  string i1_name = omega.familyname() + "-" + itos(i+1);
+  char buffer [100];
+  sprintf (buffer, "%.3d", int(i+1)); // see geo::name() in geo.cc
+  string i1_name = omega.familyname() + "-" + buffer;
   size_type d = omega.dimension();
   string algo = (d <= 2) ? "bamg" : "mmg3d";
   command = "gmsh " + options
@@ -107,9 +107,11 @@ adapt_gmsh (
   // ----------------------------------------
   // 4) conversion : nom-crit-<i>.msh
   // ----------------------------------------
-  command = "msh2geo " + i1_name + ".msh | geo -upgrade - -geo | gzip -9 > " + i1_name + ".geo.gz";
+  command = "msh2geo -" + omega.coordinate_system_name() 
+            + " " + i1_name + ".msh > " + i1_name + ".geo";
   if (do_verbose) derr << "! " << command << endl;
   check_macro (dis_system (command) == 0, "adapt: command failed");
+  clean_files += " " + i1_name + ".msh";
   // ----------------------------------------
   // 5) chargement  nom-<i+1>.geo
   // ----------------------------------------
@@ -118,13 +120,23 @@ adapt_gmsh (
   in >> new_omega;
   new_omega.set_name (omega.familyname());
   new_omega.set_serial_number (i+1);
+  clean_files += " " + i1_name + ".geo";
+  clean_files += " " + i1_name + ".geo.gz";
+  // ----------------------------------------
+  // 6) clean
+  // ----------------------------------------
+  if (do_clean) {
+    command = "rm -f" + clean_files;
+    if (do_verbose) derr << "! " << command << endl;
+    check_macro (dis_system (command) == 0, "adapt: command failed");
+  }
   return new_omega;
 }
 // ----------------------------------------------------------------------------
 // instanciation in library
 // ----------------------------------------------------------------------------
 #define _RHEOLEF_instanciation(T,M) 							\
-template geo_basic<T,M> adapt_gmsh (const field_basic<T,M>&, const adapt_option_type&);
+template geo_basic<T,M> adapt_gmsh (const field_basic<T,M>&, const adapt_option&);
 
 _RHEOLEF_instanciation(Float,sequential)
 #ifdef _RHEOLEF_HAVE_MPI
