@@ -30,7 +30,7 @@
 namespace rheolef {
 
 /*Class:
-NAME: @code{band} - compute the band arround a level set
+NAME: @code{band} - compute the band around a level set
 @findex  level_set
 @clindex field
 @clindex geo
@@ -46,8 +46,8 @@ ACCESSORS:
   Each side in the surface mesh, as returned by the @code{level_set} member
   function, is included into an element of the band mesh, as returned by the
   @code{band} member function. Moreover, in the distributed memory environment,
-  this correspondance is on the same process, so local indexes can be used
-  for this correspondance: this is the @code{sid_ie2bnd_ie} member functions.
+  this correspondence is on the same process, so local indexes can be used
+  for this correspondence: this is the @code{sid_ie2bnd_ie} member functions.
 
 BAND TOPOLOGY AND DOMAINS:
   For the direct resolution of systems posed on the band, the mesh returned
@@ -55,7 +55,7 @@ BAND TOPOLOGY AND DOMAINS:
   The @code{"zero"} vertex domain lists all vertices @code{xi} such that @code{fh(xi)=0}.
   The @code{"isolated"} vertex domain lists all vertices @code{xi}
   such that @code{fh(xi)!=0} and @code{xi} is contained by only one element @code{K}
-  and all vertices @code{xj!=xi} of @code{K} satifies @code{fh(xj)=0}.
+  and all vertices @code{xj!=xi} of @code{K} satisfies @code{fh(xj)=0}.
   Others vertices of the band, separated by the zero and isolated ones,
   are organizd by connected components:
   the @code{n_connex_component} member function returns its number.
@@ -75,7 +75,7 @@ public:
 
   band_basic();
   band_basic(const field_basic<T,M>& fh,
-    const level_set_option_type& opt = level_set_option_type());
+    const level_set_option& opt = level_set_option());
 
 /// accessors:
 
