@@ -219,7 +219,7 @@ template <class T, class M>
 inline
 branch_basic<T,M>::branch_basic ()
  : std::vector<std::pair<std::string,field_basic<T,M> > >(0),
-   _parameter_name ("*unamed*"),
+   _parameter_name ("*unnamed*"),
    _parameter_value(std::numeric_limits<T>::max()),
    _n_value        (std::numeric_limits<size_type>::max()),
    _count_value    (std::numeric_limits<size_type>::max()),
