@@ -24,11 +24,26 @@
 #include "rheolef/rheostream.h"
 #include "rheolef/band.h"
 
-namespace rheolef { namespace details { 
+// ===========================================================================
+// allocator
+// ===========================================================================
+namespace rheolef {
 
+template<class T, class M>
+characteristic_rep<T,M>::characteristic_rep(const field_basic<T,M>& dh)
+  : _dh(dh),
+    _coq_map()
+{
+  // automatically add the "boundary" domain, if not already present:
+  _dh.get_geo().boundary();
+}
+
+} // namespace rheolef
 // ===========================================================================
 // externs
 // ===========================================================================
+namespace rheolef { namespace details { 
+
 template<class T, class M>
 void
 interpolate_pass1_symbolic (
@@ -53,7 +68,7 @@ riesz_pass1_symbolic (
     const space_basic<T,M>&             Xh,
     const field_basic<T,M>&             dh,
  // i/o :
-          quadrature_option_type&       qopt,
+          quadrature_option&       qopt,
  // output :
           quadrature<T>&                   quad,
           basis_on_pointset<T>&            piola_on_quad,
@@ -92,7 +107,7 @@ trace_macro ("quadrature : " << quad.get_family_name() << " order " << quad.get_
     distributor ige_ownership = omega.sizes().ownership_by_variant [variant];
     if (ige_ownership.dis_size() == 0) continue;
     reference_element hat_K (variant);
-    size_type nq = piola_on_quad.size (hat_K);
+    size_type nq = piola_on_quad.pointset_size (hat_K);
         sz += nq*ige_ownership.size();
     dis_sz += nq*ige_ownership.dis_size();
   }
@@ -105,7 +120,7 @@ trace_macro ("quadrature : " << quad.get_family_name() << " order " << quad.get_
   for (size_type ixq = 0, ie = 0, ne = omega.size(); ie < ne; ie++) {
     const geo_element& K = omega[ie];
     omega.dis_inod (K, dis_inod);
-    for (size_type q = 0, nq = piola_on_quad.size(K); q < nq; q++, ixq++) {
+    for (size_type q = 0, nq = piola_on_quad.pointset_size(K); q < nq; q++, ixq++) {
       xq[ixq] = piola_transformation (omega, piola_on_quad, K, dis_inod, q);
     }
   }
@@ -122,7 +137,7 @@ trace_macro ("quadrature : " << quad.get_family_name() << " order " << quad.get_
   for (size_type ixq = 0, ie = 0, ne = omega.size(); ie < ne; ie++) {
     const geo_element& K = omega[ie];
     Dh.dis_idof (K, d_dis_idof);
-    for (size_type q = 0, nq = piola_on_quad.size(K); q < nq; q++, ixq++) {
+    for (size_type q = 0, nq = piola_on_quad.pointset_size(K); q < nq; q++, ixq++) {
       dq[ixq] = vector_field_evaluate (dh, d_basis_on_quad, K, d_dis_idof, q);
       ix2dis_ie[ixq] = ie; // will be a guest for locate(yq)
     }
@@ -148,18 +163,18 @@ const characteristic_on_quadrature<T,M>&
 characteristic_rep<T,M>::get_pre_computed (
     const space_basic<T,M>&       Xh,
     const field_basic<T,M>&       dh,
-    const quadrature_option_type& qopt1) const
+    const quadrature_option& qopt1) const
 {
   // get a good quadrature if not set
   typedef typename space_basic<T,M>::size_type size_type;
-  quadrature_option_type qopt = qopt1;
-  if (qopt.get_order() == std::numeric_limits<quadrature_option_type::size_type>::max()) {
+  quadrature_option qopt = qopt1;
+  if (qopt.get_order() == std::numeric_limits<quadrature_option::size_type>::max()) {
     size_type quad_order = Xh.get_numbering().get_basis().degree();
     if (Xh.get_geo().coordinate_system() != space_constant::cartesian) quad_order++;
     qopt.set_order (quad_order);
   }
-  if (qopt.get_family() == quadrature_option_type::max_family) {
-    qopt.set_family (quadrature_option_type::gauss_lobatto);
+  if (qopt.get_family() == quadrature_option::max_family) {
+    qopt.set_family (quadrature_option::gauss_lobatto);
   }
   // search if already used & memorized
   std::string label = qopt.get_family_name() + "(" + itos(qopt.get_order()) + ")";
