@@ -22,6 +22,7 @@
 /// =========================================================================
 
 #include "rheolef/damped-newton-generic.h"
+#include "rheolef/newton_add_missing.h"
 
 namespace rheolef { 
 
@@ -48,7 +49,8 @@ DESCRIPTION:
     class my_problem @{
     public:
       ...
-      Float space_norm (const field& uh) const;
+      value_type derivative_trans_mult (const value_type& mrh) const;
+      Float space_norm (const value_type& uh) const;
     @};
   @end example
 AUTHOR:
@@ -58,29 +60,15 @@ DATE:   14 oct 2009
 METHODS: @newton
 End:
 */
-struct newton_identity_preconditioner {
-  template <class Problem>
-  Float operator() (const Problem& P, const typename Problem::value_type& MFv) const {
-    return 0.5*sqr(P.dual_space_norm(MFv));
-  }
-  template <class Problem>
-  Float operator() (const Problem& P, const typename Problem::value_type& MFu, const typename Problem::value_type& delta_u) const {
-    return operator() (P, MFu);
-  }
-  template <class Problem>
-  typename Problem::value_type grad (const Problem& P, const typename Problem::value_type& MFu) const { 
-    return P.derivative_trans_mult (MFu);
-  }
-  template <class Problem>
-  Float slope (const Problem& P, const typename Problem::value_type& MFu, const typename Problem::value_type& delta_u) const { 
-    return -sqr(P.dual_space_norm(MFu));
-  }
-};
+
 //<damped_newton:
 template <class Problem, class Field, class Real, class Size>
-int damped_newton (Problem P, Field& u, Real& tol, Size& max_iter, odiststream* p_derr=0) {
-  return damped_newton(P, newton_identity_preconditioner(), u, tol, max_iter, p_derr);
-}
+int damped_newton (const Problem& F, Field& u, Real& tol, Size& max_iter, odiststream* p_derr=0)
 //>damped_newton:
+{
+  details::add_missing_damped_newton<Problem> G (F); // TODO: avoid a copy of pb F here: put a reference in G ?
+  return damped_newton (G, newton_identity_preconditioner(), u, tol, max_iter, p_derr);
+}
+
 }// namespace rheolef
 # endif // _RHEO_DAMPED_NEWTON_H
