@@ -287,9 +287,9 @@ DESCRIPTION:
   The @code{domain_indirect} class defines a container for a part of a
   finite element mesh.
   This describes the connectivity of edges or faces.
-  This class is usefull for boundary condition setting.
+  This class is useful for boundary condition setting.
 IMPLEMENTATION NOTE:
-  The @code{domain} class is splitted into two parts.
+  The @code{domain} class is split into two parts.
   The first one is the @code{domain_indirect} class, that contains the main
   renumbering features: it acts as a indirect on a @code{geo} class(@pxref{geo class}).
   The second one is the @code{domain} class, that simply contains two
