@@ -156,7 +156,8 @@ field_basic<T,M>::get (idiststream& ids)
     } else {
       omega = geo_type (geo_name); // load a new mesh
     }
-    constit = space_constitution<T,M>(omega, approx);
+    // TODO: get directly "P1" as a space_constitution by: "ids >> constit"; as for the version 2 format
+    constit = space_constitution<T,M>(omega, approx, "scalar");
   }
   // TODO: do not load mesh when we re-use _V: read only string constit and compare to _V.stamp()
   if (!(_V.get_constitution() == constit)) {
@@ -252,8 +253,9 @@ odiststream&
 field_basic<T,M>::put_field (odiststream& ods) const
 {
   using namespace std;
-  if (get_space().get_constitution().is_hierarchical()) {
-    // multi-field header
+  bool need_header = (get_space().get_constitution().is_hierarchical());
+  if (need_header) {
+    // multi-field header or non-equispaced node set
     ods << "field" << endl
         << "2" << endl
         << "header" << endl
@@ -261,6 +263,7 @@ field_basic<T,M>::put_field (odiststream& ods) const
         << "end header" << endl
         << endl;
   } else {
+    // scalar-field header and equispaced node set
     const space_scalar_constitution<T,M>& scalar_constit = get_space().get_constitution().get_scalar();
     ods << "field" << endl
         << "1 " << dis_ndof() << endl 
@@ -393,7 +396,8 @@ field_basic<T,M>::evaluate (const geo_element& K, const point_basic<T>& hat_x, s
   }
   // WARNING: not efficient since it evaluate the hat_basis at each hat_x
   // when hat_x is on a repetitive pattern, such as quadrature nodes or Lagrange basis nodes
-  std::vector<T> b_value (loc_ndof);
+  // TODO: evaluate basis one time for all on hat_K
+  arma::Col<T>   b_value (loc_ndof);
   b.eval (K, hat_x, b_value);
 
   T value = 0;
