@@ -129,7 +129,7 @@ NON-LINEAR ALGEBRA:
   Notice that when using isoparametric elements, the normal vector is no more
   constant along any face of the mesh.
   Also, on general curved domains, the unit normal vector is discontinuous
-  accross boundary element interfaces.
+  across boundary element interfaces.
 
 ACCESS BY DOMAIN:
   The restriction of a field to a geometric domain, says @code{"boundary"}
@@ -217,7 +217,7 @@ LOW-LEVEL DEGREE-OF-FREEDOM ACCESS:
   See @pxref{disarray class} for more about distributed arrays.
 
   For convenience, @code{uh.max()}, @code{uh.min()} and @code{uh.max_abs()} 
-  retuns respectively the maximum, minimum and maximum of the absolute value
+  returns respectively the maximum, minimum and maximum of the absolute value
   of the degrees of freedom.
 
 FILE FORMAT:
@@ -264,17 +264,6 @@ public :
     field_basic<T,M>& operator=  (const T&);
     field_basic<T,M>& operator=  (const field_basic<T,M>&);
 
-#ifdef TO_CLEAN
-    field_basic                   (const field_indirect<T,M>&);
-    field_basic<T, M>& operator=  (const field_indirect<T,M>&);
-    field_basic                   (const field_indirect_const<T,M>&);
-    field_basic<T, M>& operator=  (const field_indirect_const<T,M>&);
-    field_basic                   (const field_component<T,M>&);
-    field_basic<T, M>& operator=  (const field_component<T,M>&);
-    field_basic                   (const field_component_const<T,M>&);
-    field_basic<T, M>& operator=  (const field_component_const<T,M>&);
-#endif // TO_CLEAN
-
     // linear expressions:
     template <class Expr, class Sfinae
                     = typename std::enable_if<
@@ -380,18 +369,18 @@ public:
         const geo_basic<T,M>&         band,
         const band_basic<T,M>&        gh,
         const Expr&                   expr,
-        const quadrature_option_type& qopt,
+        const quadrature_option& qopt,
         bool                          is_on_band);
     template <class Expr>
     void assembly (
         const geo_basic<T,M>&         domain,
         const Expr&                   expr,
-        const quadrature_option_type& qopt);
+        const quadrature_option& qopt);
     template <class Expr>
     void assembly (
         const band_basic<T,M>&        gh,
         const Expr&                   expr,
-        const quadrature_option_type& qopt);
+        const quadrature_option& qopt);
 
 protected:
     void dis_dof_indexes_requires_update() const;
@@ -460,10 +449,6 @@ public:
   bool operator== (const iterator& j) const { return _blk_iub_iter == j._blk_iub_iter; }
   bool operator!= (const iterator& j) const { return ! operator== (j); }
 protected:
-#ifdef TO_CLEAN
-  // CLANG problem
-  template <class T1, class M1> friend class field_basic<T1,M1>::const_iterator;
-#endif // TO_CLEAN
   friend class const_iterator;
 // data:
   iter_t _blk_iub_iter;
@@ -702,15 +687,6 @@ operator << (odiststream& ops, const field_basic<T,M>& uh)
 {
   return uh.put (ops);
 }
-#ifdef TO_CLEAN
-template <class T, class M>
-inline
-field_basic<T,M>
-norm (const field_basic<T,M>& uh)
-{
-  return sqrt(norm2(uh));
-}
-#endif // TO_CLEAN
 
 }// namespace rheolef
 # endif /* _RHEOLEF_FIELD_H */
