@@ -366,108 +366,6 @@ field_basic<T,M>::field_basic (const Expr& expr)
 {
     operator= (expr);
 }
-
-#ifdef TO_CLEAN
-template<class T, class M>
-inline
-field_basic<T,M>&
-field_basic<T,M>::operator=  (const field_indirect<T,M>& expr)
-{
-  if (stamp() == "") {
-    resize (expr.get_space());
-  } else {
-    check_macro (stamp() == expr.stamp(), "incompatible spaces "
-	<< stamp() << " and " << expr.stamp()
-	<< " in field = field[domain]");
-  }
-  dis_dof_indexes_requires_update();
-  algo::copy_n (expr.begin_dof(), expr.ndof(), begin_dof());
-  return *this;
-}
-template<class T, class M>
-inline
-field_basic<T,M>&
-field_basic<T,M>::operator=  (const field_indirect_const<T,M>& expr)
-{
-  if (stamp() == "") {
-    resize (expr.get_space());
-  } else {
-    check_macro (stamp() == expr.stamp(), "incompatible spaces "
-	<< stamp() << " and " << expr.stamp()
-	<< " in field = field[domain]");
-  }
-  dis_dof_indexes_requires_update();
-  algo::copy_n (expr.begin_dof(), expr.ndof(), begin_dof());
-  return *this;
-}
-template<class T, class M>
-inline
-field_basic<T,M>&
-field_basic<T,M>::operator=  (const field_component_const<T,M>& uh_comp)
-{
-  if (stamp() == "") {
-    resize (uh_comp.get_space());
-  } else {
-    check_macro (stamp() == uh_comp.stamp(), "incompatible spaces "
-        << stamp() << " and " << uh_comp.stamp()
-        << " in field = field[i_comp]");
-  }
-  dis_dof_indexes_requires_update();
-  std::copy (uh_comp.begin_dof(), uh_comp.end_dof(), begin_dof());
-  return *this;
-}
-template<class T, class M>
-inline
-field_basic<T,M>::field_basic (const field_indirect<T,M>& expr)
- : _V(),
-   _u(),
-   _b(),
-   _dis_dof_indexes_requires_update(true),
-   _dis_dof_assembly_requires_update(false)
-{
-    operator= (expr);
-}
-template<class T, class M>
-inline
-field_basic<T,M>::field_basic (const field_indirect_const<T,M>& expr)
- : _V(),
-   _u(),
-   _b(),
-   _dis_dof_indexes_requires_update(true),
-   _dis_dof_assembly_requires_update(false)
-{
-    operator= (expr);
-}
-template<class T, class M>
-inline
-field_basic<T,M>&
-field_basic<T,M>::operator=  (const field_component<T,M>& uh_comp)
-{
-  return operator= (field_component_const<T,M>(uh_comp));
-}
-template<class T, class M>
-inline
-field_basic<T,M>::field_basic (const field_component<T,M>& uh_comp)
- : _V(),
-   _u(),
-   _b(),
-   _dis_dof_indexes_requires_update(true),
-   _dis_dof_assembly_requires_update(false)
-{
-  operator= (uh_comp);
-}
-template<class T, class M>
-inline
-field_basic<T,M>::field_basic (const field_component_const<T,M>& uh_comp)
- : _V(),
-   _u(),
-   _b(),
-   _dis_dof_indexes_requires_update(true),
-   _dis_dof_assembly_requires_update(false)
-{
-  operator= (uh_comp);
-}
-#endif // TO_CLEAN
 // -------------------------------------------
 // 4.1.2. field_component
 // -------------------------------------------
@@ -482,30 +380,6 @@ field_component<T,M>::operator= (const Expr& expr) {
   details::assign_with_operator (begin_dof(), end_dof(), expr.begin_dof(), details::assign_op());
   return *this;
 }
-#ifdef TO_CLEAN
-template<class T, class M>
-inline
-field_component<T,M>&
-field_component<T,M>::operator= (const field_component<T,M>& uh_comp)
-{
-  check_macro (stamp() == uh_comp.stamp(), "incompatible spaces "
-        << stamp() << " and " << uh_comp.stamp()
-        << " in field[i_comp] = field[j_comp]");
-  std::copy (uh_comp.begin_dof(), uh_comp.end_dof(), begin_dof());
-  return *this;
-}
-template<class T, class M>
-inline
-field_component<T,M>&
-field_component<T,M>::operator= (const field_basic<T,M>& uh)
-{
-  check_macro (stamp() == uh.stamp(), "incompatible spaces "
-        << stamp() << " and " << uh.stamp()
-        << " in field[i_comp] = field");
-  std::copy (uh.begin_dof(), uh.end_dof(), begin_dof());
-  return *this;
-}
-#endif // TO_CLEAN
 // -------------------------------------------
 // 4.1.2. field_indirect
 // -------------------------------------------
@@ -515,54 +389,11 @@ template<class Expr, class Sfinae>
 inline
 field_indirect<T,M>& 
 field_indirect<T,M>::operator= (const Expr& expr) {
-#ifdef TO_CLEAN
-  // is it still a restriction ? check it...
-  check_macro (_V.valued_tag() == space_constant::scalar, 
-               "field[domain] = expression: non-scalar valued field not yet supported -- sorry");
-#endif // TO_CLEAN
   check_macro (stamp() == expr.stamp(), "field [domain] = field_expression : incompatible spaces "
                 << stamp() << " and " << expr.stamp());
-#ifdef TO_CLEAN
-  algo::copy_n (expr.begin_dof(), expr.ndof(), begin_dof());
-#endif // TO_CLEAN
   details::assign_with_operator (begin_dof(), end_dof(), expr.begin_dof(), details::assign_op());
   return *this;
 }
-#ifdef TO_CLEAN
-template<class T, class M>
-inline
-field_indirect<T,M>&
-field_indirect<T,M>::operator=  (const field_basic<T,M>& expr)
-{
-  check_macro (_V.valued_tag() == space_constant::scalar, "field[domain]: unsupported non-scalar field");
-  check_macro (stamp() == expr.stamp(), "field[domain] = field : incompatible spaces "
-		<< stamp() << " and " << expr.stamp());
-  algo::copy_n (expr.begin_dof(), expr.ndof(), begin_dof());
-  return *this;
-}
-template<class T, class M>
-inline
-field_indirect<T,M>&
-field_indirect<T,M>::operator=  (const field_indirect<T,M>& expr)
-{
-  check_macro (_V.valued_tag() == space_constant::scalar, "field[domain]: unsupported non-scalar field");
-  check_macro (stamp() == expr.stamp(), "field[domain] = field[domain]: incompatible spaces "
-		<< stamp() << " and " << expr.stamp());
-  algo::copy_n (expr.begin_dof(), expr.ndof(), begin_dof());
-  return *this;
-}
-template<class T, class M>
-inline
-field_indirect<T,M>&
-field_indirect<T,M>::operator=  (const field_indirect_const<T,M>& expr)
-{
-  check_macro (_V.valued_tag() == space_constant::scalar, "field[domain]: unsupported non-scalar field");
-  check_macro (stamp() == expr.stamp(), "field[domain] = field[domain]: incompatible spaces "
-		<< stamp() << " and " << expr.stamp());
-  algo::copy_n (expr.begin_dof(), expr.ndof(), begin_dof());
-  return *this;
-}
-#endif // TO_CLEAN
 // ---------------------------------------------------------------------------
 // 4.2. computed assignment
 // ---------------------------------------------------------------------------
