@@ -193,10 +193,6 @@ public:
     typedef field_expr_v2_nonlinear_node_unary<UnaryFunction, Expr> This;
     typedef typename details::generic_unary_traits<UnaryFunction>::template hint<typename Expr::value_type,Result>::argument_type
             A1;
-#ifdef TO_CLEAN
-    static const space_constant::valued_type argument_tag = space_constant::valued_tag_traits<A1>::value;
-    evaluate_switch <This, Result, A1, argument_tag> helper;
-#endif // TO_CLEAN
     evaluate_switch <This, Result, A1> helper;
     helper.evaluate (*this, K, value);
     return true;
@@ -370,9 +366,6 @@ public:
 
   template<class Result, class Arg1, class Arg2>
   void evaluate_internal2 (const geo_element& K, std::vector<Result>& value) const {
-#ifdef TO_CLEAN
-    _check<Result,Arg1,Arg2> ();
-#endif // TO_CLEAN
     std::vector<Arg1> tmp1_value;
     std::vector<Arg2> tmp2_value;
     _expr1.evaluate (K, tmp1_value);
