@@ -170,7 +170,7 @@ field_expr_v2_nonlinear_terminal_function_rep<normal_pseudo_function<T> >::evalu
 {
   base::evaluate_initialize (K);
   reference_element hat_K = K.variant();
-  value.resize (base::_piola_ops.size(hat_K));
+  value.resize (base::_piola_ops.pointset_size(hat_K));
   size_type q = 0;
   tensor_basic<T> DF;
   for (typename std::vector<result_type>::iterator
@@ -232,7 +232,7 @@ field_expr_v2_nonlinear_terminal_function_rep<h_local_pseudo_function<T> >::eval
   size_type K_map_d = K.dimension();
   tensor_basic<T> DF;
   reference_element hat_K = K.variant();
-  value.resize (base::_piola_ops.size(hat_K));
+  value.resize (base::_piola_ops.pointset_size(hat_K));
   if (K_map_d != 0) {
     size_type q = 0;
     for (typename std::vector<result_type>::iterator
@@ -315,7 +315,7 @@ field_expr_v2_nonlinear_terminal_function_rep<penalty_pseudo_function<T> >::eval
   size_type map_d = K.dimension();
   reference_element hat_K = K.variant();
   tensor_basic<T> DF;
-  size_type nq = base::_piola_ops.size(hat_K);
+  size_type nq = base::_piola_ops.pointset_size(hat_K);
   T meas_max_K = 0;
   for (size_type q = 0; q < nq; ++q) {
     jacobian_piola_transformation (base::_omega, base::_piola_ops, K, base::_dis_inod, q, DF);
@@ -338,7 +338,7 @@ field_expr_v2_nonlinear_terminal_function_rep<penalty_pseudo_function<T> >::eval
   reference_element hat_K = K.variant();
   size_type n_sides = L.n_subgeo (K.dimension());
   base::evaluate_initialize (K);
-  value.resize (base::_piola_ops.size(hat_K));
+  value.resize (base::_piola_ops.pointset_size(hat_K));
   for (size_type loc_idof = 0, loc_ndof = value.size(); loc_idof < loc_ndof; ++loc_idof) {
     value[loc_idof] = n_sides*meas_side_K/meas_K;
   }
@@ -518,7 +518,7 @@ field_expr_v2_nonlinear_terminal_field_rep<T,M>::evaluate (
     if (base::_have_dg_on_sides && K.dimension() == base::_omega.map_dimension()) {
       hat_K = base::_tilde_L;
     }
-    value.resize (base::_bops.size(hat_K));
+    value.resize (base::_bops.pointset_size(hat_K));
     size_type q = 0;
     for (typename std::vector<Result>::iterator
 	iter = value.begin(),
@@ -914,6 +914,7 @@ field_expr_v2_nonlinear_terminal_field_o_characteristic_rep<T,M>::field_expr_v2_
     _quad(),
     _bops(),
     _uq(),
+    _uq_K(),
     _start_q(0)
 {
 }
@@ -949,7 +950,7 @@ field_expr_v2_nonlinear_terminal_field_o_characteristic_rep<T,M>::initialize (
     // as in mesh adaptation loops
     _uh.dis_dof_update();
 
-    quadrature_option_type qopt = quad.get_options();
+    quadrature_option qopt = quad.get_options();
  
     // coq is stored in _X : it is independent of _uh ; depend only of _uh.space and qopt
     const characteristic_on_quadrature<T,M> coq = _X.get_pre_computed (_uh.get_space(), _X.get_displacement(), qopt);
@@ -984,19 +985,6 @@ field_expr_v2_nonlinear_terminal_field_o_characteristic_rep<T,M>::initialize (
     fatal_macro ("characteristic: not yet for interpolate");
     return true;
 }
-#ifdef TO_CLEAN
-template<class T, class M>
-template<class Result>
-void
-field_expr_v2_nonlinear_terminal_field_o_characteristic_rep<T,M>::_check () const
-{
-    check_macro (_is_initialized, "may be initialized");
-    space_constant::valued_type result_valued_tag = space_constant::valued_tag_traits<Result>::value;
-    check_macro (_uh.valued_tag() == result_valued_tag, "unexpected "<<_uh.valued()
-	<< "-valued field for " << space_constant::valued_name(result_valued_tag)
-	<< "-valued evaluator");
-}
-#endif // TO_CLEAN
 // general case:
 template<class T, class M, class Result>
 void
@@ -1103,66 +1091,10 @@ field_expr_v2_nonlinear_terminal_field_o_characteristic_rep<T,M>::evaluate (
     std::vector<Result>& value) const
 {
     reference_element hat_K = K.variant();
-    value.resize (_bops.size(hat_K));
+    value.resize (_bops.pointset_size(hat_K));
     set_value (*this, K, value);
     return true;
 }
-#ifdef TO_CLEAN
-// ----------------------------------------------------------------------------
-// instanciation in library (old)
-// ----------------------------------------------------------------------------
-#define _RHEOLEF_instanciation_base_seq_only(T) 			      \
-template class field_expr_v2_nonlinear_terminal_function_base_rep<T>; 		      \
-template class field_expr_v2_nonlinear_terminal_function_rep< normal_pseudo_function<T> >; \
-template class field_expr_v2_nonlinear_terminal_function_rep<h_local_pseudo_function<T> >; \
-template class field_expr_v2_nonlinear_terminal_function_rep<penalty_pseudo_function<T> >; \
-
-// extra when Result=tensor3, tensor4
-#define _RHEOLEF_instanciation_base_both_members_full(T,M,Result) 	\
-template bool field_expr_v2_nonlinear_terminal_field_rep<T,M>::evaluate<Result > ( 	\
-    		const geo_element&, std::vector<Result >&) const;	\
-template bool field_expr_v2_nonlinear_terminal_field_grad_rep<T,M>::evaluate<Result > ( \
-    		const geo_element&, std::vector<Result >&) const;	\
-template void field_expr_v2_nonlinear_terminal_field_rep<T,M>::evaluate_on_side<Result > ( 	\
-    		const geo_element& K, const side_information_type& sid, 	\
-		std::vector<Result>& value) const;			\
-template bool field_expr_v2_nonlinear_terminal_field_o_characteristic_rep<T,M>::evaluate<Result > ( 	\
-    		const geo_element&, std::vector<Result >&) const;	\
-template bool field_expr_v2_nonlinear_terminal_field_curl_rep<T,M>::evaluate<Result > ( \
-    		const geo_element&, std::vector<Result >&) const;	\
-
-#define _RHEOLEF_instanciation_base_both_members_mini(T,M,Result) 	\
-	_RHEOLEF_instanciation_base_both_members_full(T,M,Result) 	\
-template bool field_expr_v2_nonlinear_terminal_field_dg_rep<T,M>::evaluate<Result > ( \
-    		const geo_element&, std::vector<Result >&) const;	\
-
-#define _RHEOLEF_instanciation_base_both(T,M) 				\
-template class field_expr_v2_nonlinear_terminal_field_rep<T,M>;			\
-template class field_expr_v2_nonlinear_terminal_field_grad_rep<T,M>;			\
-template class field_expr_v2_nonlinear_terminal_field_div_rep<T,M>;			\
-template class field_expr_v2_nonlinear_terminal_field_curl_rep<T,M>;			\
-template class field_expr_v2_nonlinear_terminal_field_dg_rep<T,M>;			\
-template class field_expr_v2_nonlinear_terminal_field_o_characteristic_rep<T,M>;	\
-        _RHEOLEF_instanciation_base_both_members_mini(T,M,T) 		\
-        _RHEOLEF_instanciation_base_both_members_mini(T,M,point_basic<T>) 	\
-        _RHEOLEF_instanciation_base_both_members_mini(T,M,tensor_basic<T>) 	\
-        _RHEOLEF_instanciation_base_both_members_full(T,M,tensor3_basic<T>) 	\
-        _RHEOLEF_instanciation_base_both_members_full(T,M,tensor4_basic<T>) 	\
-
-#define _RHEOLEF_instanciation_seq(T)	 				\
-        _RHEOLEF_instanciation_base_seq_only(T) 			\
-        _RHEOLEF_instanciation_base_both(T,sequential)
-
-#define _RHEOLEF_instanciation_dis(T) 					\
-        _RHEOLEF_instanciation_base_both(T,distributed)
-
-_RHEOLEF_instanciation_seq(Float)
-#ifdef _RHEOLEF_HAVE_MPI
-_RHEOLEF_instanciation_dis(Float)
-#endif // _RHEOLEF_HAVE_MPI
-
-#endif // TO_CLEAN
-
 // ----------------------------------------------------------------------------
 // instanciation in library (v2)
 // ----------------------------------------------------------------------------
