@@ -153,7 +153,7 @@ public:
   bool evaluate (const geo_element& K, std::vector<result_type>& value) const {
     base::evaluate_initialize (K);
     reference_element hat_K = K.variant();
-    value.resize (base::_piola_ops.size(hat_K));
+    value.resize (base::_piola_ops.pointset_size(hat_K));
     size_type q = 0;
     for (typename std::vector<result_type>::iterator
 	  iter = value.begin(),
@@ -208,12 +208,6 @@ public:
   explicit field_expr_v2_nonlinear_terminal_function (const Constant& c) 
     : base(new_macro(rep(f_constant<point_basic<float_type>,result_type>(c)))) {}
 
-#ifdef TO_CLEAN
-  template <class FieldFunctor, class Result>
-  explicit field_expr_v2_nonlinear_terminal_function (const field_functor<FieldFunctor,Result>& f)
-    : base(new_macro(rep(f.get_ref()))) {}
-#endif // TO_CLEAN
-
 // accessors:
 
   space_constant::valued_type valued_tag() const { return base::data().valued_tag(); }
@@ -500,12 +494,6 @@ public:
 
 // alocators:
 
-#ifdef TO_CLEAN
-  field_expr_v2_nonlinear_terminal_field_base_rep (const field_basic<T,M>& uh)
-    : _uh(uh),   _omega(), _bops(), _use_dom2bgd(false), _use_bgd2dom(false), 
-      _have_dg_on_sides(false), _tilde_L(), _dis_idof() {}
-#endif // TO_CLEAN
-
   template <class Expr,
             class Sfinae = typename std::enable_if<details::is_field_expr_v2_linear_arg<Expr>::value>::type>
   explicit field_expr_v2_nonlinear_terminal_field_base_rep (const Expr& expr) 
@@ -552,11 +540,6 @@ public:
 
 // alocators:
 
-#ifdef TO_CLEAN
-  field_expr_v2_nonlinear_terminal_field_rep (const field_basic<T,M>& uh) 
-   : base(uh) {}
-#endif // TO_CLEAN
-
   template <class Expr,
             class Sfinae = typename std::enable_if<details::is_field_expr_v2_linear_arg<Expr>::value>::type>
   explicit field_expr_v2_nonlinear_terminal_field_rep (const Expr& expr) 
