@@ -60,8 +60,7 @@ put_edge (std::ostream& gdat, const geo_element& E, const geo_basic<T,sequential
   uh.get_space().dis_idof (E, dis_idof1);
   std::vector<size_type> dis_inod;
   omega.dis_inod (E, dis_inod);
-  std::vector<point_basic<T> > hat_xi;
-  uh.get_space().get_numbering().get_basis().hat_node (E.variant(), hat_xi);
+  const std::vector<point_basic<T> >& hat_xi = uh.get_space().get_numbering().get_basis().hat_node (E.variant());
   for (size_type i = 0; i <= my_order; i++) {
     size_type iloc = reference_element_e::ilat2loc_inod (my_order, ilat(i));
     point_basic<T> xi = piola_transformation (omega, geo_on_pointset,   E.variant(), dis_inod, iloc);
@@ -69,7 +68,10 @@ put_edge (std::ostream& gdat, const geo_element& E, const geo_basic<T,sequential
     xi.put (gdat, dim); gdat << " " << ui << endl;
     bbox.update (xi, ui);
   }
-  gdat << endl << endl;
+  gdat << endl;
+  gdat << endl;
+#ifdef TO_CLEAN
+#endif // TO_CLEAN
 }
 template<class T>
 static
@@ -89,7 +91,7 @@ put_triangle (std::ostream& gdat, const geo_element& F, const geo_basic<T,sequen
   std::vector<size_type> dis_inod;
   omega.dis_inod (F, dis_inod);
   uh.get_space().dis_idof (F, dis_idof1);
-  size_type nloc = geo_on_pointset.size(F);
+  size_type nloc = geo_on_pointset.pointset_size(F);
   std::vector<point_basic<T> > xdof (nloc);
   std::vector<T>               udof (nloc);
   for (size_type iloc = 0; iloc < nloc; iloc++) {
@@ -260,12 +262,11 @@ visu_gnuplot_scalar (odiststream& ods, const field_basic<T,sequential>& uh)
     plot << "set terminal " << terminal    << endl
          << "set output \"" << outfile_fmt << "\"" << endl;
   }
-  if (!black_and_white && map_dim == dim) {
-    plot << "set noborder" << endl;
-  }
+  plot << "umin = " << bbox.umin << endl
+       << "umax = " << bbox.umax << endl
+       << "n_isovalue  = " << n_isovalue << endl
+       << "uincr = (umax-umin)/n_isovalue" << endl;
   if (dim == 2) {
-    plot << "umin = " << bbox.umin << endl
-         << "umax = " << bbox.umax << endl;
     if (bbox.xmin[0] >= bbox.xmax[0]) plot << "#";
     plot << "set xrange [" << bbox.xmin[0] << ":" << bbox.xmax[0] << "]" << endl;
     if (bbox.xmin[1] >= bbox.xmax[1]) plot << "#";
@@ -284,30 +285,36 @@ visu_gnuplot_scalar (odiststream& ods, const field_basic<T,sequential>& uh)
     } else {
       plot << "set view map" << endl;
     }
-    if (color || gray) {
-      plot << "set pm3d interpolate 10,10 corners2color mean" << endl;
-      if (gray) {
-        plot << "set palette gray" << endl;
-      } else {
-        plot << "set palette rgbformulae 33,13,-4" << endl;
-      }
-    } else { // black-and-white
+    if (map_dim == 2) {
+      plot << "unset surface" << endl
+           << "set contour base" << endl;
       if (values.size() != 0) {
         plot << "set cntrparam levels discrete ";
         for (size_t i = 0, n = values.size(); i < n; i++) {
           plot << values[i];
-	  if (i != n-1) plot << ", ";
+          if (i+1 != n) plot << ", ";
         }
         plot << endl;
       } else {
-        plot << "set cntrparam levels incremental umin,(umax-umin)/10.0,umax"<< endl;
+        plot << "eps = (umax-umin)*1e-4"<< endl;
+        plot << "uincr_eps = (umax-umin-2*eps)/n_isovalue"<< endl;
+        plot << "set cntrparam levels incremental umin+eps,uincr_eps,umax-eps"<< endl;
       }
-      plot << "unset surface" << endl
-           << "set contour base" << endl
-           << "set nokey" << endl
-           << "set palette rgbformulae 0,0,0" << endl
-           << "unset colorbox" << endl;
     }
+    if (black_and_white) {
+      plot << "set cbtics out scale 0.5" << endl;
+    }
+    plot << "set cbtics uincr" << endl
+         << "set cbrange [umin:umax]" << endl;
+    if (gray) {
+      plot << "set palette gray" << endl;
+    } else if (color) {
+      plot << "set palette rgbformulae 33,13,-4" << endl;
+    } else { // bw
+      plot << "set palette rgbformulae 0,0,0" << endl;
+    }
+    plot << "set palette maxcolors n_isovalue+1" << endl
+         << "set nokey" << endl;
   } else if (dim == 3 && map_dim == 2) {
     // field defined on a 3D surface
     point_basic<T> dx = 0.1*(omega.xmax() - omega.xmin());
@@ -318,14 +325,19 @@ visu_gnuplot_scalar (odiststream& ods, const field_basic<T,sequential>& uh)
     if (omega.dimension() == 3) dx[2] = max(dx[2],dx_max);
     point_basic<T> xmin = omega.xmin() - dx;
     point_basic<T> xmax = omega.xmax() + dx;
+    // TODO: visu contours discrets comme en 2d classique
     plot << "set xrange [" << xmin[0] << ":" << xmax[0] << "]" << endl
          << "set yrange [" << xmin[1] << ":" << xmax[1] << "]" << endl
          << "set zrange [" << xmin[2] << ":" << xmax[2] << "]" << endl
          << "set xyplane at " << xmin[2] << endl
          << "set view equal xyz # equal scales" << endl
          << "set view 70,120" << endl
-         << "set pm3d interpolate 5,5 corners2color mean" << endl
-         << "set palette rgbformulae 33,13,-4" << endl;
+         << "n_isovalue  = " << n_isovalue << endl
+	 << "n_subdivide = 40 " << endl
+         << "uincr = (umax-umin)/n_isovalue" << endl
+         << "set cbtics uincr" << endl
+         << "set pm3d interpolate n_subdivide,n_subdivide corners2color mean" << endl
+         << "set palette rgbformulae 33,13,-4 maxcolors n_isovalue" << endl;
     if (format != "") {
       plot << "set noxlabel" << endl
            << "set noylabel" << endl
@@ -337,8 +349,11 @@ visu_gnuplot_scalar (odiststream& ods, const field_basic<T,sequential>& uh)
     }
   }
   if (dim == 1) {
-    plot << "plot \"" << gdatname << "\" notitle with lines";
-    if (black_and_white) {
+    if (color) {
+      plot << "set colors classic" << endl;
+    }
+    plot << "plot \"" << gdatname << "\" notitle with lines lw 2";
+    if (gray || black_and_white) {
       plot << " lc 0" << endl;
     }
     plot << endl;
@@ -350,13 +365,13 @@ visu_gnuplot_scalar (odiststream& ods, const field_basic<T,sequential>& uh)
     } 
     plot << " \"" << gdatname << "\" notitle";
     if (map_dim == 2) {
-      if (!black_and_white && fill) {
-        plot << " with pm3d" << endl;
+      if (black_and_white) {
+        plot << " with lines palette lw 2" << endl;
       } else {
         plot << " with lines palette" << endl;
       }
     } else { // a 2d line
-      plot << " with lines palette lw 2" << endl;
+        plot << " with lines palette lw 2" << endl;
     }
   }
   //
