@@ -107,7 +107,7 @@ field_basic<T,M>::assembly_internal (
     const geo_basic<T,M>&         band,
     const band_basic<T,M>&        gh,
     const Expr&                   expr,
-    const quadrature_option_type& qopt,
+    const quadrature_option& qopt,
     bool                          is_on_band)
 {
   // ------------------------------------
@@ -123,7 +123,7 @@ field_basic<T,M>::assembly_internal (
   resize (Xh, 0);
 
   quadrature<T> quad;
-  if (qopt.get_order() != std::numeric_limits<quadrature_option_type::size_type>::max()) {
+  if (qopt.get_order() != std::numeric_limits<quadrature_option::size_type>::max()) {
     quad.set_order (qopt.get_order());
   } else {
     size_type k = Xh.degree();
@@ -220,7 +220,7 @@ void
 field_basic<T,M>::assembly (
     const geo_basic<T,M>&         dom,
     const Expr&                   expr,
-    const quadrature_option_type& qopt)
+    const quadrature_option& qopt)
 {
   assembly_internal (dom, dom, band_basic<T,M>(), expr, qopt, false);
 }
@@ -231,7 +231,7 @@ void
 field_basic<T,M>::assembly (
     const band_basic<T,M>&        gh,
     const Expr&                   expr,
-    const quadrature_option_type& qopt)
+    const quadrature_option& qopt)
 {
   assembly_internal (gh.level_set(), gh.band(), gh, expr, qopt, true);
 }
