@@ -35,7 +35,7 @@ form_basic<T,M>::form_basic (
     const space_type& X, 
     const space_type& Y,
     const std::string& name,
-    const quadrature_option_type& qopt)
+    const quadrature_option& qopt)
   : _X(X), 
     _Y(Y), 
     _uu(),
@@ -51,7 +51,7 @@ form_basic<T,M>::form_basic (
     const space_type& Y,
     const std::string& name,
     const field_basic<T,M>& wh,
-    const quadrature_option_type& qopt)
+    const quadrature_option& qopt)
   : _X(X), 
     _Y(Y), 
     _uu(),
@@ -67,7 +67,7 @@ form_basic<T,M>::form_basic (
     const space_type& Y,
     const std::string& name,
     const geo_basic<T,M>& gamma,
-    const quadrature_option_type& qopt)
+    const quadrature_option& qopt)
   : _X(X), 
     _Y(Y), 
     _uu(),
@@ -90,7 +90,7 @@ form_basic<T,M>::form_basic (
     const std::string& name,
     const geo_basic<T,M>& gamma,
     const field_basic<T,M>& wh,
-    const quadrature_option_type& qopt)
+    const quadrature_option& qopt)
   : _X(X), 
     _Y(Y), 
     _uu(),
