@@ -24,7 +24,7 @@
 #include "rheolef/csr.h"
 #include "rheolef/field.h"
 #include "rheolef/quadrature.h"
-#include "rheolef/form_option_type.h"
+#include "rheolef/integrate_option.h"
 namespace rheolef { 
 
 // these classes are used for allocator from the std::initializer_list
@@ -85,7 +85,7 @@ EXAMPLE:
 
 ALGEBRA:
   Forms, as matrices (see @ref{csr class}), support linear algebra:
-  Adding or substracting two forms writes @code{a+b} and @code{a-b}, respectively,
+  Adding or subtracting two forms writes @code{a+b} and @code{a-b}, respectively,
   and multiplying a form by a field @code{uh} writes @code{a*uh}.
   Thus, any linear combination of forms is available.
 
@@ -189,45 +189,45 @@ public:
         const geo_basic<T,M>&         band,
         const band_basic<T,M>&        gh,
         const Expr&                   expr,
-        const form_option_type&       fopt,
+        const integrate_option&       fopt,
         bool                          is_on_band);
     template <class Expr>
     void assembly (
         const geo_basic<T,M>&         domain,
         const Expr&                   expr,
-        const form_option_type&       fopt);
+        const integrate_option&       fopt);
     template <class Expr>
     void assembly (
         const band_basic<T,M>&        gh,
         const Expr&                   expr,
-        const form_option_type&       fopt);
+        const integrate_option&       fopt);
 
     // backward compat: named forms
     form_basic (const space_type& X, const space_type& Y,
 	const std::string& name = "",
-	const quadrature_option_type& qopt = quadrature_option_type());
+	const quadrature_option& qopt = quadrature_option());
 
     form_basic (const space_type& X, const space_type& Y,
 	const std::string& name,
 	const field_basic<T,M>& weight, 
-	const quadrature_option_type& qopt = quadrature_option_type());
+	const quadrature_option& qopt = quadrature_option());
 
     template<class Function>
     form_basic (const space_type& X, const space_type& Y,
 	const std::string& name,
 	Function weight,
-	const quadrature_option_type& qopt = quadrature_option_type());
+	const quadrature_option& qopt = quadrature_option());
 
     form_basic (const space_type& X, const space_type& Y,
 	const std::string& name,
 	const geo_basic<T,M>& gamma,
-	const quadrature_option_type& qopt = quadrature_option_type());
+	const quadrature_option& qopt = quadrature_option());
 
     form_basic (const space_type& X, const space_type& Y,
 	const std::string& name,
 	const geo_basic<T,M>& gamma,
 	const field_basic<T,M>& weight,
-	const quadrature_option_type& qopt = quadrature_option_type());
+	const quadrature_option& qopt = quadrature_option());
 
     template<class Function>
     form_basic (
@@ -236,7 +236,7 @@ public:
         const std::string& name,
         const geo_basic<T,M>& gamma,
         Function weight,
-	const quadrature_option_type& qopt = quadrature_option_type());
+	const quadrature_option& qopt = quadrature_option());
 protected: 
     // backward compat: named forms (cont.)
     template<class WeightFunction>
@@ -244,7 +244,7 @@ protected:
                    const std::string&      name,
                    bool                    has_weight,
                    WeightFunction          weight,
-                   const quadrature_option_type& qopt);
+                   const quadrature_option& qopt);
     template<class WeightFunction>
     void form_init_on_domain (
     		   const std::string&      name,
@@ -252,7 +252,7 @@ protected:
                    bool                    has_weight,
     		   WeightFunction          weight,
     		   const geo_basic<T,M>&   w_omega, // the domain where the fct weight is defined
-    		   const quadrature_option_type& qopt);
+    		   const quadrature_option& qopt);
 };
 template<class T, class M> form_basic<T,M> trans (const form_basic<T,M>& a);
 template<class T, class M> field_basic<T,M> diag (const form_basic<T,M>& a);
