@@ -88,7 +88,7 @@ form_basic<T,M>::assembly_internal (
    const geo_basic<T,M>&         band,
    const band_basic<T,M>&        gh,
    const Expr&                   expr,
-   const form_option_type&       fopt,
+   const integrate_option&       fopt,
    bool                          is_on_band)
 {
   // ----------------------------------------
@@ -105,7 +105,7 @@ form_basic<T,M>::assembly_internal (
 
   quadrature<T> quad;
   size_type n_derivative = expr.n_derivative();
-  if (fopt.get_order() != std::numeric_limits<quadrature_option_type::size_type>::max()) {
+  if (fopt.get_order() != std::numeric_limits<quadrature_option::size_type>::max()) {
     quad.set_order (fopt.get_order());
   } else {
     size_type k1 = _X.degree();
@@ -193,9 +193,6 @@ form_basic<T,M>::assembly_internal (
         ak (loc_idof,loc_jdof) += value (loc_idof,loc_jdof)*wq;
       }}
     }
-#ifdef TO_CLEAN
-    std::cerr << "ak=" << ak;
-#endif // TO_CLEAN
     // ----------------------------------------
     // 2) optional local post-traitement
     // ----------------------------------------
@@ -285,7 +282,7 @@ void
 form_basic<T,M>::assembly (
     const geo_basic<T,M>&         dom,
     const Expr&                   expr,
-    const form_option_type&       fopt)
+    const integrate_option&       fopt)
 {
   assembly_internal (dom, dom, band_basic<T,M>(), expr, fopt, false);
 }
@@ -296,7 +293,7 @@ void
 form_basic<T,M>::assembly (
     const band_basic<T,M>&        gh,
     const Expr&                   expr,
-    const form_option_type&       fopt)
+    const integrate_option&       fopt)
 {
   assembly_internal (gh.level_set(), gh.band(), gh, expr, fopt, true);
 }
