@@ -40,7 +40,7 @@ form_named_init (
     const std::string&      name,
     bool                    has_weight,
     WeightFunction          w,
-    const quadrature_option_type& qopt)
+    const quadrature_option& qopt)
 {
   // backward compatibility code:
   // branch to variational formulation routines:
@@ -70,7 +70,7 @@ form_named_init (
   } else if (name == "inv_mass") {
   // --------------------------------
     check_macro (!has_weight, "unsupported weighted "<<name<<" form (HINT: use integrate())");
-    form_option_type fopt (qopt);
+    integrate_option fopt (qopt);
     fopt.invert = true;
     switch (a.get_first_space().valued_tag()) {
       case space_constant::scalar: a.assembly (dom, u*v,   fopt); return true;
@@ -82,7 +82,7 @@ form_named_init (
   } else if (name == "lumped_mass") {
   // --------------------------------
     check_macro (!has_weight, "unsupported weighted "<<name<<" form (HINT: use integrate())");
-    form_option_type fopt (qopt);
+    integrate_option fopt (qopt);
     fopt.lump = true;
     switch (a.get_first_space().valued_tag()) {
       case space_constant::scalar: a.assembly (dom, u*v,   fopt); return true;
@@ -153,7 +153,7 @@ form_basic<T,M>::form_init (
     const std::string&      name,
     bool                    has_weight,
     WeightFunction          w,
-    const quadrature_option_type& qopt)
+    const quadrature_option& qopt)
 {
     if (name == "" || name == "nul" || name == "null") {
       // empty name => nul form, but with declared csr matrix sizes
@@ -190,7 +190,7 @@ form_basic<T,M>::form_basic (
   const space_type& Y,
   const std::string& name,
   Function weight,
-  const quadrature_option_type& qopt)
+  const quadrature_option& qopt)
   : _X(X),
     _Y(Y),
     _uu(),
@@ -212,7 +212,7 @@ form_basic<T,M>::form_init_on_domain (
     bool                          has_weight,
     WeightFunction                w,
     const geo_basic<T,M>&         w_omega,
-    const quadrature_option_type& qopt)
+    const quadrature_option& qopt)
 {
     const geo_basic<T,M>& omega = _X.get_geo().get_background_geo();
 
@@ -228,7 +228,7 @@ form_basic<T,M>::form_basic (
     const std::string& name,
     const geo_basic<T,M>& gamma,
     Function weight,
-    const quadrature_option_type& qopt)
+    const quadrature_option& qopt)
   : _X(X), 
     _Y(Y), 
     _uu(),
