@@ -26,6 +26,7 @@
 #include "geo_header.h"
 
 namespace rheolef {
+using namespace std;
 
 // =========================================================================
 // cstors
@@ -134,7 +135,19 @@ geo_rep<T,distributed>::clone() const
 }
 #endif // _RHEOLEF_HAVE_MPI
 // =========================================================================
-// geo_load(name): handle name as "square[boundary]" or "square.boundary"
+// global table of preloaded geos
+// =========================================================================
+template<class T, class M>
+typename geo_base_rep<T,M>::loaded_map_t geo_base_rep<T,M>::_loaded_map;
+
+template<class T, class M>
+typename geo_base_rep<T,M>::loaded_map_t&
+geo_base_rep<T,M>::loaded_map() 
+{
+  return _loaded_map;
+}
+// =========================================================================
+// geo_load(name): handle name as "square[boundary]"
 // =========================================================================
 // geo(name) { base::operaor=(geo_load(name)); }
 static
@@ -142,14 +155,12 @@ bool
 is_domain (const std::string& name, std::string& bgd_name, std::string& dom_name)
 {
   size_t n = name.length();
-  trace_macro ("is_domain: n=" << n);
   if (n <= 2 || name[n-1] != ']') return false;
   size_t i = n-2;
   for (; i > 0 && name[i] != '[' && name[i] != '/'; i--) ;
   // ../../nfem/ptst/triangle_p10-v2 => name[i] == '/' : stop before "../../"
   if (i == 0 || i == n-2 || name[i] == '/') return false;
   // name[i] == '[' as "square[right]"
-  trace_macro ("is_domain: i=" << i);
   bgd_name = name.substr(0,i); // range [0:i[
   dom_name = name.substr(i+1); // range [i+1:end[
   dom_name = dom_name.substr(0,dom_name.length()-1); // range [0:end-1[ : skip ']'
@@ -157,92 +168,244 @@ is_domain (const std::string& name, std::string& bgd_name, std::string& dom_name
 }
 template<class T, class M>
 geo_basic<T,M>
-geo_load (const std::string& name)
+geo_load (const std::string& filename)
 {
-  trace_macro ("geo_load: " << name);
-  std::string root_name = delete_suffix (delete_suffix(name, "gz"), "geo");
+  typedef typename geo_basic<T,M>::base base;
+  std::string root_name = delete_suffix (delete_suffix(filename, "gz"), "geo");
   std::string bgd_name, dom_name;
   if (is_domain(root_name,bgd_name,dom_name)) {
-    trace_macro ("bgd_name="<<bgd_name<<", dom_name="<<dom_name);
     geo_basic<T,M> omega (bgd_name);
     return omega[dom_name];
   }
-  // allocate a new geo_rep<mpi> object ; TODO geo_rep(name,comm)
+  std::string name = get_basename (root_name);
+
+  // check for previously loaded geo:
+  auto iter = geo_base_rep<T,M>::loaded_map().find (name);
+  if (iter != geo_base_rep<T,M>::loaded_map().end()) {
+    // geo(name) was already loaded: reuse it from table
+#ifdef DEBUG_LOADED_TABLE_TRACE
+    dis_warning_macro ("geo::geo_load("<<name<<"): REUSE");
+#endif // DEBUG_LOADED_TABLE_TRACE
+    geo_basic<T,M> omega;
+    omega.base::operator= (base((*iter).second,typename base::internal()));
+    return omega;
+  }
+  // allocate a new geo_rep<mpi> and load it from file
   geo_rep<T,M>* ptr = new_macro((geo_rep<T,M>));
-  ptr->load (name, communicator());
+  ptr->load (filename, communicator());
   geo_basic<T,M> omega;
   omega.geo_basic<T,M>::base::operator= (ptr);
+
+  // store the new created geo in the loaded map: 
+#ifdef DEBUG_LOADED_TABLE_TRACE
+  dis_warning_macro ("geo::geo_load("<<name<<"): NEW");
+#endif // DEBUG_LOADED_TABLE_TRACE
+  geo_base_rep<T,M>::loaded_map().insert (std::make_pair(name, omega.base::get_count())); 
+
   return omega;
 }
+// ==============================================================================
+// compact: convert a geo_domain_indirect to a geo_domain
+// by compacting elements and node numbering to refer only to those used 
+// by the domain: can then be used to solve a pb by FEM on this domain
+// ==============================================================================
+template <class T, class M>
+geo_basic<T,M>
+compact (const geo_basic<T,M>& gamma)
+{
+    if (gamma.variant() != geo_abstract_base_rep<T>::geo_domain_indirect) {
+        return gamma;
+    }
+    /* allocate a new geo_rep object */
+    const geo_domain_indirect_rep<T,M>* dom_ptr
+     = dynamic_cast<const geo_domain_indirect_rep<T,M>*>(gamma.operator->());
+    geo_domain_rep<T,M>* geo_ptr = new_macro((geo_domain_rep<T,M>)(*dom_ptr));
+    geo_basic<T,M> new_gamma;
+    new_gamma.geo_basic<T,M>::base::operator= (geo_ptr);
+    return new_gamma;
+}
+// ==============================================================================
+// geo interface for non-const members that are specific to geo_rep
+// - check that pointer to geo_abstract_rep points to a geo_rep
+// - as non-const, manage also entries in the table
+// ==============================================================================
+
+#define _RHEOLEF_save(M)	                                              	\
+template <class T>								\
+void										\
+geo_basic<T,M>::save (std::string filename) const				\
+{										\
+  if (filename == "") filename = name();					\
+  odiststream out (filename, "geo");						\
+  put (out);									\
+}
+#define _RHEOLEF_set_name(M)		                                    	\
+template <class T>								\
+void										\
+geo_basic<T,M>::set_name (std::string new_name)					\
+{										\
+  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
+  check_macro (ptr != 0, "cannot set_name on geo_domains");			\
+  ptr->set_name(new_name);							\
+  geo_base_rep<T,M>::loaded_map().insert (make_pair(name(), base::get_count()));\
+}
+#define _RHEOLEF_set_serial_number(M)	                                    	\
+template <class T>								\
+void										\
+geo_basic<T,M>::set_serial_number (size_type i)					\
+{										\
+  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
+  check_macro (ptr != 0, "cannot set_serial_number on geo_domains");		\
+  ptr->set_serial_number(i);							\
+  geo_base_rep<T,M>::loaded_map().insert (make_pair(name(), base::get_count()));\
+}
+#define _RHEOLEF_reset_order(M)                                              	\
+template <class T>								\
+void										\
+geo_basic<T,M>::reset_order (size_type order)					\
+{										\
+  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
+  check_macro (ptr != 0, "cannot reset_order on geo_domains");			\
+  ptr->reset_order(order);							\
+}
+#define _RHEOLEF_set_nodes(M)                                              	\
+template <class T>								\
+void										\
+geo_basic<T,M>::set_nodes (const disarray<node_type,M>& x)			\
+{										\
+  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
+  check_macro (ptr != 0, "cannot set_nodes on geo_domains");			\
+  ptr->set_nodes(x);								\
+}
+#define _RHEOLEF_set_coordinate_system(M)                                    	\
+template <class T>								\
+void										\
+geo_basic<T,M>::set_coordinate_system (coordinate_type sys_coord)		\
+{										\
+  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
+  check_macro (ptr != 0, "cannot set_coordinate_system on geo_domains");	\
+  ptr->set_coordinate_system(sys_coord);					\
+}
+#define _RHEOLEF_set_dimension(M)	                                    	\
+template <class T>								\
+void										\
+geo_basic<T,M>::set_dimension (size_type dim)					\
+{										\
+  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
+  check_macro (ptr != 0, "cannot set_dimension on geo_domains");		\
+  ptr->set_dimension(dim);							\
+}
+#define _RHEOLEF_build_by_subdividing(M)		                        \
+template <class T>								\
+void										\
+geo_basic<T,M>::build_by_subdividing (						\
+  const geo_basic<T,M>& omega, 							\
+  size_type k)									\
+{										\
+  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
+  check_macro (ptr != 0, "cannot build_by_subdividing on geo_domains");		\
+  ptr->build_by_subdividing (omega, k);						\
+}
+#define _RHEOLEF_build_from_data(M)		                                \
+template <class T>								\
+void										\
+geo_basic<T,M>::build_from_data (						\
+  const geo_header&               hdr,						\
+  const disarray<node_type, M>&   node,						\
+        std::array<disarray<geo_element_auto<heap_allocator<size_type> >,M, heap_allocator<size_type> >, reference_element::max_variant>& tmp_geo_element, \
+  bool do_upgrade)								\
+{										\
+  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
+  check_macro (ptr != 0, "cannot build_from_data on geo_domains");		\
+  ptr->build_from_data (hdr, node, tmp_geo_element, do_upgrade);		\
+}
+
+_RHEOLEF_save(sequential)
+_RHEOLEF_set_name(sequential)
+_RHEOLEF_set_serial_number(sequential)
+_RHEOLEF_reset_order(sequential)
+_RHEOLEF_set_nodes(sequential)
+_RHEOLEF_set_coordinate_system(sequential)
+_RHEOLEF_set_dimension(sequential)
+_RHEOLEF_build_by_subdividing(sequential)
+_RHEOLEF_build_from_data(sequential)
+#ifdef _RHEOLEF_HAVE_MPI
+_RHEOLEF_save(distributed)
+_RHEOLEF_set_name(distributed)
+_RHEOLEF_set_serial_number(distributed)
+_RHEOLEF_reset_order(distributed)
+_RHEOLEF_set_nodes(distributed)
+_RHEOLEF_set_coordinate_system(distributed)
+_RHEOLEF_set_dimension(distributed)
+_RHEOLEF_build_by_subdividing(distributed)
+#ifdef TODO
+_RHEOLEF_build_from_data(distributed)
+#endif // TODO
+#endif // _RHEOLEF_HAVE_MPI
+#undef _RHEOLEF_set_nodes
+#undef _RHEOLEF_reset_order
+#undef _RHEOLEF_set_coordinate_system
+#undef _RHEOLEF_set_dimension
+#undef _RHEOLEF_set_name
+#undef _RHEOLEF_build_from_data
+#undef _RHEOLEF_build_by_subdividing
+// ----------------------------------------------------------------------------
+// set order: resize node disarray ; internal node are not computed
+// since they depend on the curved boundary information (cad data)
+// that is not aivailable here
+// ----------------------------------------------------------------------------
+#define _RHEOLEF_reset_order(M)						\
+template <class T>							\
+void									\
+geo_rep<T,M>::reset_order (size_type new_order)				\
+{									\
+  if (new_order == base::_numbering.degree()) return;			\
+  base::_numbering.set_degree (new_order);				\
+  size_type dis_nnod = base::_numbering.dis_ndof (base::_gs, base::_map_dimension); \
+  size_type     nnod = base::_numbering.ndof     (base::_gs, base::_map_dimension); \
+  base::_gs.node_ownership = distributor (nnod, base::comm(), nnod);	\
+  disarray<point_basic<T>, M> new_node (base::_gs.node_ownership);		\
+  for (size_type iv = 0, nv = base::_gs.ownership_by_dimension[0].size(); iv < nv; iv++) { \
+    new_node [iv] = base::_node [iv];					\
+  }									\
+  base::_node = new_node;						\
+  build_external_entities ();						\
+}
+_RHEOLEF_reset_order(sequential)
+#ifdef _RHEOLEF_HAVE_MPI
+_RHEOLEF_reset_order(distributed)
+#endif // _RHEOLEF_HAVE_MPI
+#undef _RHEOLEF_reset_order
 // =========================================================================
-// utility: vertex ownership follows node ownership, but dis_numbering differ
-// for high order > 1 meshes. This function converts numbering.
+// geo_base_rep destructor
 // =========================================================================
 template <class T, class M>
-typename geo_base_rep<T,M>::size_type
-geo_base_rep<T,M>::dis_inod2dis_iv (size_type dis_inod) const
+geo_base_rep<T,M>::~geo_base_rep()
 {
-  if (is_sequential<M>::value || order() == 1) return dis_inod;
-  distributor vertex_ownership = geo_element_ownership(0);
-  distributor   node_ownership = _node.ownership();
-  size_type iproc          =   node_ownership.find_owner(dis_inod);
-  size_type first_dis_inod =   node_ownership.first_index(iproc);
-  size_type first_dis_iv   = vertex_ownership.first_index(iproc);
-  size_type   inod = dis_inod - first_dis_inod;
-  size_type     iv = inod;
-  size_type dis_iv = first_dis_iv + iv;
-  return dis_iv;
-}
-template <class T, class M>
-typename geo_base_rep<T,M>::size_type
-geo_base_rep<T,M>::dis_iv2dis_inod (size_type dis_iv) const
-{
-  if (is_sequential<M>::value || order() == 1) return dis_iv;
-  distributor vertex_ownership = _gs.ownership_by_variant [reference_element::p];
-  distributor   node_ownership = _gs.node_ownership;
-  size_type iproc          = vertex_ownership.find_owner(dis_iv);
-  size_type first_dis_iv   = vertex_ownership.first_index(iproc);
-  size_type first_dis_inod =   node_ownership.first_index(iproc);
-  size_type       iv = dis_iv - first_dis_iv;
-  size_type     inod = iv;
-  size_type dis_inod = first_dis_inod + inod;
-  return dis_inod;
-}
-// --------------------------------------------------------------------------
-// accessors to distributed data
-// --------------------------------------------------------------------------
-template <class T, class M>
-typename geo_base_rep<T,M>::const_reference  
-geo_base_rep<T,M>::dis_get_geo_element (size_type dim, size_type dis_ige) const
-{
-  if (is_sequential<M>::value) return get_geo_element (dim, dis_ige);
-  if (_gs.ownership_by_dimension[dim].is_owned (dis_ige)) {
-    size_type first_dis_ige = _gs.ownership_by_dimension[dim].first_index();
-    size_type ige = dis_ige - first_dis_ige;
-    return get_geo_element (dim, ige);
+  size_t n_erased = geo_base_rep<T,M>::loaded_map().erase (name());
+  if (_name == "*nogeo*" || _name == "unnamed") {
+    return;
   }
-  // element is owned by another proc ; get its variant and then its index-variant igev
-  size_type variant  = _gs.dis_ige2variant  (dim, dis_ige);
-  size_type dis_igev = _gs.dis_ige2dis_igev (dim, variant, dis_ige);
-  typename geo_base_rep<T,M>::const_reference res = _geo_element [variant].dis_at (dis_igev);
-  return res;
+#ifdef DEBUG_LOADED_TABLE_TRACE
+  if (n_erased != 1) { 
+    dis_warning_macro ("geo::~geo(\""<<name()<<"\"): was not present in the preloaded table");
+  }
+  if (n_erased == 1) { 
+    dis_warning_macro ("geo::~geo("<<name()<<"): ERASED from table");
+  }
+#endif // DEBUG_LOADED_TABLE_TRACE
 }
 // =========================================================================
 // geo_base_rep members
 // =========================================================================
 template <class T, class M>
-geo_base_rep<T,M>::~geo_base_rep()
-{
-#ifdef TO_CLEAN
-  trace_macro ("dstor geo_base_rep: name="<<name()<<", dim="<<dimension()<<", map_dim="<<map_dimension()<<" size="<<size());
-#endif // TO_CLEAN
-}
-template <class T, class M>
 std::string
 geo_base_rep<T,M>::name() const
 {
   if (_serial_number == 0) return _name;
-  return _name + "-" + itos(_serial_number);
+  char buffer [100];
+  sprintf (buffer, "%.3d", int(_serial_number));
+  return _name + "-" + buffer;
 }
 template <class T, class M>
 bool
@@ -253,11 +416,6 @@ geo_base_rep<T,M>::have_domain_indirect (const std::string& name) const
     const domain_indirect_basic<M>& dom = *iter;
     if (name == dom.name()) return true;
   }
-#ifdef TO_CLEAN
-  // predefined domains:
-  if (name == "boundary" || name == "sides"  || name == "internal_sides") 
-    return true;
-#endif // TO_CLEAN
   return false;
 }
 template <class T, class M>
@@ -320,7 +478,7 @@ geo_base_rep<T,M>::compute_bbox()
     _xmax[j] = -std::numeric_limits<T>::max();
   }
   for (size_type j = _dimension+1; j < 3; j++) {
-    _xmin [j] = _xmax [j] = 0;
+    _xmin [j] = _xmax [j] = T(0);
   }
   for (size_type inod = 0, nnod = _node.size(); inod < nnod; inod++) {
     const point_basic<T>& x = _node [inod];
@@ -341,7 +499,7 @@ geo_base_rep<T,M>::compute_bbox()
 
   // next, compute hmin & hmax
   _hmin = std::numeric_limits<T>::max();
-  _hmax = 0;
+  _hmax = T(0);
   for (size_t iedg = 0, nedg = geo_element_ownership(1).size(); iedg < nedg; ++iedg) {
     const geo_element& E = get_geo_element (1, iedg);
     const point_basic<T>& x0 = dis_node(E[0]);
@@ -389,8 +547,8 @@ template <class T, class M>
 typename geo_base_rep<T,M>::node_type
 geo_base_rep<T,M>::piola (const geo_element& K, const node_type& hat_x) const
 {
-  // TODO: use basis_on_lattice [K.variant] instead of values[]
-  std::vector<T> values;
+  // TODO: use basis_on_lattice [K.variant] instead of values[] (computed one time for all)
+  arma::Col<T> values;
   reference_element hat_K (K.variant());
   _numbering.get_basis().eval (hat_K, hat_x, values);
 
@@ -406,33 +564,59 @@ geo_base_rep<T,M>::piola (const geo_element& K, const node_type& hat_x) const
   }
   return x;
 }
-// ----------------------------------------------------------------------------
-// set order & resize node disarray ; internal node are not computed
-// since they depend on the curved boundary information (cad data)
-// that is not aivailable here
-// ----------------------------------------------------------------------------
-#define _RHEOLEF_reset_order(M)						\
-template <class T>							\
-void									\
-geo_rep<T,M>::reset_order (size_type new_order)				\
-{									\
-  if (new_order == base::_numbering.degree()) return;			\
-  base::_numbering.set_degree (new_order);				\
-  size_type dis_nnod = base::_numbering.dis_ndof (base::_gs, base::_map_dimension); \
-  size_type     nnod = base::_numbering.ndof     (base::_gs, base::_map_dimension); \
-  base::_gs.node_ownership = distributor (nnod, base::comm(), nnod);	\
-  disarray<point_basic<T>, M> new_node (base::_gs.node_ownership);		\
-  for (size_type iv = 0, nv = base::_gs.ownership_by_dimension[0].size(); iv < nv; iv++) { \
-    new_node [iv] = base::_node [iv];					\
-  }									\
-  base::_node = new_node;						\
-  build_external_entities ();						\
+// =========================================================================
+// utility: vertex ownership follows node ownership, but dis_numbering differ
+// for high order > 1 meshes. This function converts numbering.
+// =========================================================================
+template <class T, class M>
+typename geo_base_rep<T,M>::size_type
+geo_base_rep<T,M>::dis_inod2dis_iv (size_type dis_inod) const
+{
+  if (is_sequential<M>::value || order() == 1) return dis_inod;
+  distributor vertex_ownership = geo_element_ownership(0);
+  distributor   node_ownership = _node.ownership();
+  size_type iproc          =   node_ownership.find_owner(dis_inod);
+  size_type first_dis_inod =   node_ownership.first_index(iproc);
+  size_type first_dis_iv   = vertex_ownership.first_index(iproc);
+  size_type   inod = dis_inod - first_dis_inod;
+  size_type     iv = inod;
+  size_type dis_iv = first_dis_iv + iv;
+  return dis_iv;
+}
+template <class T, class M>
+typename geo_base_rep<T,M>::size_type
+geo_base_rep<T,M>::dis_iv2dis_inod (size_type dis_iv) const
+{
+  if (is_sequential<M>::value || order() == 1) return dis_iv;
+  distributor vertex_ownership = _gs.ownership_by_variant [reference_element::p];
+  distributor   node_ownership = _gs.node_ownership;
+  size_type iproc          = vertex_ownership.find_owner(dis_iv);
+  size_type first_dis_iv   = vertex_ownership.first_index(iproc);
+  size_type first_dis_inod =   node_ownership.first_index(iproc);
+  size_type       iv = dis_iv - first_dis_iv;
+  size_type     inod = iv;
+  size_type dis_inod = first_dis_inod + inod;
+  return dis_inod;
+}
+// --------------------------------------------------------------------------
+// accessors to distributed data
+// --------------------------------------------------------------------------
+template <class T, class M>
+typename geo_base_rep<T,M>::const_reference  
+geo_base_rep<T,M>::dis_get_geo_element (size_type dim, size_type dis_ige) const
+{
+  if (is_sequential<M>::value) return get_geo_element (dim, dis_ige);
+  if (_gs.ownership_by_dimension[dim].is_owned (dis_ige)) {
+    size_type first_dis_ige = _gs.ownership_by_dimension[dim].first_index();
+    size_type ige = dis_ige - first_dis_ige;
+    return get_geo_element (dim, ige);
+  }
+  // element is owned by another proc ; get its variant and then its index-variant igev
+  size_type variant  = _gs.dis_ige2variant  (dim, dis_ige);
+  size_type dis_igev = _gs.dis_ige2dis_igev (dim, variant, dis_ige);
+  typename geo_base_rep<T,M>::const_reference res = _geo_element [variant].dis_at (dis_igev);
+  return res;
 }
-_RHEOLEF_reset_order(sequential)
-#ifdef _RHEOLEF_HAVE_MPI
-_RHEOLEF_reset_order(distributed)
-#endif // _RHEOLEF_HAVE_MPI
-#undef _RHEOLEF_reset_order
 // -------------------------------------------------------------------
 // guards for omega.boundary() and omega.internal_sides()
 // -------------------------------------------------------------------
@@ -498,6 +682,7 @@ void sides_guard (const geo_basic<T,M>& omega)
 #define _RHEOLEF_instanciation(T,M) 				\
 template class geo_base_rep<T,M>;				\
 template class geo_rep<T,M>;					\
+template class geo_basic<T,M>;					\
 template geo_basic<T,M> geo_load (const std::string& name); 	\
 template geo_basic<T,M> compact    (const geo_basic<T,M>&);    	\
 template void boundary_guard       (const geo_basic<T,M>&);	\
