@@ -66,6 +66,8 @@
 #include "rheolef/geo_locate.h"
 #include "rheolef/geo_trace_ray_boundary.h"
 #include "rheolef/geo_nearest.h"
+#include "rheolef/rounder.h"
+#include <unordered_map>
 
 namespace rheolef {
 
@@ -88,6 +90,21 @@ struct _point_put {
   size_type d;
   std::ostream& operator() (std::ostream& os, const point_basic<T>& x) { return x.put (os, d); }
 };
+/// @brief point output helper, with rounding feature
+template <class T>
+struct _round_point_put {
+  typedef typename point_basic<T>::size_type size_type;
+  _round_point_put (size_type d1, const T& eps1) : d(d1), round(eps1) {}
+  size_type       d;
+  rounder_type<T> round;
+  std::ostream& operator() (std::ostream& os, const point_basic<T>& x) {
+    for (size_t i = 0; i < d; ++i) {
+      os << round(x[i]);
+      if (i+1 != d) os << " ";
+    }
+    return os;
+  }
+};
 
 // forward declaration:
 template <class T, class M> class geo_basic;
@@ -446,7 +463,7 @@ public:
       const std::array<disarray<geo_element_auto<heap_allocator<size_type> >,M>,
                          reference_element::max_variant>& elt_list);
 
-    ~geo_base_rep ();
+    ~geo_base_rep();
 
 // abstract accessors defined:
   
@@ -562,6 +579,7 @@ protected:
     void init_neighbour() const;
     template<class U> friend void add_ball_externals (const geo_base_rep<U,M>&, const disarray<index_set,M>&);
 
+
 // data:
 // 0) header:
     std::string                              _name;
@@ -586,6 +604,13 @@ protected:
     geo_locate<T,M>                          _locator;
     geo_trace_ray_boundary<T,M>              _tracer_ray_boundary;
     geo_nearest<T,M>                         _nearestor;
+
+// static data member: loaded geo table
+public:
+    typedef std::unordered_map<std::string,void*> loaded_map_t;
+    static loaded_map_t& loaded_map();
+protected:
+    static loaded_map_t _loaded_map;
 };
 template <class T, class M>
 inline
@@ -745,10 +770,6 @@ public:
     const distributor& vertex_ownership()        const { return geo_element_ownership(0); }
     const_reference operator[] (size_type ie) const { return get_geo_element (map_dimension(), ie); }
     reference       operator[] (size_type ie)       { return get_geo_element (map_dimension(), ie); }
-#ifdef TO_CLEAN
-    size_type             dis_inod2dis_iv (size_type dis_inod) const { return dis_inod; }
-    size_type             dis_iv2dis_inod (size_type dis_iv)   const { return dis_iv; }
-#endif // TO_CLEAN
 
 // i/o:
 
@@ -971,7 +992,7 @@ public:
 };
 /*Class:geo
 NAME:  @code{geo} - finite element mesh (@PACKAGE@-@VERSION@)
-SYNOPSYS:       
+SYNOPSIS:       
  Distributed finite element mesh.
 SEE ALSO: "geo_element"(3)
 AUTHORS: Pierre.Saramito@imag.fr
@@ -1046,7 +1067,6 @@ public:
     const geo_size&      sizes()             const { return base::data().sizes(); }
     const geo_size&  ios_sizes()             const { return base::data().ios_sizes(); }
     const_reference get_geo_element (size_type dim, size_type ige) const { return base::data().get_geo_element (dim, ige); }
-          reference get_geo_element (size_type dim, size_type ige)       { return base::data().get_geo_element (dim, ige); }
     const_reference dis_get_geo_element (size_type dim, size_type dis_ige) const
 		{ return get_geo_element (dim, dis_ige); }
     const geo_element& bgd2dom_geo_element (const geo_element& bgd_K) const { return base::data().bgd2dom_geo_element (bgd_K); }
@@ -1154,7 +1174,6 @@ public:
     size_type     n_vertex()          const { return size     (0); }
     size_type dis_n_vertex()          const { return dis_size (0); }
     const_reference operator[] (size_type ie) const { return get_geo_element (map_dimension(), ie); }
-	  reference operator[] (size_type ie)       { return get_geo_element (map_dimension(), ie); }
     const_iterator begin (size_type dim) const { return base::data().begin(dim); }
     const_iterator end   (size_type dim) const { return base::data().end  (dim); }
     const_iterator begin ()              const { return begin(map_dimension()); }
@@ -1183,7 +1202,6 @@ public:
     idiststream& get (idiststream& ips);
     odiststream& put (odiststream& ops) const;
     void save (std::string filename = "") const;
-    void dump (std::string name) const {        base::data().dump (name); }
     bool check (bool verbose = true) const { return base::data().check(verbose); }
 };
 //>verbatim:
@@ -1503,128 +1521,6 @@ geo_basic<T,distributed>::sides() const
 }
 #endif // _RHEOLEF_HAVE_MPI
 
-// ==============================================================================
-// geo fat interface: members are specific to geo_rep
-// => check that pointer to geo_abstract_rep points to a geo_rep
-// ==============================================================================
-
-#define _RHEOLEF_save(M)	                                              	\
-template <class T>								\
-void										\
-geo_basic<T,M>::save (std::string filename) const				\
-{										\
-  if (filename == "") filename = name();					\
-  odiststream out (filename, "geo");						\
-  put (out);									\
-}
-#define _RHEOLEF_set_nodes(M)                                              	\
-template <class T>								\
-void										\
-geo_basic<T,M>::set_nodes (const disarray<node_type,M>& x)			\
-{										\
-  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot set_nodes on geo_domains");			\
-  ptr->set_nodes(x);								\
-}
-#define _RHEOLEF_reset_order(M)                                              	\
-template <class T>								\
-void										\
-geo_basic<T,M>::reset_order (size_type order)					\
-{										\
-  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot reset_order on geo_domains");			\
-  ptr->reset_order(order);							\
-}
-#define _RHEOLEF_set_coordinate_system(M)                                    	\
-template <class T>								\
-void										\
-geo_basic<T,M>::set_coordinate_system (coordinate_type sys_coord)		\
-{										\
-  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot set_coordinate_system on geo_domains");	\
-  ptr->set_coordinate_system(sys_coord);					\
-}
-#define _RHEOLEF_set_dimension(M)	                                    	\
-template <class T>								\
-void										\
-geo_basic<T,M>::set_dimension (size_type dim)					\
-{										\
-  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot set_dimension on geo_domains");		\
-  ptr->set_dimension(dim);							\
-}
-#define _RHEOLEF_set_serial_number(M)	                                    	\
-template <class T>								\
-void										\
-geo_basic<T,M>::set_serial_number (size_type i)					\
-{										\
-  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot set_serial_number on geo_domains");		\
-  ptr->set_serial_number(i);							\
-}
-#define _RHEOLEF_set_name(M)		                                    	\
-template <class T>								\
-void										\
-geo_basic<T,M>::set_name (std::string name)					\
-{										\
-  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot set_name on geo_domains");			\
-  ptr->set_name(name);								\
-}
-#define _RHEOLEF_build_from_data(M)		                                \
-template <class T>								\
-void										\
-geo_basic<T,M>::build_from_data (						\
-  const geo_header&               hdr,						\
-  const disarray<node_type, M>&   node,						\
-        std::array<disarray<geo_element_auto<heap_allocator<size_type> >,M, heap_allocator<size_type> >, reference_element::max_variant>& tmp_geo_element, \
-  bool do_upgrade)								\
-{										\
-  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot build_from_data on geo_domains");		\
-  ptr->build_from_data (hdr, node, tmp_geo_element, do_upgrade);		\
-}
-#define _RHEOLEF_build_by_subdividing(M)		                        \
-template <class T>								\
-void										\
-geo_basic<T,M>::build_by_subdividing (						\
-  const geo_basic<T,M>& omega, 							\
-  size_type k)									\
-{										\
-  geo_rep<T,M>* ptr = dynamic_cast<geo_rep<T,M>*>(base::pointer());		\
-  check_macro (ptr != 0, "cannot build_by_subdividing on geo_domains");		\
-  ptr->build_by_subdividing (omega, k);						\
-}
-
-_RHEOLEF_save(sequential)
-_RHEOLEF_set_nodes(sequential)
-_RHEOLEF_reset_order(sequential)
-_RHEOLEF_set_coordinate_system(sequential)
-_RHEOLEF_set_dimension(sequential)
-_RHEOLEF_set_serial_number(sequential)
-_RHEOLEF_set_name(sequential)
-_RHEOLEF_build_from_data(sequential)
-_RHEOLEF_build_by_subdividing(sequential)
-#ifdef _RHEOLEF_HAVE_MPI
-_RHEOLEF_save(distributed)
-_RHEOLEF_set_nodes(distributed)
-_RHEOLEF_reset_order(distributed)
-_RHEOLEF_set_coordinate_system(distributed)
-_RHEOLEF_set_dimension(distributed)
-_RHEOLEF_set_serial_number(distributed)
-_RHEOLEF_set_name(distributed)
-_RHEOLEF_build_by_subdividing(distributed)
-#ifdef TODO
-_RHEOLEF_build_from_data(distributed)
-#endif // TODO
-#endif // _RHEOLEF_HAVE_MPI
-#undef _RHEOLEF_set_nodes
-#undef _RHEOLEF_reset_order
-#undef _RHEOLEF_set_coordinate_system
-#undef _RHEOLEF_set_dimension
-#undef _RHEOLEF_set_name
-#undef _RHEOLEF_build_from_data
-#undef _RHEOLEF_build_by_subdividing
 // ==============================================================================
 // inlined: geo<T,M>
 // ==============================================================================
