@@ -117,20 +117,8 @@ geo_domain_rep<T,M>::get_domain_indirect (const std::string& name) const
 // ------------------------------------------------------------------------
 template <class T, class M>
 geo_basic<T,M>
-compact (const geo_basic<T,M>& gamma)
-{
-    if (gamma.variant() != geo_abstract_base_rep<T>::geo_domain_indirect) {
-        return gamma;
-    }
-    /* allocate a new geo_rep object */
-    const geo_domain_indirect_rep<T,M>* dom_ptr
-     = dynamic_cast<const geo_domain_indirect_rep<T,M>*>(gamma.operator->());
-    geo_domain_rep<T,M>* geo_ptr
-     = new_macro((geo_domain_rep<T,M>)(*dom_ptr));
-    geo_basic<T,M> new_gamma;
-    new_gamma.geo_basic<T,M>::base::operator= (geo_ptr);
-    return new_gamma;
-}
+compact (const geo_basic<T,M>& gamma);
+
 // only two specialized M=seq & dist have the member fct; thus, use a macro:
 #define _RHEOLEF_get_bgd_geo(M) 						\
 template <class T>								\
