@@ -96,9 +96,6 @@ template <class T, class M>
 const geo_size&
 geo_domain_indirect_base_rep<T,M>::sizes() const
 {
-#ifdef TO_CLEAN
-  error_macro ("domain.sizes: not yet");
-#endif // TO_CLEAN
   return _omega.sizes();
 }
 template <class T, class M>
