@@ -665,6 +665,10 @@ geo_rep<T,distributed>::build_from_domain (
   /** TODO
     	_domains : intersection avec le dom courant
    */
+  // ------------------------------------------------------------------------
+  // some post treatments (after build_external_entities and so one!)
+  // ------------------------------------------------------------------------
+  base::compute_bbox();
 }
 // ----------------------------------------------------------------------------
 // instanciation in library
