@@ -104,47 +104,6 @@ protected:
   point_basic<T> a, b, c, d, center;
   T radius;
 };
-#ifdef TO_CLEAN
-// ====================================================================================
-// triangle (a,b,c) with curved edge (a,b)
-// ====================================================================================
-template<class T>
-class curved_ball_t_old : public curved_ball_q {
-public:
-// allocator:
-  curved_ball_t_old (const point_basic<T>& a0, const point_basic<T>& b0, const point_basic<T>& c0,
-	const point_basic<T>& center0 = point_basic<T>(0,0), const T& radius0 = 1)
-   : curved_ball_q (a0, b0, c0, c0, center0, radius0) {}
-// accessor:
-  point_basic<T> operator() (const point_basic<T>& hat_x) const {
-    /* Transform for a triangle, from eqn (27) in:
-	@article{DeySheFla-1997,
-	 title = {Geometry representation issues associated with p-version finite element computations},
-	 author = {S. Dey and M. S. Shephard and J. E. Flaherty},
-	 journal = {Comput. Meth. Appl. Mech. Engrg.},
-	 volume = 150, 
-	 year = 1997, 
-	 pages = {39--55}
-	}
-      Remark : SheKar-1999, p. 162-163 : cite GorHal-1973 for a quadrangle
-      but says that the triangle-to-square transform + the quadrangle formulae
-      does not work here (its true, I have checked) because of a singular jacobian.
-      Triangle requires thus a specific formulae as it is done here.
-      Also: similar ref: eqn (3.17), page 169 in SolSegDol-2004 is incorrect.
-    */
-    T la = 1 - hat_x[0] - hat_x[1]; // barycentric coords
-    T lb = hat_x[0];
-    T lc = hat_x[1];
-    return 0.5*( la/(1-lb)*f_ab(lb) + lb/(1-la)*f_ab(1-la)
-               + lb/(1-lc)*f_bc(lc) + lc/(1-lb)*f_bc(1-lb) 
-	       + lc/(1-la)*f_ca(la) + la/(1-lc)*f_ca(1-lc)
-	       - la*a - lb*b - lc*c);
-  }
-// internals:
-protected:
-  point_basic<T> f_ca (const T& s) const { return f_ad(1-s); }
-};
-#endif // TO_CLEAN
 // ====================================================================================
 // triangle (a,b,c) with i-th curved edge
 // ====================================================================================
@@ -208,80 +167,6 @@ protected:
   T radius;
   std::array<bool,3> is_bdry_edg;
 };
-#ifdef TO_CLEAN
-// ====================================================================================
-// tetrahedron (a,b,c,d) with curved face (a,b,c)
-// ====================================================================================
-template<class T>
-class curved_ball_T_old {
-public:
-// allocator:
-  curved_ball_T_old (const point_basic<T>& a0, const point_basic<T>& b0, const point_basic<T>& c0, const point_basic<T>& d0,
-	const point_basic<T>& center0 = point_basic<T>(0,0), const T& radius0 = 1)
-   : a(a0), b(b0), c(c0), d(d0), center(center0), radius(radius0) {}
-// accessor:
-  point_basic<T> operator() (const point_basic<T>& hat_x) const {
-    T la = 1 - hat_x[0] - hat_x[1] - hat_x[2]; // barycentric coords
-    T lb = hat_x[0];
-    T lc = hat_x[1];
-    T ld = hat_x[2];
- 
-    curved_ball_t_old G_abd (a, b, d, center, radius);
-    curved_ball_t_old G_acd (a, c, d, center, radius);
-    curved_ball_t_old G_bcd (b, c, d, center, radius);
-
-    point_basic<T> s_abc = f_abc((la*a + lb*b + lc*c)/(la+lb+lc));
-    point_basic<T> s_abd = G_abd(point_basic<T>(lb, ld)/(la+lb+ld));
-    point_basic<T> s_acd = G_acd(point_basic<T>(lc, ld)/(la+lc+ld));
-    point_basic<T> s_bcd = G_bcd(point_basic<T>(lc, ld)/(lb+lc+ld));
-    point_basic<T> e_ab  = f_ab ((la*a + lb*b)/(la+lb));
-    point_basic<T> e_ac  = f_ac ((la*a + lc*c)/(la+lc));
-    point_basic<T> e_ad  = f_ad ((la*a + ld*d)/(la+ld));
-    point_basic<T> e_bc  = f_bc ((lb*b + lc*c)/(lb+lc));
-    point_basic<T> e_cd  = f_cd ((lc*c + ld*d)/(lc+ld));
-    point_basic<T> e_bd  = f_bd ((lb*b + ld*d)/(lb+ld));
-    return (1-ld)*s_abc
-         + (1-lc)*s_abd
-         + (1-lb)*s_acd
-         + (1-la)*s_bcd
-         - (1-lc-ld)*e_ab
-         - (1-ld-lb)*e_ac
-         - (1-lb-lc)*e_ad
-         - (1-la-ld)*e_bc
-         - (1-la-lb)*e_cd
-         - (1-la-lc)*e_bd
-         + la*a + lb*b + lc*c + ld*d;
-  }
-// internals:
-protected:
-    /* Transform for a tetra, from eqn (30) in:
-	@article{DeySheFla-1997,
-	 title = {Geometry representation issues associated with p-version finite element computations},
-	 author = {S. Dey and M. S. Shephard and J. E. Flaherty},
-	 journal = {Comput. Meth. Appl. Mech. Engrg.},
-	 volume = 150, 
-	 pages = {39--55},
-	 year = 1997
-	}
-    */
-  point_basic<T> project_on_boundary (const point_basic<T>& x) const {
-    return center + radius*(x-center)/norm(x-center);
-  }
-  point_basic<T> f_abc (const point_basic<T>& x) const { return project_on_boundary (x); }
-  point_basic<T> f_abd (const point_basic<T>& x) const { return x; }
-  point_basic<T> f_acd (const point_basic<T>& x) const { return x; }
-  point_basic<T> f_bcd (const point_basic<T>& x) const { return x; }
-  point_basic<T> f_ab  (const point_basic<T>& x) const { return project_on_boundary (x); }
-  point_basic<T> f_ac  (const point_basic<T>& x) const { return project_on_boundary (x); }
-  point_basic<T> f_bc  (const point_basic<T>& x) const { return project_on_boundary (x); }
-  point_basic<T> f_ad  (const point_basic<T>& x) const { return x; }
-  point_basic<T> f_bd  (const point_basic<T>& x) const { return x; }
-  point_basic<T> f_cd  (const point_basic<T>& x) const { return x; }
-// data:
-  point_basic<T> a, b, c, d, center;
-  T radius;
-};
-#endif // TO_CLEAN
 // ====================================================================================
 // tetrahedron (a,b,c,d) with i-th curved face
 // ====================================================================================
