@@ -238,7 +238,7 @@ geo_locate<T,M>::dis_locate (
 template <class T, class M>
 class geo_locate_abstract_rep {
 public:
-  typedef typename array<T,M>::size_type size_type;
+  typedef typename disarray<T,M>::size_type size_type;
   virtual ~geo_locate_abstract_rep() {}
   virtual void initialize (const geo_base_rep<T,M>& omega) const = 0;
   virtual size_type seq_locate (
@@ -411,13 +411,13 @@ geo_base_rep<T,M>::dis_locate (
   return _locator.dis_locate (*this, x, dis_ie_guest);
 }
 // ----------------
-// 6b) array case:
+// 6b) disarray case:
 // ----------------
 template <class T>
 void
 geo_rep<T,sequential>::locate (
-  const array<point_basic<T>, sequential>& x,
-        array<size_type, sequential>&      dis_ie,
+  const disarray<point_basic<T>, sequential>& x,
+        disarray<size_type, sequential>&      dis_ie,
   bool do_check) const
 {
   dis_ie.resize (x.ownership());
@@ -433,8 +433,8 @@ geo_rep<T,sequential>::locate (
 template <class T>
 void
 geo_rep<T,distributed>::locate (
-  const array<point_basic<T>, distributed>& x,
-        array<size_type, distributed>&      dis_ie,
+  const disarray<point_basic<T>, distributed>& x,
+        disarray<size_type, distributed>&      dis_ie,
 	// dis_ie(ix) can contains a guest for x in K=omega[dis_ie(ix)]
   bool do_check) const
 {
@@ -453,7 +453,7 @@ trace_macro ("locate...");
       failed.push_back (id_pt_t<T>(dis_i, x[i]));
     }
   }
-  // 2) merge the failed list into a massive array, then distributed to all
+  // 2) merge the failed list into a massive disarray, then distributed to all
   communicator comm = ownership.comm();
   distributor fld_ownership (distributor::decide, comm, failed.size());
   size_type   fld_dis_size = fld_ownership.dis_size();
@@ -497,7 +497,7 @@ trace_macro ("locate done(1)");
         massive_merged.begin().operator->(),
         mpi::minimum<size_type>());
 
-  // 5) store the local range into the distributed array dis_ie:
+  // 5) store the local range into the distributed disarray dis_ie:
   for (size_type fld_dis_i = first_fld_dis_i; fld_dis_i < last_fld_dis_i; ++fld_dis_i, ++iter) {
     size_type dis_i  = massive_query [fld_dis_i].first;
     check_macro (dis_i >= first_dis_i, "invalid index");
@@ -560,8 +560,8 @@ geo_base_rep<T,M>::dis_locate (
 template <class T>
 void
 geo_rep<T,sequential>::locate (
-  const array<point_basic<T>, sequential>& x,
-        array<size_type, sequential>&      dis_ie,
+  const disarray<point_basic<T>, sequential>& x,
+        disarray<size_type, sequential>&      dis_ie,
   bool do_check) const
 {
   fatal_macro ("geo: locator not available (HINT: recompile Rheolef with the CGAL library)");
@@ -570,8 +570,8 @@ geo_rep<T,sequential>::locate (
 template <class T>
 void
 geo_rep<T,distributed>::locate (
-  const array<point_basic<T>, distributed>& x,
-        array<size_type, distributed>&      dis_ie,
+  const disarray<point_basic<T>, distributed>& x,
+        disarray<size_type, distributed>&      dis_ie,
 	// dis_ie(ix) can contains a guest for x in K=omega[dis_ie(ix)]
   bool do_check) const
 {
