@@ -41,21 +41,6 @@ geo_mpi_partition (
 // --------------------------------------------------------------------------
 // utility for geo get
 // --------------------------------------------------------------------------
-#ifdef TO_CLEAN
-// or move to rheostream: used to dump parallel cerr into separate files
-std::streambuf* strm_buffer = 0;
-std::ofstream file;
-void start_redirect (std::ostream& strm, std::string filename) {
-    file.open (filename.c_str());
-    strm_buffer = strm.rdbuf(); // save output buffer of the stream
-    strm.rdbuf (file.rdbuf()); // redirect ouput into the file
-}
-void end_redirect (std::ostream& strm, std::string="") {
-    // restore old output buffer
-    strm.rdbuf (strm_buffer);
-}
-#endif // TO_CLEAN
-
 static
 distributor
 build_true_ios_ge_ownership_by_dimension (
