@@ -83,7 +83,16 @@ geo_rep<T,distributed>::put (odiststream& ops)  const
   // 2) put nodes
   //
   if (base::_dimension > 0) {
-    base::_node.permuted_put_values (ops, _inod2ios_dis_inod, _point_put<T>(base::_dimension));
+    T rounding_prec = iorheo::getrounding_precision(ops.os());
+    if (rounding_prec == 0) {
+      base::_node.permuted_put_values (ops,
+		_inod2ios_dis_inod,
+		_point_put<T>(base::_dimension));
+    } else {
+      base::_node.permuted_put_values (ops,
+		_inod2ios_dis_inod, 
+      		_round_point_put<T>(base::_dimension, rounding_prec));
+    }
     ops << endl;
   }
   //
