@@ -397,7 +397,7 @@ geo_rep<T,distributed>::nearest (
 // ----------------------------------------------------------------------------
 // no CGAL: no nearest
 // ----------------------------------------------------------------------------
-#else // _RHEOLEF_HAVE_CGAL
+#else // ! _RHEOLEF_HAVE_CGAL
 template <class T, class M>
 geo_nearest<T,M>::~geo_nearest()
 {
@@ -405,10 +405,9 @@ geo_nearest<T,M>::~geo_nearest()
 template <class T, class M>
 typename geo_nearest<T,M>::size_type
 geo_nearest<T,M>::seq_nearest (
-    const geo_base_rep<T,M>& omega,
-    const point_basic<T>&    x,
-          point_basic<T>&    x_nearest,
-    size_type                dis_ie_guest) const
+        const geo_base_rep<T,M>& omega,
+        const point_basic<T>&    x,
+              point_basic<T>&    x_nearest) const
 {
   fatal_macro ("geo: nearest not available (HINT: recompile Rheolef with the CGAL library)");
   return 0;
@@ -416,10 +415,9 @@ geo_nearest<T,M>::seq_nearest (
 template <class T, class M>
 typename geo_nearest<T,M>::size_type
 geo_nearest<T,M>::dis_nearest (
-    const geo_base_rep<T,M>& omega,
-    const point_basic<T>&    x,
-          point_basic<T>&    x_nearest,
-    size_type                dis_ie_guest) const
+        const geo_base_rep<T,M>& omega,
+        const point_basic<T>&    x,
+              point_basic<T>&    x_nearest) const
 {
   fatal_macro ("geo: nearest not available (HINT: recompile Rheolef with the CGAL library)");
   return 0;
@@ -447,7 +445,7 @@ void
 geo_rep<T,sequential>::nearest (
   const disarray<point_basic<T>, sequential>& x,
         disarray<point_basic<T>, sequential>& x_nearest,
-        disarray<size_type, sequential>&      dis_ie) const
+        disarray<typename geo_base_rep<T,sequential>::size_type, sequential>& idx) const
 {
   fatal_macro ("geo: nearest not available (HINT: recompile Rheolef with the CGAL library)");
 }
@@ -457,9 +455,7 @@ void
 geo_rep<T,distributed>::nearest (
   const disarray<point_basic<T>, distributed>& x,
         disarray<point_basic<T>, distributed>& x_nearest,
-        disarray<size_type, distributed>&      dis_ie,
-	// dis_ie(ix) can contains a guest for x in K=omega[dis_ie(ix)]
-  bool do_check) const
+        disarray<typename geo_base_rep<T,distributed>::size_type, distributed>& idx) const
 {
   fatal_macro ("geo: nearest not available (HINT: recompile Rheolef with the CGAL library)");
 }
