@@ -179,15 +179,6 @@ geo_base_rep<T,M>::init_neighbour() const
           if (orient < 0) std::swap (dis_ie1, dis_ie2);
           S.set_master (0, dis_ie1);
           S.set_master (1, dis_ie2);
-#ifdef TO_CLEAN
-          // manage also external nodes of local elements K (already done)
-          for (size_type loc_inod = 0, loc_nnod = K.n_node(); loc_inod < loc_nnod; loc_inod++) {
-            size_type dis_inod = K[loc_inod];
-            if (! inod_ownership.is_owned (dis_inod)) {
-              ext_inod_set += dis_inod;
-            }
-          }
-#endif // TO_CLEAN
           break;
         }
         default: error_macro ("neighbour: side #"<< ball_intersect.size()<<" connectivity problem");
