@@ -62,7 +62,7 @@ geo_get_vtk (idiststream& ips, geo_basic<T,sequential>& omega)
   check_macro (ips.good(), "bad input stream for vtk");
   // ------------------------------------------------------------------------
   // 2) load the domain connectivity
-  //	  LINES <ne> <ntot>
+  //	LINES <ne> <ntot>
   //    2  {s1 s2} j=0..ne-1
   // or
   //    POLYGONS <ne> <ntot>
@@ -76,8 +76,10 @@ geo_get_vtk (idiststream& ips, geo_basic<T,sequential>& omega)
     for (size_type i = 0; i < n; i++) {
       is  >> d >> idx;
     }
-    is >> ws >> mark;
   }
+  do {
+    if (mark == "POLYGONS" || mark == "LINES") break;
+  } while (is >> ws >> mark);
   if (mark == "POLYGONS")      hdr.map_dimension = 2;
   else if (mark == "LINES")    hdr.map_dimension = 1;
   else error_macro ("geo: unexpected `" << mark << "' in vtk polydata input.");
@@ -111,9 +113,6 @@ geo_get_vtk (idiststream& ips, geo_basic<T,sequential>& omega)
                    variant < reference_element:: last_variant_by_dimension(hdr.map_dimension); variant++) {
       geo_element_auto<> init_val (variant, hdr.order);
       tmp_geo_element [variant] = disarray_t (hdr.dis_size_by_variant [variant], init_val, alloc);
-#ifdef TO_CLEAN
-      tmp_geo_element [variant].resize (hdr.dis_size_by_variant [variant], init_val);
-#endif // TO_CLEAN
     }
     std::array<size_type, 4> counter;
     counter.fill(0);
