@@ -79,10 +79,18 @@ geo_rep<T,sequential>::put_geo (odiststream& ops)  const {
     ops << endl << h << endl;
   }
   //
-  // put nodes & elements
+  // put nodes
   //
-  base::_node.put_values (ops, _point_put<T>(base::_dimension));
+  T rounding_prec = iorheo::getrounding_precision(ops.os());
+  if (rounding_prec == 0) {
+    base::_node.put_values (ops, _point_put<T>(base::_dimension));
+  } else {
+    base::_node.put_values (ops, _round_point_put<T>(base::_dimension, rounding_prec));
+  }
   ops << endl;
+  //
+  // put elements
+  //
   if (base::_map_dimension > 0) {
     for (size_type variant = reference_element::first_variant_by_dimension(base::_map_dimension);
                    variant < reference_element:: last_variant_by_dimension(base::_map_dimension); variant++) {
