@@ -213,9 +213,6 @@ geo_rep<T,sequential>::get_upgrade (
                    variant < reference_element:: last_variant_by_dimension(hdr.map_dimension); variant++) {
       geo_element_auto<heap_allocator<size_type> > init_val (variant, hdr.order, alloc);
       tmp_geo_element [variant] = disarray_t (hdr.dis_size_by_variant [variant], init_val, alloc);
-#ifdef TO_CLEAN
-      tmp_geo_element [variant].resize (hdr.dis_size_by_variant [variant], init_val);
-#endif // TO_CLEAN
       tmp_geo_element [variant].get_values (ips);
       check_macro (ips.good(), "bad input stream for geo.");
     }
