@@ -359,7 +359,7 @@ visu_gnuplot (odiststream& ops, const geo_basic<T,sequential>& omega)
   }
   if (omega.dimension() == 2) {
     plot << "set size ratio -1  # equal scales" << endl
-         << "set key left Right at graph 1,1" << endl;
+         << "#set key left Right at graph 1,1" << endl;
   }
   if (omega.dimension() == 3) {
     plot << "set zrange [" << xmin[2] << ":" << xmax[2] << "]" << endl
