@@ -60,21 +60,21 @@ DESCRIPTION:
   the result is a linear form, represented by the @code{field} class. 
   (iii) When the expression involves both  symbolic trial- and test-functions @pxref{test class},
   the result is a bilinear form, represented by the @code{field} class. 
-SYNOPSYS:
+SYNOPSIS:
 @example
  Float integrate (geo domain);
- Float integrate (geo domain, quadrature_option_type qopt);
- Value integrate (geo domain, Expression, quadrature_option_type qopt);
+ Float integrate (geo domain, quadrature_option qopt);
+ Value integrate (geo domain, Expression, quadrature_option qopt);
 
  field integrate (Expression);
- field integrate (Expression, quadrature_option_type qopt);
+ field integrate (Expression, quadrature_option qopt);
  field integrate (geo domain, Expression);
- field integrate (geo domain, Expression, quadrature_option_type qopt);
+ field integrate (geo domain, Expression, quadrature_option qopt);
 
  form integrate (Expression);
- form integrate (Expression, form_option_type qopt);
+ form integrate (Expression, integrate_option qopt);
  form integrate (geo domain, Expression);
- form integrate (geo domain, Expression, form_option_type qopt);
+ form integrate (geo domain, Expression, integrate_option qopt);
 @end example
 EXAMPLE:
 @noindent
@@ -86,12 +86,12 @@ EXAMPLE:
 @example
   Float f (const point& x);
   ...
-  quadrature_option_type qopt;
+  quadrature_option qopt;
   qopt.set_order (3);
   Float int_f = integrate (omega, f, qopt);
 @end example
   The last argument specifies the quadrature formulae 
-  (see @ref{quadrature_option_type class})
+  (see @ref{quadrature_option class})
   used for the computation of the integral.
   The function can be replaced by any field-valued expression (see @ref{field class}).
   For computing a right-hand-side of a variational formulation
@@ -114,9 +114,9 @@ DEFAULT ARGUMENTS:
   Also, the quadrature formulae is optional: by default, its order
   is @code{2*k+1} where @code{k} is the polynomial degree of the
   @code{Xh} space associated to the test function @code{v}.
-  When both a test @code{u} and trial @code{v} functions are suppied, let k1 and k2 be their polynomial degrees.
-  Then the default quadrature is choosen to be exact at least for k1+k2+1 polynoms.
-  When the integration is perfomed on a subdomain, this subdomain
+  When both a test @code{u} and trial @code{v} functions are supplied, let k1 and k2 be their polynomial degrees.
+  Then the default quadrature is chosen to be exact at least for k1+k2+1 polynoms.
+  When the integration is performed on a subdomain, this subdomain
   simply replace the first argument and a domain name could also be used:
 @example
   field l2h = integrate (omega["boundary"], f*v);
@@ -138,7 +138,7 @@ typename std::enable_if<
   && ! is_undeterminated<Result>::value,
   Result
 >::type
-integrate (const geo_basic<T,M>& omega, const Expr& expr, const quadrature_option_type& qopt,
+integrate (const geo_basic<T,M>& omega, const Expr& expr, const quadrature_option& qopt,
 	   Result dummy = Result())
 {
   typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr>::type  wrap_t;
@@ -154,9 +154,9 @@ integrate (const geo_basic<T,M>& omega, const Expr& expr, const quadrature_optio
 // ---------------------------------------------------
 template <class T, class M>
 T
-integrate (const geo_basic<T,M>& omega, quadrature_option_type&& qopt = quadrature_option_type())
+integrate (const geo_basic<T,M>& omega, quadrature_option&& qopt = quadrature_option())
 {
-  if (qopt.get_order() == std::numeric_limits<quadrature_option_type::size_type>::max()) {
+  if (qopt.get_order() == std::numeric_limits<quadrature_option::size_type>::max()) {
     qopt.set_order(0);
   }
   details::f_constant <point_basic<T>,T> one(1);
@@ -173,7 +173,7 @@ typename std::enable_if<
   && is_undeterminated<typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr>::type::value_type>::value,
   typename scalar_traits<typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr>::type::value_type>::type
 >::type
-integrate (const geo_basic<T,M>& omega, const Expr& expr, const quadrature_option_type& qopt)
+integrate (const geo_basic<T,M>& omega, const Expr& expr, const quadrature_option& qopt)
 {
   typedef typename details::field_expr_v2_nonlinear_terminal_wrapper_traits<Expr>::type::value_type undef_t;
   typedef typename scalar_traits<undef_t>::type scalar_type;
@@ -206,7 +206,7 @@ std::enable_if<
 integrate (
   const geo_basic<T,M>& domain, 
   const Expr& expr,
-  const quadrature_option_type& qopt = quadrature_option_type())
+  const quadrature_option& qopt = quadrature_option())
 {
   field_basic<T,M> lh;
   lh.assembly (domain, expr, qopt);
@@ -224,7 +224,7 @@ std::enable_if<
 >::type
 integrate (
   const Expr& expr,
-  const quadrature_option_type& qopt = quadrature_option_type())
+  const quadrature_option& qopt = quadrature_option())
 {
   field_basic <typename Expr::scalar_type, typename Expr::memory_type> lh;
   lh.assembly (expr.get_vf_space().get_geo(), expr, qopt);
@@ -243,7 +243,7 @@ std::enable_if<
 integrate (
   const std::string& domname, 
   const Expr& expr,
-  const quadrature_option_type& qopt = quadrature_option_type())
+  const quadrature_option& qopt = quadrature_option())
 {
   field_basic <typename Expr::scalar_type, typename Expr::memory_type> lh;
   lh.assembly (expr.get_vf_space().get_geo()[domname], expr, qopt);
@@ -264,7 +264,7 @@ std::enable_if<
 integrate (
   const geo_basic<T,M>& domain, 
   const Expr& expr,
-  const form_option_type& fopt = form_option_type())
+  const integrate_option& fopt = integrate_option())
 {
   form_basic<T,M> a;
   a.assembly (domain, expr, fopt);
@@ -282,7 +282,7 @@ std::enable_if<
 >::type
 integrate (
   const Expr& expr,
-  const form_option_type& fopt = form_option_type())
+  const integrate_option& fopt = integrate_option())
 {
   form_basic <typename Expr::scalar_type, typename Expr::memory_type> a;
   a.assembly (expr.get_test_space().get_geo(), expr, fopt);
@@ -301,7 +301,7 @@ std::enable_if<
 integrate (
   const std::string& domname, 
   const Expr& expr,
-  const form_option_type& fopt = form_option_type())
+  const integrate_option& fopt = integrate_option())
 {
   form_basic <typename Expr::scalar_type, typename Expr::memory_type> a;
   a.assembly (expr.get_test_space().get_geo()[domname], expr, fopt);
@@ -320,7 +320,7 @@ std::enable_if<
 integrate (
   const band_basic<T,M>& gh, 
   const Expr& expr,
-  const quadrature_option_type& qopt = quadrature_option_type())
+  const quadrature_option& qopt = quadrature_option())
 {
   field_basic <typename Expr::scalar_type, typename Expr::memory_type> lh;
   lh.assembly (gh, expr, qopt);
@@ -336,7 +336,7 @@ std::enable_if<
 integrate (
   const band_basic<T,M>& gh, 
   const Expr& expr,
-  const form_option_type& fopt = form_option_type())
+  const integrate_option& fopt = integrate_option())
 {
   form_basic <typename Expr::scalar_type, typename Expr::memory_type> a;
   a.assembly (gh, expr, fopt);
