@@ -92,9 +92,9 @@ interpolate_pass1_symbolic (
     // otherwise: manage the scatter in a separate map<ext_ix,x>
     //    map<ix,x> ext_x_map;
     //    x.append_dis_indexes (ext_dis_ix_set, ext_x_map);
-    // bug:
-    // x.append_dis_indexes (ext_dis_ix_set);
-    x.set_dis_indexes (ext_dis_ix_set);
+    // bug: see field_reinterpolate2_tst.cc
+    //    x.set_dis_indexes (ext_dis_ix_set);
+    x.append_dis_indexes (ext_dis_ix_set);
   }
   // -----------------------------------------------------------------------------
   // 3) loop on K and compute hat_x(dis_ix)
@@ -155,7 +155,7 @@ interpolate_pass2_valued (
   const basis_basic<T>& b = fem.get_basis();
   std::vector<size_type> dis_idof;
   std::vector<T>         dof;
-  std::vector<T>         b_value;
+  arma::Col<T>           b_value;
   for (size_type ie = 0, ne = ie2dis_ix.size(); ie < ne; ie++) {
     const index_set&   dis_ix_set = ie2dis_ix [ie];
     if (dis_ix_set.size() == 0) continue;
@@ -255,7 +255,6 @@ interpolate (const space_basic<T,M>& V2h, const field_basic<T,M>& u1h)
   // -----------------------------------------------------------------------------
   // 1) locate each xdof of V2 in omega1
   // -----------------------------------------------------------------------------
-  trace_macro ("reinterpolate with locate: "<<u1h.get_space().stamp()<<" --> " << V2h.stamp());
   const geo_basic<T,M>& omega1 = u1h.get_geo();
   const disarray<point_basic<T>,M>& xdof2 = V2h.get_xdofs();
   disarray<size_type,M> dis_ie1_tab;
