@@ -84,7 +84,7 @@ template <class T>
 static
 bool
 is_zero (const T& x) {
-  // TODO: control by level_set_option_type ?
+  // TODO: control by level_set_option ?
   return fabs(x) <= level_set_epsilon;
 }
 template <class T>
@@ -405,43 +405,6 @@ gamma_list2disarray (
     }
   }
 }
-#ifdef TO_CLEAN
-template <class T, class M>
-void
-gamma_dump (
-  const disarray<point_basic<T>, M>&         gamma_node,
-  const std::array<disarray<element_type,M>, reference_element::max_variant>& gamma_side,
-  size_t                                     d)
-{
-  using namespace std;
-  typedef geo_element::size_type size_type;
-  dout << "mesh" << endl
-       << "4" << endl
-       << "header" << endl
-       << " dimension " << d << endl
-       << " nodes  " << gamma_node.dis_size() << endl;
-  if (d == 3) {
-    if (gamma_side[reference_element::t].dis_size()!= 0) {
-      dout << " triangles "   << gamma_side[reference_element::t].dis_size() << endl;
-    }
-    if (gamma_side[reference_element::q].dis_size()!= 0) {
-      dout << " quadrangles " << gamma_side[reference_element::q].dis_size() << endl;
-    }
-  } else {
-    dout << " edges " << gamma_side[reference_element::e].dis_size() << endl;
-  }
-  dout << "end header" << endl
-       << endl
-       << setprecision(7); // avoid non-regr test to depend upon mach prec
-  gamma_node.put_values (dout, _point_put<T>(d));
-  dout << endl;
-  size_type map_dim = d-1;
-  for (size_type variant = reference_element::first_variant_by_dimension(map_dim);
-                 variant < reference_element:: last_variant_by_dimension(map_dim); variant++) {
-    dout << gamma_side [variant];
-  }
-}
-#endif // TO_CLEAN
 struct to_solve {
   size_t variant, S_ige, k, dis_i;
   to_solve (size_t variant1, size_t S_ige1=0, size_t k1=0, size_t dis_i1=0) 
@@ -451,7 +414,7 @@ template <class T, class M>
 geo_basic<T,M>
 level_set_internal (
     const field_basic<T,M>&      fh,
-    const level_set_option_type& opt,
+    const level_set_option& opt,
     std::vector<size_t>&         bnd_dom_ie_list,
     disarray<size_t,M>&          sid_ie2bnd_ie)
 {
@@ -960,7 +923,7 @@ template <class T, class M>
 geo_basic<T,M>
 level_set (
     const field_basic<T,M>&      fh,
-    const level_set_option_type& opt)
+    const level_set_option& opt)
 {
   typedef geo_element::size_type size_type;
   std::vector<size_type> bnd_dom_ie_list;
@@ -973,12 +936,12 @@ level_set (
 #define _RHEOLEF_instanciation(T,M)                                                     \
 template geo_basic<T,M> level_set_internal (						\
     const field_basic<T,M>&,								\
-    const level_set_option_type&,							\
+    const level_set_option&,							\
     std::vector<size_t>&,								\
     disarray<size_t,M>&);								\
 template geo_basic<T,M> level_set (							\
     const field_basic<T,M>&,								\
-    const level_set_option_type&);
+    const level_set_option&);
 
 _RHEOLEF_instanciation(Float,sequential)
 #ifdef _RHEOLEF_HAVE_MPI
