@@ -45,11 +45,11 @@ DESCRIPTION:
   @example
     class my_problem @{
     public:
-      my_problem();
-      field residue          (const field& uh) const;
-      Float dual_space_norm  (const field& mrh) const;
-      void update_derivative (const field& uh) const;
-      field derivative_solve (const field& mrh) const;
+      typedef value_type;
+      value_type residue          (const value_type& uh)  const;
+      Float dual_space_norm  (const value_type& mrh) const;
+      void update_derivative      (const value_type& uh)  const;
+      value_type derivative_solve (const value_type& mrh) const;
     @};
   @end example
   The @code{dual_space_norm} returns a scalar from the weighted residual field term
@@ -68,7 +68,7 @@ End:
 
 //<newton:
 template <class Problem, class Field>
-int newton (Problem P, Field& uh, Float& tol, size_t& max_iter, odiststream *p_derr = 0) {
+int newton (const Problem& P, Field& uh, Float& tol, size_t& max_iter, odiststream *p_derr = 0) {
     if (p_derr) *p_derr << "# Newton:" << std::endl << "# n r" << std::endl << std::flush;
     for (size_t n = 0; true; n++) {
       Field rh = P.residue(uh);
