@@ -56,10 +56,6 @@ OVERVIEW:
 #include "rheolef/undeterminated.h"
 #include "rheolef/space_constant.h"
 
-#ifdef TO_CLEAN
-#include "rheolef/field_functor.h" // for std::function<> & point_basic
-#endif // TO_CLEAN
-
 namespace rheolef { namespace details {
 
 // ===========================================================================
@@ -437,11 +433,6 @@ struct generic_binary_traits<plus> {
 // --------
 // x-y
 // --------
-#ifdef TO_CLEAN
-struct minus {
-    template <class T> T operator() (const T& a, const T& b) const { return a-b; }
-};
-#endif // TO_CLEAN
 struct minus {
   template <class T1, class T2> 
   typename plus_result<T1,T2>::type operator() (const T1& a, const T2& b) const { return a-b; }
@@ -1722,16 +1713,10 @@ struct function_wrapper {
 };
 template<class Result, class Arg>
 struct function_wrapper<Result(Arg)> {
-#ifdef TO_CLEAN
-  typedef std::pointer_to_unary_function<Arg,Result> type;
-#endif // TO_CLEAN
   typedef std::function<Result(Arg)> type;
 };
 template<class Result, class Arg1, class Arg2>
 struct function_wrapper<Result(Arg1,Arg2)> {
-#ifdef TO_CLEAN
-  typedef std::pointer_to_binary_function<Arg1,Arg2,Result> type;
-#endif // TO_CLEAN
   typedef std::function<Result(Arg1,Arg2)> type;
 };
 
