@@ -67,7 +67,7 @@ End:
 # include "rheolef/rheostream.h"
 # include "rheolef/iorheo.h"
 # include "rheolef/skit.h"
-# include "rheolef/pcg.h"
+# include "rheolef/cg.h"
 # include "rheolef/eye.h"
 # include "rheolef/geo.h"
 # include "rheolef/geo_domain_indirect.h"
@@ -87,7 +87,7 @@ End:
 # include "rheolef/interpolate.h"
 # include "rheolef/integrate.h"
 # include "rheolef/compose.h"
-# include "rheolef/rounder.h"
+# include "rheolef/round.h"
 
 # include "rheolef/form_field_expr.h"
 # include "rheolef/field_vf_assembly.h"
@@ -100,6 +100,7 @@ End:
 # include "rheolef/newton.h"
 # include "rheolef/damped_newton.h"
 # include "rheolef/limiter.h"
+# include "rheolef/continuation.h"
 
 // obsolete: for backward compat.
 # include "rheolef/riesz.h"
