@@ -89,8 +89,11 @@ public:
 // allocators:
 
     space_base_rep ();
+    space_base_rep (
+      		const geo_basic<T,M>&    omega,
+      		std::string              approx,
+      		std::string              valued);
     space_base_rep (const space_constitution<T,M>& constit);
-    space_base_rep (const geo_basic<T,M>& omega, std::string approx, std::string valued);
     space_base_rep (const space_mult_list<T,M>&);
     virtual ~space_base_rep () {}
 
@@ -186,8 +189,10 @@ public:
 
 // allocators:
 
+    space_rep ( const geo_basic<T,sequential>&    omega,
+      		std::string                       approx,
+      		std::string                       valued);
     space_rep (const space_constitution<T,sequential>& constit);
-    space_rep (const geo_basic<T,sequential>& omega, std::string approx, std::string valued);
     space_rep (const space_mult_list<T,sequential>&);
     ~space_rep () {}
 
@@ -217,8 +222,10 @@ public:
 
 // allocators:
 
+    space_rep ( const geo_basic<T,distributed>&   omega,
+      		std::string                       approx,
+      		std::string                       valued);
     space_rep (const space_constitution<T,distributed>& constit);
-    space_rep (const geo_basic<T,distributed>& omega, std::string approx, std::string valued);
     space_rep (const space_mult_list<T,distributed>&);
     ~space_rep () {}
 
@@ -232,18 +239,11 @@ public:
     const distributor& ios_ownership() const { return _ios_idof2dis_idof.ownership(); }
     size_type     idof2ios_dis_idof (size_type     idof) const { base::freeze_guard(); return _idof2ios_dis_idof [idof]; }
     size_type     ios_idof2dis_idof (size_type ios_idof) const { base::freeze_guard(); return _ios_idof2dis_idof [ios_idof]; }
-#ifdef TO_CLEAN
-    void get_ios_dis_idof (const geo_element& K, std::vector<size_type>& ios_dis_idof) const;
-#endif // TO_CLEAN
     const std::set<size_type>& ext_iu_set() const { return _ext_iu_set; }
     const std::set<size_type>& ext_ib_set() const { return _ext_ib_set; }
 
 protected:
     template <class T1, class M1> friend class field_basic;
-    typedef std::map <size_type, size_type, std::less<size_type>,
-            heap_allocator<std::pair<size_type,size_type> > >           map_type;
-    typedef std::map <size_type, space_pair_type, std::less<size_type>,
-            heap_allocator<std::pair<size_type,space_pair_type> > >     map_pair_type;
 // internal procedures:
     void freeze_body() const;
     void append_external_dof (const geo_basic<T,distributed>& dom, std::set<size_type>& ext_dof_set) const;
@@ -304,7 +304,8 @@ public:
 // allocators:
 
     space_basic (const geo_basic<T,sequential>& omega = (geo_basic<T,sequential>()),
-		  std::string approx = "", std::string valued = "scalar");
+		 std::string approx                   = "", 
+                 std::string valued                   = "scalar");
     space_basic (const space_mult_list<T,sequential>& expr);
     space_basic (const space_constitution<T,sequential>& constit);
 
@@ -378,17 +379,17 @@ public:
 template<class T>
 inline
 space_basic<T,sequential>::space_basic (
-    const space_constitution<T,sequential>& constit)
- : base (new_macro(rep(constit)))
+    const geo_basic<T,sequential>& omega,
+    std::string                    approx,
+    std::string                    valued)
+ : base (new_macro(rep(omega, approx, valued)))
 {
 }
 template<class T>
 inline
 space_basic<T,sequential>::space_basic (
-    const geo_basic<T,sequential>& omega,
-    std::string approx,
-    std::string valued)
- : base (new_macro(rep(omega, approx, valued)))
+    const space_constitution<T,sequential>& constit)
+ : base (new_macro(rep(constit)))
 {
 }
 template<class T>
@@ -655,7 +656,8 @@ public:
 // allocators:
 
     space_basic (const geo_basic<T,distributed>& omega = (geo_basic<T,distributed>()),
-		  std::string approx = "", std::string valued = "scalar");
+		 std::string approx                   = "", 
+                 std::string valued                   = "scalar");
     space_basic (const space_mult_list<T,distributed>&);
     space_basic (const space_constitution<T,distributed>& constit);
 
@@ -731,17 +733,17 @@ public:
 template<class T>
 inline
 space_basic<T,distributed>::space_basic (
-    const space_constitution<T,distributed>& constit)
- : base (new_macro(rep(constit)))
+    const geo_basic<T,distributed>& omega,
+    std::string                    approx,
+    std::string                    valued)
+ : base (new_macro(rep(omega, approx, valued)))
 {
 }
 template<class T>
 inline
 space_basic<T,distributed>::space_basic (
-    const geo_basic<T,distributed>& omega,
-    std::string approx,
-    std::string valued)
- : base (new_macro(rep(omega, approx, valued)))
+    const space_constitution<T,distributed>& constit)
+ : base (new_macro(rep(constit)))
 {
 }
 template<class T>
