@@ -32,9 +32,9 @@ namespace rheolef {
 // ======================================================================
 template <class T, class M>
 space_constitution_rep<T,M>::space_constitution_rep (
-    const geo_basic<T,M>& omega,
-    std::string approx,
-    std::string valued)
+    const geo_basic<T,M>&    omega,
+    std::string              approx,
+    std::string              valued)
   : _ownership(),
     _start_by_component(),
     _valued_tag(space_constant::scalar),
@@ -50,7 +50,7 @@ space_constitution_rep<T,M>::space_constitution_rep (
     _valued_tag      = space_constant::valued_tag (valued);
     size_type n_comp = space_constant::n_component (_valued_tag, d, omega.coordinate_system());
     _hier_constit.resize(n_comp);
-    space_constitution<T,M> x (omega, approx);
+    space_constitution<T,M> x (omega, approx, "scalar");
     for (size_type i_comp = 0; i_comp < n_comp; i_comp++) {
       _hier_constit [i_comp] = x;
     }
@@ -170,8 +170,7 @@ put (std::ostream& os, const space_constitution<T,M>& constit, size_t level = 0)
   if (! constit.is_hierarchical()) {
     const space_scalar_constitution<T,M>& scalar_constit = constit.get_scalar();
     if (!scalar_constit.data().is_initialized()) return os; // no numbering available: TODO: scalar_constit.is_initialized()
-    os << scalar_constit.get_numbering().name()
-       << "(" << scalar_constit.get_geo().name() << ")";
+    os << scalar_constit.get_numbering().name() << "(" << scalar_constit.get_geo().name() << ")";
     return os;
   }
   if (constit.valued_tag() == space_constant::vector ||
