@@ -26,6 +26,7 @@ namespace rheolef {
 template <class T, class M>
 test_rep<T,M>::test_rep (const space_type& V)
 : _V(V),
+  _opt(),
   _dom(),
   _basis_on_quad(),
   _is_on_band(false),
@@ -42,6 +43,7 @@ test_rep<T,M>::test_rep (const space_type& V)
 template <class T, class M>
 test_rep<T,M>::test_rep (const test_rep<T,M>& x)
 : _V(x._V),
+  _opt(x._opt),
   _dom(x._dom),
   _basis_on_quad(x._basis_on_quad),
   _is_on_band(x._is_on_band),
@@ -149,7 +151,7 @@ test_rep<T,M>::element_initialize (const geo_element& K) const
       const geo_element& dom_K = _dom.bgd2dom_geo_element (K);
       _dom.dis_inod (dom_K, _dis_inod_K);
     }
-    return _basis_on_quad.size (K);
+    return _basis_on_quad.pointset_size (K);
   } else {
     // find L in the band such that K is the intersected side of L
     // as the zero level set isosurface
@@ -161,12 +163,12 @@ test_rep<T,M>::element_initialize (const geo_element& K) const
     _tilde_L = L.variant();
     _gh.level_set().dis_inod (K, _dis_inod_K);
     _gh.band().dis_inod      (L, _dis_inod_L);
-    return _basis_on_quad.size (_tilde_L);
+    return _basis_on_quad.pointset_size (_tilde_L);
   }
 }
 template <class T, class M>
 typename test_rep<T,M>::size_type
-test_rep<T,M>::element_initialize_on_side (const geo_element& K, const side_information_type& sid)
+test_rep<T,M>::element_initialize_on_side (const geo_element& K, const side_information_type& sid) //BUG with const for DG
 {
   _basis_on_quad.restrict_on_side (K, sid);
   _piola_on_quad.restrict_on_side (K, sid);
@@ -189,6 +191,7 @@ test_rep<T,M>::_basis_evaluate_init (const reference_element& hat_K, size_type q
     check_macro (loc_ndof == get_vf_space().get_constitution().loc_ndof (ref_K), 
 	"invalid value local ndof="<<loc_ndof<<": expect loc_ndof="
   	<<get_vf_space().get_constitution().loc_ndof (ref_K)
+  	<<" with approx " << get_vf_space().get_approx()
         <<" on element variant=" << ref_K.name());
     _basis_on_quad.evaluate (ref_K, q);
   } else {
@@ -206,6 +209,7 @@ template <class T, class M>
 void
 test_rep<T,M>::_basis_evaluate (const reference_element& hat_K, size_type q, std::vector<T>& value) const
 {
+  size_type boq_sz = _basis_on_quad.pointset_size(hat_K);
   _basis_evaluate_init (hat_K, q, value.size());
   for (size_type loc_idof = 0; loc_idof < value.size(); ++loc_idof) {
     value[loc_idof] = _basis_on_quad.value (loc_idof); 
