@@ -19,9 +19,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/nfem/ptst"}
 BINDIR="../pbin"
+SBINDIR="../sbin"
 NPROC_MAX=${NPROC_MAX-"3"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
@@ -44,7 +45,7 @@ square_q_bamg
 square_tq_bamg
 "
 for geo in $L; do
-  run "cat ${SRCDIR}/${geo}.bamg ${dmn} | ${BINDIR}/geo -if bamg -geo - 2>/dev/null | diff -Bw ${SRCDIR}/${geo}.geo - >/dev/null"
+  run "${SBINDIR}/bamg2geo ${SRCDIR}/${geo}.bamg ${dmn} 2>/dev/null | diff -Bw ${SRCDIR}/${geo}.geo - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
 
@@ -56,7 +57,7 @@ L="
 square_t_bamg
 "
 for geo in $L; do
-  run "cat ${SRCDIR}/${geo}.bamg ${dmn} | ${BINDIR}/geo -if bamg -geo - 2>/dev/null | diff -Bw ${SRCDIR}/${geo}_vertex_dom.geo - >/dev/null"
+  run "${SBINDIR}/bamg2geo ${SRCDIR}/${geo}.bamg ${dmn} 2>/dev/null | diff -Bw ${SRCDIR}/${geo}_vertex_dom.geo - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
 
