@@ -32,4 +32,6 @@ NPROC_MAX=${NPROC_MAX-"3"}
 #exit 0
 
 loop_mpirun "./compose_tst $SRCDIR/carre-v2.geo >/dev/null 2>/dev/null"
+status=$?
 
+exit $status
