@@ -57,7 +57,7 @@ compute_error_s (
   const point_basic<std::string>& u_expr,
   const point_basic<std::string>& n_expr,
   const point_basic<symbol>&      x,
-  const quadrature_option_type&   qopt)
+  const quadrature_option&   qopt)
 {
   space Xh (omega, approx, "vector");
   size_t k = Xh.degree();
@@ -86,7 +86,7 @@ compute_error_band (
   const point_basic<std::string>& u_expr,
   const point_basic<std::string>& n_expr,
   const point_basic<symbol>&      x,
-  const quadrature_option_type&   qopt)
+  const quadrature_option&   qopt)
 {
   space Xh  (lambda, approx);
   field phi_h = interpolate(Xh, phi);
@@ -99,7 +99,7 @@ compute_error_band (
   space Xbh (gh.band(), approx,      "vector");
   space Tbh (gh.band(), grad_approx, "tensor");
   trial u (Xbh), sigma (Tbh); test v (Xbh), tau (Tbh);
-  form_option_type fopt (qopt);
+  integrate_option fopt (qopt);
   fopt.invert = true;
   form inv_m  = integrate (gh, ddot(sigma,tau), fopt);
   form ds     = integrate (gh, ddot(Ds(u), tau), qopt);
@@ -123,9 +123,9 @@ int main(int argc, char**argv) {
     string approx = (argc > 2) ?      argv[2]  : "P1";
     size_t q      = (argc > 3) ? atoi(argv[3]) : 12;
     Float tol     = (argc > 4) ? atof(argv[4]) : 1e-10;
-    quadrature_option_type qopt;
+    quadrature_option qopt;
     qopt.set_order  (q);
-    qopt.set_family (quadrature_option_type::gauss);
+    qopt.set_family (quadrature_option::gauss);
 
     size_t d = omega.dimension();
     point_basic<symbol> x (symbol("x"),symbol("y"),symbol("z"));
