@@ -19,9 +19,8 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
-SRCDIR=${SRCDIR-"."}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/nfem/ptst"}
 NPROC_MAX=${NPROC_MAX-"3"}
 DATADIR=$SRCDIR
 BINDIR="../pbin"
