@@ -20,14 +20,13 @@
 /// =========================================================================
 // check field_indirect_const::const_iterator
 #include "rheolef.h"
-#include "rheolef/rounder.h"
 using namespace rheolef;
 using namespace std;
 Float g (const point& x) { return sin(x[0]+x[1]+0.5); }
 void ff (const field& gh, const field fh, string dom_name, Float prec) {
   field zh (gh.get_space());
   zh = 0.5*(gh + fh[dom_name]);
-  dout << setprecision(15) << field(compose (rounder(prec),zh));
+  dout << round (zh, prec);
 }
 int main(int argc, char**argv) {
   environment rheolef(argc, argv);
