@@ -37,11 +37,7 @@ int main(int argc, char**argv) {
   space Zh (omega, "P1", "vector");
   field xh (Xh,1), yh(Xh,1);
   field zh (Zh,1), th(Zh,1);
-  // field expr: vector <- scalar*vector
-#ifdef TODO // boost::proto-1.54 & g++-4.8
   field uh = interpolate(Zh, (2*xh + yh)*(3*zh + th - zh));
-#endif // TODO
-  field uh = interpolate(Zh, field(2*xh + yh)*field(3*zh + th - zh));
   field uh_expect (Zh, 9);
   Float err = field(uh - uh_expect).max_abs();
   derr << "err = " << err << endl;
