@@ -21,8 +21,8 @@
 # -------------------------------------------------------------------------
 # note: do not check output, only check the compilation
 #
-SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/nfem/ptst"}
 NPROC_MAX=${NPROC_MAX-"2"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
