@@ -19,8 +19,8 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/nfem/ptst"}
 NPROC_MAX=${NPROC_MAX-"3"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
@@ -46,7 +46,7 @@ interpolate-circle_p3-v2
 "
 for x in $L; do
   for Pk in P1 P2 P3 P0 P1d; do
-    loop_mpirun "./field_io_tst 1e-10 < ${SRCDIR}/$x-$Pk.field 2>/dev/null | diff -w -B ${SRCDIR}/$x-$Pk.field - >/dev/null"
+    loop_mpirun_raw "RHEOPATH=$SRCDIR \$RUN ./field_io_tst 1e-10 < ${SRCDIR}/$x-$Pk.field 2>/dev/null | diff -w -B ${SRCDIR}/$x-$Pk.field - >/dev/null"
     if test $? -ne 0; then status=1; fi
   done
 done
@@ -60,7 +60,7 @@ interpolate_dom-cube-gmsh-v2-right
 "
 for x in $L; do
   for Pk in P0 P1 P1d P2; do
-    loop_mpirun "./field_io_tst 1e-10 < ${SRCDIR}/$x-$Pk.field 2>/dev/null | diff -w -B ${SRCDIR}/$x-$Pk.field - >/dev/null"
+    loop_mpirun_raw "RHEOPATH=$SRCDIR \$RUN ./field_io_tst 1e-10 < ${SRCDIR}/$x-$Pk.field 2>/dev/null | diff -w -B ${SRCDIR}/$x-$Pk.field - >/dev/null"
     if test $? -ne 0; then status=1; fi
   done
 done
