@@ -45,14 +45,14 @@ int main(int argc, char**argv) {
     trial u (Xh); test v (Xh);
     trial p (Th); test q (Th);
     field uh = interpolate (Xh, f1());
-    form_option_type fopt;
+    integrate_option fopt;
     fopt.invert = true;
     form inv_mass = integrate (dot(p,q), fopt);
     form mgrad = integrate (dot(grad(u),q));
     field grad_uh = inv_mass*(mgrad*uh);
   
     // 1.1) grad(uh) in integrate()
-    quadrature_option_type qopt;
+    quadrature_option qopt;
     qopt.set_order(5);
     Float err1 = integrate (omega, norm(grad(uh)-grad_uh), qopt);
     derr << "err1 = " << err1 << endl;
@@ -78,14 +78,14 @@ warning_macro ("main[1.2.c]...");
     trial u (Xh);     test v (Xh);
     trial sigma (Th); test tau (Th);
     field uh = interpolate (Xh, f2());
-    form_option_type fopt;
+    integrate_option fopt;
     fopt.invert = true;
     form inv_mass = integrate (ddot(sigma,tau), fopt);
     form mD = integrate (ddot(D(u),tau));
     field D_uh = inv_mass*(mD*uh);
 
     // 2.1) D(uh) in integrate()
-    quadrature_option_type qopt;
+    quadrature_option qopt;
     qopt.set_order(5);
     Float err3 = integrate (omega, norm(D(uh)-D_uh), qopt);
     derr << "err3 = " << err3 << endl;
@@ -108,14 +108,14 @@ warning_macro ("main[1.2.c]...");
     trial u (Xh); test v (Xh);
     trial p (Th); test q (Th);
     field uh = interpolate (Xh, f2());
-    form_option_type fopt;
+    integrate_option fopt;
     fopt.invert = true;
     form inv_mass = integrate (p*q, fopt);
     form m_div = integrate (div(u)*q);
     field div_uh = inv_mass*(m_div*uh);
 
     // 3.1) in integrate()
-    quadrature_option_type qopt;
+    quadrature_option qopt;
     qopt.set_order(5);
     Float err5 = integrate (omega, abs(div(uh)-div_uh), qopt);
     derr << "err5 = " << err5 << endl;
