@@ -36,27 +36,21 @@ int main(int argc, char**argv) {
   geo omega2 (argv[2]);
   Float tol       = (argc > 3) ?    atof(argv[3]) : 1e-7;
   bool  use_expr  = (argc > 4) ? (string(argv[4]) == "-expression") : false;
+  dis_warning_macro ("use_expr="<<use_expr);
   space V1h (omega1, "P1");
   space V2h (omega2, "P1");
   field u1h = interpolate (V1h, u());
   // mpirun -np 2 ./field_reinterpolate_tst ../../../rheolef/nfem/ptst/line-3-bdry.geo ../../../rheolef/nfem/ptst/line-20-bdry.geo
   //        fatal{0}(../../include/rheolef/disarray_mpi.icc,523): unexpected external index=10
-#define HAVE_BUG
-#ifdef  HAVE_BUG
   field u2h     = interpolate (V2h, u1h);
-#endif // HAVE_BUG
   field u2h_bis = use_expr ? interpolate (V2h, u()*1)  // expression -> element-based Lagrange interpolate version
                            : interpolate (V2h, u());   // function   -> xdof-based Lagrange interpolate version
   // => goes to thegeneral details::interpolate_check on a bdr space (geo_domain) :
   //    perhaps a memory corruption in field_expr_v2_nonlinear_terminal_function<F> ?
   //    or in reinterpolate on a different mesh (locate,nearest) in the distributed case
   //    bcause when we swap the two statements, the previous mpirun is ok...:-(
-#ifdef HAVE_BUG
   field eh = u2h - u2h_bis;
   Float err = dual(eh,eh);
   derr << "err = " << err << endl;
   return (err < tol) ? 0 : 1;
-#else // HAVE_BUG
-  return 0;
-#endif // HAVE_BUG
 }
