@@ -31,7 +31,7 @@ int main (int argc, char **argv) {
   space Xh (omega, "P1");
   form m (Xh, Xh, "mass");
   form a (Xh, Xh, "grad_grad");
-  form c = { {m, 0},
-             {0, a} };
+  form c = { {m,        Float(0)},
+             {Float(0), a} };
 #endif // _RHEOLEF_HAVE_STD_INITIALIZER_LIST
 }
