@@ -46,7 +46,7 @@ int
 compute_error_s (
   const geo&                    omega,
   const string&                 approx,
-  const quadrature_option_type& qopt,
+  const quadrature_option& qopt,
   const Float&                  tol,
   bool                          test_normal)
 {
@@ -77,7 +77,7 @@ int
 compute_error_band (
   const geo&                    lambda,
   const string&                 approx,
-  const quadrature_option_type& qopt,
+  const quadrature_option& qopt,
   const Float&                  tol,
   bool                          test_normal)
 {
@@ -141,8 +141,8 @@ compute_error_band (
 // usage: prog mesh.geo [-normal|-polynom] [-band] qorder tol
 int main (int argc, char**argv) {
   environment rheolef (argc, argv);
-  quadrature_option_type qopt;
-  qopt.set_family (quadrature_option_type::gauss);
+  quadrature_option qopt;
+  qopt.set_family (quadrature_option::gauss);
   geo omega (argv[1]);
   bool test_normal = false;
   int io = 2;
