@@ -19,9 +19,12 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/nfem/ptst"}
 NPROC_MAX=${NPROC_MAX-"20"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 run "./geo_specs_tst 2>/dev/null >/dev/null"
+status=$?
+
+exit $status
