@@ -39,7 +39,8 @@ circle_p2-v2
 "
 
 for geo in $L; do
-  run "../pbin/geo -geo -subdivide 2 - < ${SRCDIR}/$geo.geo 2>/dev/null | diff -B -w ${SRCDIR}/${geo}-nsub-2.geo - >/dev/null"
+  run "../pbin/geo -geo -subdivide 2 -round - < ${SRCDIR}/$geo.geo 2>/dev/null | diff -B -w ${SRCDIR}/${geo}-nsub-2.geo - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
 
+exit $status
