@@ -19,15 +19,19 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 # -------------------------------------------------------------------------
-SRCDIR=${SRCDIR-"."}
-TOP_SRCDIR=${TOP_SRCDIR-"../.."}
+TOP_SRCDIR=${TOP_SRCDIR-"../../../rheolef"}
+SRCDIR=${SRCDIR-"$TOP_SRCDIR/nfem/ptst"}
 BINDIR="../pbin"
+SBINDIR="../sbin"
 NPROC_MAX=${NPROC_MAX-"3"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
 export TMPDIR="."
 ZDIFF="$TOP_SRCDIR/config/zdiff"
 
+#echo "      not yet (skiped)"
+#exit 0
+
 if test x"${QD_EXT}" != x""; then
   echo "      not yet (skiped when QD lib is active)"
   exit 0
@@ -35,9 +39,14 @@ fi
 
 status=0
 
-L="
+L_1D="
 edge_s_2d_p9
 edge_s_3d_p9
+circle_s_p1
+circle_s_p2
+"
+
+L_2D="
 triangle_p1
 triangle_p2
 triangle_p3
@@ -49,6 +58,20 @@ quadrangle_p1
 quadrangle_p2
 quadrangle_p9
 quadrangle_s_p9
+circle_p1
+circle_p2
+circle_p5
+circle_q_p1
+circle_q_p2
+sphere_s_p1
+sphere_s_p2
+sphere_s_p10
+sphere_s_q_p1
+sphere_s_q_p2
+sphere_s_q_p10
+"
+
+L_3D="
 tetra_p1
 tetra_p2
 tetra_p3
@@ -62,19 +85,6 @@ tetra2_p9
 prism_p1
 hexa_p1
 hexa_p1
-circle_p1
-circle_p2
-circle_p5
-circle_q_p1
-circle_q_p2
-circle_s_p1
-circle_s_p2
-sphere_s_p1
-sphere_s_p2
-sphere_s_p10
-sphere_s_q_p1
-sphere_s_q_p2
-sphere_s_q_p10
 sphere_p1
 sphere_p2
 sphere_p3
@@ -82,6 +92,7 @@ sphere_p9
 sphere_H_p1
 sphere_H_p2
 "
+
 # gmsh change its gnerated .msh when changing gmsh version (TODO: upgrade all my_cube*.field files)
 L_UPGRADE_GMSH="
 my_cube_TP-5
@@ -93,8 +104,16 @@ L_TODO="
 prism_p2
 "
 
+L="
+$L_1D
+$L_2D
+$L_3D
+"
+
 for geo in $L; do
-  run "${BINDIR}/msh2geo_int < ${SRCDIR}/${geo}.msh 2>/dev/null | diff -B -w ${SRCDIR}/${geo}-v1.geo - >/dev/null"
+  run "${SBINDIR}/msh2geo -noupgrade < ${SRCDIR}/${geo}.msh 2>/dev/null | diff -B -w ${SRCDIR}/${geo}-v1.geo - >/dev/null"
+  if test $? -ne 0; then status=1; fi
+  run "${SBINDIR}/msh2geo   -upgrade < ${SRCDIR}/${geo}.msh 2>/dev/null | diff -B -w ${SRCDIR}/${geo}-v2.geo - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
 
