@@ -34,7 +34,7 @@ space_constitution_io_complex.valid
 "
 export RHEOPATH=".:${SRCDIR}"
 for x in $L; do
-  loop_mpirun "./space_constitution_io_tst < ${SRCDIR}/$x 2>/dev/null | diff -Bw $SRCDIR/$x - >/dev/null"
+  loop_mpirun_raw "RHEOPATH=${SRCDIR} \$RUN ./space_constitution_io_tst < ${SRCDIR}/$x 2>/dev/null | diff -Bw $SRCDIR/$x - >/dev/null"
   if test $? -ne 0; then status=1; fi
 done
 
