@@ -28,10 +28,6 @@
 using namespace rheolef;
 using namespace std;
 int main (int argc, char **argv) {
-#ifdef _RHEOLEF_HAVE_QD
-        unsigned int oldcw;
-        fpu_fix_start(&oldcw);
-#endif // _RHEOLEF_HAVE_QD
 	size_t R  = argc > 1 ? atoi(argv[1]) : 5;
         Float tol = argc > 2 ? Float(atof(argv[2])) : sqrt(numeric_limits<Float>::epsilon());
 	if (R == 0) return 0;
@@ -45,8 +41,5 @@ int main (int argc, char **argv) {
 	    cout << r << "\t" << zeta[r] << "\t" << omega[r] << endl;
 	Float err = gauss_legendre_check (R, zeta.begin(), omega.begin(), 2*R-1);
 	if (err >= tol) cerr << "err = " << err << endl;
-#ifdef _RHEOLEF_HAVE_QD
-        fpu_fix_end(&oldcw);
-#endif // _RHEOLEF_HAVE_QD
         return err < tol ? 0 : 1;
 }
