@@ -19,9 +19,11 @@
 /// 
 /// =========================================================================
 #include "sqr.h"
+namespace rheolef {
 template <class T> T pythag(T a, T b) {
         T absa = fabs (a);
         T absb = fabs (b);
         if (absa > absb)     return absa*sqrt (1.0 + sqr (absb/absa));
         return (absb == T(0.0) ? T(0.0) : absb*sqrt (1.0 + sqr (absa/absb)));
 }
+} // namepace rheolef
