@@ -181,13 +181,25 @@ void put_right() {
         for (size_t k = 0; k < nz; k++) {
 	    if (type == TETRA) {
 	        print_triangle(no(i,ny,k), no(i+1,ny,k+1), no(i+1,ny,k)); 
-	        print_triangle(no(i,ny,k), no(i,ny,k+1), no(i+1,ny,k+1));
+	        print_triangle(no(i,ny,k), no(i,  ny,k+1), no(i+1,ny,k+1));
 	    } else {
 		print_rectangle (no(i,ny,k), no(i,ny,k+1), no(i+1,ny,k+1), no(i+1,ny,k));
 	    }
 	}
     }
 }
+void put_interface() {
+    for (size_t i = 0; i < nx; i++) {
+        for (size_t k = 0; k < nz; k++) {
+	    if (type == TETRA) {
+	        print_triangle(no(i,ny/2,k), no(i+1,ny/2,k+1), no(i+1,ny/2,k)); 
+	        print_triangle(no(i,ny/2,k), no(i,  ny/2,k+1), no(i+1,ny/2,k+1));
+	    } else {
+		print_rectangle (no(i,ny/2,k), no(i,ny/2,k+1), no(i+1,ny/2,k+1), no(i+1,ny/2,k));
+	    }
+	}
+    }
+}
 void put_back() {
     for (size_t j = 0; j < ny; j++) {
         for (size_t k = 0; k < nz; k++)  {
@@ -214,10 +226,6 @@ main (int argc, char**argv)
     // machine-dependent precision
     int digits10 = numeric_limits<Float>::digits10;
     cout << setprecision(digits10);
-#ifdef _RHEOLEF_HAVE_QD
-    unsigned int oldcw;
-    fpu_fix_start(&oldcw);
-#endif // _RHEOLEF_HAVE_QD
 
     // parse command line 
     for (int i = 1; i < argc; i++) {
@@ -323,9 +331,9 @@ main (int argc, char**argv)
     for (size_t k = 0; k <= nz; k++)
       for (size_t j = 0; j <= ny; j++)
         for (size_t i = 0; i <= nx; i++)
-	   cout << A+(B-A)*i/Float(nx) << " "
-	        << C+(D-C)*j/Float(ny) << " "
-	        << F+(G-F)*k/Float(nz) << endl;
+	   cout << A+(B-A)*i/Float(int(nx)) << " "
+	        << C+(D-C)*j/Float(int(ny)) << " "
+	        << F+(G-F)*k/Float(int(nz)) << endl;
     // connectivity
     for (size_t i = 0; i < nx; i++) 
       for (size_t j = 0; j < ny; j++) 
@@ -398,6 +406,8 @@ main (int argc, char**argv)
 			no(i,j,k),   no(i+1,j,k),   no(i+1,j+1,k),   no(i,j+1,k),
 			no(i,j,k+1), no(i+1,j,k+1), no(i+1,j+1,k+1), no(i,j+1,k+1));
 	    cout << endl;
+            print_domain("interface", (type == TETRA) ? 2*nx*ny : nx*ny);
+	    put_interface();
     }
     // corners = 4 0d-domains
     if (corner) {
@@ -411,8 +421,4 @@ main (int argc, char**argv)
                  << "\ndomain\nright_top_back\n1 0 1\n"     << no(0, ny,nz) << endl
 		 << endl;
     }
-#ifdef _RHEOLEF_HAVE_QD
-  fpu_fix_end(&oldcw);
-#endif // _RHEOLEF_HAVE_QD
 }
-
