@@ -27,10 +27,10 @@ NPROC_MAX=${NPROC_MAX-"1"}
 
 status=0
 
-run "./form_convect_dg_nh2_tst ../data/carre-v2.geo.gz    0.004 >/dev/null 2>/dev/null"
+run "./form_convect_dg_nh2_tst $TOP_SRCDIR/nfem/data/carre-v2.geo.gz    0.004 >/dev/null 2>/dev/null"
 if test $? -ne 0; then status=1; echo "        => *NO*"; fi
 
-run "./form_convect_dg_nh2_tst ../data/square-bamg.geo.gz 0.003 >/dev/null 2>/dev/null"
+run "./form_convect_dg_nh2_tst $TOP_SRCDIR/nfem/data/square-bamg.geo.gz 0.003 >/dev/null 2>/dev/null"
 if test $? -ne 0; then status=1; echo "        => *NO*"; fi
 
 exit ${status}
