@@ -21,7 +21,7 @@
 # -------------------------------------------------------------------------
 status=0
 
-command="../bin/mkgeo_grid_2d 10 | ../bin/geo -upgrade -geo - > mesh-2d.geo"
+command="../sbin/mkgeo_grid_2d 10 | ../bin/geo -upgrade -geo - > mesh-2d.geo"
 echo "      $command"
 eval $command 2>/dev/null
 if test $? -ne 0; then status=1; echo "        => *NO*"; exit 1; fi
