@@ -229,11 +229,7 @@ END: */
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
 //  2. Regular square case
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
-#ifdef _RHEOLEF_HAVE_DOUBLEDOUBLE
-static const Float pi = doubledouble::Pi;
-#else
 static const Float pi = acos(Float(-1.)); // pi
-#endif
 static const Float omega = pi;
 
 Float u_reg_2d (const point& x) {
