@@ -657,11 +657,11 @@ def mayavi2_field_scalar (view, basename, option):
     #print "mm.scalar_lut_manager = ", mm.scalar_lut_manager
     if not option['view_1d'] and option['color'] != 'black_and_white' and mm != None:
         mm.scalar_lut_manager.show_scalar_bar = True
-        if option['label'] != "output" and (option['name'] != "scalars" and option['name'] != "scalar" and option['name'] != "unamed"):
+        if option['label'] != "output" and (option['name'] != "scalars" and option['name'] != "scalar" and option['name'] != "unnamed"):
             title = option['name'] + ": " + option['label']
         elif option['label'] != "output":
             title = option['label']
-        elif (option['name'] != "scalars" and option['name'] != "scalar" and option['name'] != "unamed"):
+        elif (option['name'] != "scalars" and option['name'] != "scalar" and option['name'] != "unnamed"):
             title = option['name']
         else:
             title = ""
