@@ -67,7 +67,6 @@ def build_isovalue_list (option):
     for i in range(1,n_iso):
        iso_value[i] = f_min + 1.*i*(f_max-f_min)/n_iso
     iso_value[n_iso] = f_max
-    #print "iso_value=", iso_value
     return iso_value
 
 # --------------------------------------------------------------------------
@@ -154,6 +153,9 @@ def make_color_bar (option):
       # paraview-3
       0;
     color_bar = CreateScalarBar(Title=name, Enabled=1, LabelFontSize=12, LabelColor=[0, 0, 0], LookupTable=color_map, TitleFontSize=12, TitleColor=[0, 0, 0])
+    color_bar.ComponentTitle = "";
+    try: color_bar.WindowLocation = 'LowerLeftCorner'
+    except: 0; # old paraview
     return color_bar
 
 # --------------------------------------------------------------------------
@@ -173,7 +175,6 @@ def do_final_render(paraview,basename,option):
     import os.path
     basename = os.path.basename(basename)
     filename = basename+"."+file_format
-    #print "filename=",filename
     from os import remove
     from os.path import exists
     if exists(filename):
@@ -281,7 +282,6 @@ def do_final_render(paraview,basename,option):
     if format == "pdf" and exists(filename+".gz"):
       import os
       command="mv %s.gz %s"%(filename,filename)
-      #print "!", command
       os.system (command)
     if exists(filename):
       print "! output written to \"%s\""%(filename)
@@ -319,7 +319,7 @@ def do_render(paraview, name, option):
       render.CameraParallelScale = max(dx[0],dx[1])/sqrt(2.0)
       z_camera = 1+sqrt(3)
       render.CameraPosition      = [xg[0], xg[1], z_camera]
-      render.CameraClippingRange = [0.99*z_camera, 1.015*z_camera]
+     #render.add_attribute("CameraClippingRange", [0.99*z_camera, 1.015*z_camera]);
       render.CameraViewUp        = [0, 1, 0]
       render.CameraViewAngle     = 30
     else:
@@ -366,7 +366,7 @@ def paraview_field_2d_scalar_color (paraview, basename, option):
     iso_contour.ScalarOpacityFunction = color_fct
     iso_contour.LookupTable           = color_map
     iso_contour.AmbientColor         = [0, 0, 0]
-    iso_contour.CubeAxesColor        = [0, 0, 0]
+   #iso_contour.CubeAxesColor        = [0, 0, 0]
     iso_contour.EdgeColor            = [0, 0, 0.5]
     iso_contour.BackfaceDiffuseColor = [0.3333333333333333, 0.6666666666666666, 1]
     iso_contour.DiffuseColor         = [0.3333333333333333, 0.6666666666666666, 1]
@@ -456,7 +456,7 @@ def paraview_field_2d_scalar_elevation (paraview, basename, option):
     warp_show.ScaleFactor = 1
     warp_show.DiffuseColor         = [0, 0, 0]
     warp_show.AmbientColor         = [0, 0, 0]
-    warp_show.CubeAxesColor        = [0, 0, 0]
+   #warp_show.CubeAxesColor        = [0, 0, 0]
     warp_show.BackfaceDiffuseColor = [0, 0, 0]
     warp_show.EdgeColor            = [0, 0, 0.5]
     warp_show.ScalarOpacityUnitDistance = 0.15254729527751434
@@ -474,6 +474,7 @@ def paraview_field_2d_scalar_bicolor (paraview, basename, option):
 	GetLookupTableForArray, CreateScalarBar, Calculator, Contour, IsoVolume, Show, \
 	SetActiveSource, GetRenderView, Render, Text
 
+    render = GetRenderView()
     f_min = option['range'][0]
     f_max = option['range'][1]
     eps = 1e-16
@@ -485,6 +486,7 @@ def paraview_field_2d_scalar_bicolor (paraview, basename, option):
     paraview.simple._DisableFirstRenderCameraReset()
 
     data = LegacyVTKReader( FileNames=[basename+".vtk"] )
+    data.UpdatePipeline()
     # --------------------------- 
     # two color maps
     # --------------------------- 
@@ -497,6 +499,9 @@ def paraview_field_2d_scalar_bicolor (paraview, basename, option):
     negative_color_map.VectorMode = 'Magnitude'
     negative_color_map.NanColor   = [0, 0, 0]
     negative_color_map.NumberOfTableValues = option['n_isovalue_negative']
+    negative_color_map.RescaleTransferFunction(f_min, 0);
+    negative_color_map.ScalarRangeInitialized = 1
+    negative_color_map.LockDataRange = True;
     try:
       # paraview-4.1:
       negative_color_map.ScalarOpacityFunction = negative_color_fct
@@ -506,14 +511,17 @@ def paraview_field_2d_scalar_bicolor (paraview, basename, option):
 #   negative_color_map.IndexedColors = [1, 0,                 0, \
 #                                       1, 0.862745098039215, 0, \
 #                                       0, 0.695201037613489, 0]
-    negative_color_map.ScalarRangeInitialized = 1
-    negative_color_map.LockScalarRange = 1
+    try:
+      negative_color_map.LockScalarRange = 1 ; # backward compat pb
+    except:
+      0
     try:
       # paraview-4.1:
       negative_color_map.Annotations = ["%.15g"%(f_min), "%.7g"%(f_min), \
                                         "0",            "0"]
     except:
       0
+
     positive_color_fct = CreatePiecewiseFunction()
     positive_color_fct.Points = [ 0,   0,   0.5, 0, \
                                   0.5, 0.5, 0.5, 0, \
@@ -526,8 +534,13 @@ def paraview_field_2d_scalar_bicolor (paraview, basename, option):
     positive_color_map.VectorMode = 'Magnitude'
     positive_color_map.NanColor = [0, 0, 0]
     positive_color_map.NumberOfTableValues = option['n_isovalue'] - option['n_isovalue_negative']
+    positive_color_map.RescaleTransferFunction(0,f_max);
     positive_color_map.ScalarRangeInitialized = 1
-    positive_color_map.LockScalarRange        = 1
+    positive_color_map.LockDataRange = True;
+    try:
+      positive_color_map.LockScalarRange        = 1; # backward compat pb
+    except:
+      0
     #positive_color_map.ScalarOpacityFunction = positive_color_fct
     try:
       # paraview-4.1:
@@ -540,12 +553,12 @@ def paraview_field_2d_scalar_bicolor (paraview, basename, option):
     negative_color_bar.LookupTable =  negative_color_map
     negative_color_bar.Title       = ' ' 
     negative_color_bar.Position  = [0.93, 0.25]
-    negative_color_bar.Position2 = [0.13, 0.5]
+#    negative_color_bar.Position2 = [0.13, 0.5]; # backward compat pb
     negative_color_bar.Enabled       = 1
     negative_color_bar.Selectable    = 1
     negative_color_bar.LabelShadow   = 1
     negative_color_bar.AutomaticLabelFormat = 0
-    negative_color_bar.NumberOfLabels = 1
+#   negative_color_bar.NumberOfLabels = 1; # backward compat pb
     negative_color_bar.TitleFontSize = 10
     negative_color_bar.LabelFontSize = 10
     negative_color_bar.TitleColor    = [0, 0, 0]
@@ -555,16 +568,17 @@ def paraview_field_2d_scalar_bicolor (paraview, basename, option):
     positive_color_bar.LookupTable =  positive_color_map
     positive_color_bar.Title       = ' '
     positive_color_bar.Position  = [0.85, 0.4]
-    positive_color_bar.Position2 = [0.13, 0.5]
+#   positive_color_bar.Position2 = [0.13, 0.5]; # backward compat pb
     positive_color_bar.Enabled     = 1
     positive_color_bar.Selectable  = 1
     positive_color_bar.LabelShadow = 1
     positive_color_bar.AutomaticLabelFormat = 0
-    positive_color_bar.NumberOfLabels = 1
+#   positive_color_bar.NumberOfLabels = 1; # backward compat pb
     positive_color_bar.TitleFontSize = 10
     positive_color_bar.LabelFontSize = 10
     positive_color_bar.TitleColor = [0, 0, 0]
     positive_color_bar.LabelColor = [0, 0, 0]
+
     # ----------------------------
     # title for the two color bars
     # ----------------------------
@@ -576,6 +590,7 @@ def paraview_field_2d_scalar_bicolor (paraview, basename, option):
       title_show.FontFamily = 'Times'
       title_show.FontSize   = 12
       title_show.Justification = 'Center'
+      title_show.WindowLocation = 'AnyLocation'
       title_show.Position   = [0.5, 0.95]
     # --------------------------- 
     # negative part, in backgroud
@@ -591,11 +606,15 @@ def paraview_field_2d_scalar_bicolor (paraview, basename, option):
     negative_show.ScalarOpacityFunction = negative_color_fct
     negative_show.LookupTable           = negative_color_map
     negative_show.AmbientColor  = [0, 0, 0]
-    negative_show.CubeAxesColor = [0, 0, 0]
+   #negative_show.CubeAxesColor = [0, 0, 0]
     negative_show.EdgeColor     = [0, 0, 0.5]
     negative_show.ScalarOpacityUnitDistance = 0.4027013671755797
     if option['color'] != 'color': 
       negative_show.Visibility = 0
+    negative_show.SetScalarBarVisibility(render, False)
+    negative_show.UpdatePipeline()
+    #try: negative_show.RescaleTransferFunctionToDataRange(False, True)
+    #except: 0; # old paraview
     # ----------------------------------------
     # positive part, in foregroud, with a mask
     # ----------------------------------------
@@ -622,13 +641,17 @@ def paraview_field_2d_scalar_bicolor (paraview, basename, option):
       positive_show.DiffuseColor   = [gray, gray, gray]
     positive_show.Representation = 'Surface'
     positive_show.AmbientColor  = [0, 0, 0]
-    positive_show.CubeAxesColor = [0, 0, 0]
+   #positive_show.CubeAxesColor = [0, 0, 0]
     positive_show.ScaleFactor = 1
     positive_show.ScalarOpacityUnitDistance = 0.16539091500936676
     positive_show.BackfaceDiffuseColor = [1, 1, 1]
     positive_show.AmbientColor         = [0, 0, 0]
-    positive_show.CubeAxesColor        = [0, 0, 0]
+   #positive_show.CubeAxesColor        = [0, 0, 0]
     positive_show.EdgeColor            = [0, 0, 0]
+   # before deactivating "rescale to data range":
+    positive_show.UpdatePipeline()
+    try: positive_show.RescaleTransferFunctionToDataRange(False, True)
+    except: 0; # old paraview
     # ----------------------------------------
     # isolines
     # ----------------------------------------
@@ -642,7 +665,7 @@ def paraview_field_2d_scalar_bicolor (paraview, basename, option):
       contour_show.SelectionPointFieldDataArrayName = 'scalar'
       contour_show.DiffuseColor  = [0, 0, 0]
       contour_show.AmbientColor  = [0, 0, 0]
-      contour_show.CubeAxesColor = [0, 0, 0]
+     #contour_show.CubeAxesColor = [0, 0, 0]
       contour_show.EdgeColor     = [0, 0, 0.5]
     
     if option['label'] == 1 and option['color'] == 'color': 
@@ -688,7 +711,7 @@ def paraview_field_3d_scalar (paraview, basename, option):
     #outline_show.SelectionPointFieldDataArrayName = 'scalar'
     outline_show.DiffuseColor         = [0, 0, 0]
     outline_show.AmbientColor         = [0, 0, 0]
-    outline_show.CubeAxesColor        = [0, 0, 0]
+   #outline_show.CubeAxesColor        = [0, 0, 0]
     outline_show.BackfaceDiffuseColor = [0, 0, 0]
     outline_show.EdgeColor            = [0, 0, 0.5]
     
@@ -709,7 +732,7 @@ def paraview_field_3d_scalar (paraview, basename, option):
       volume_show.LookupTable           = color_map
       volume_show.ScalarOpacityFunction = color_fct
       volume_show.AmbientColor  = [0, 0, 0]
-      volume_show.CubeAxesColor = [0, 0, 0]
+     #volume_show.CubeAxesColor = [0, 0, 0]
       volume_show.EdgeColor     = [0, 0, 0.5]
       volume_show.ScalarOpacityUnitDistance = 0.09531842929969365
     else:
@@ -733,7 +756,7 @@ def paraview_field_3d_scalar (paraview, basename, option):
         clip_show.DiffuseColor         = [1, 1, 1]
         clip_show.BackfaceDiffuseColor = [1, 1, 1]
         clip_show.AmbientColor         = [0, 0, 0]
-        clip_show.CubeAxesColor        = [0, 0, 0]
+       #clip_show.CubeAxesColor        = [0, 0, 0]
         clip_show.EdgeColor            = [0, 0, 0]
       else: # all except P0: P1, P1d, P2, etc
         # -------------------------------
@@ -756,7 +779,7 @@ def paraview_field_3d_scalar (paraview, basename, option):
           iso_show.LookupTable = color_map
         iso_show.DiffuseColor         = [0, 0, 0]
         iso_show.AmbientColor         = [0, 0, 0]
-        iso_show.CubeAxesColor        = [0, 0, 0]
+       #iso_show.CubeAxesColor        = [0, 0, 0]
         iso_show.BackfaceDiffuseColor = [0, 0, 0]
         iso_show.EdgeColor            = [0, 0, 0.5]
   
@@ -777,7 +800,7 @@ def paraview_field_3d_scalar (paraview, basename, option):
         iso_cut_show.LookupTable = color_map
         iso_cut_show.DiffuseColor         = [0, 0, 0]
         iso_cut_show.AmbientColor         = [0, 0, 0]
-        iso_cut_show.CubeAxesColor        = [0, 0, 0]
+       #iso_cut_show.CubeAxesColor        = [0, 0, 0]
         iso_cut_show.BackfaceDiffuseColor = [0, 0, 0]
         iso_cut_show.EdgeColor            = [0, 0, 0.5]
     
@@ -812,7 +835,7 @@ def paraview_field_3d_surface_scalar (paraview, basename, option):
       mesh_show.Opacity            = 0.25
       mesh_show.DiffuseColor       = [0, 0, 0]
       mesh_show.AmbientColor       = [0, 0, 0]
-      mesh_show.CubeAxesColor      = [0, 0, 0]
+     #mesh_show.CubeAxesColor      = [0, 0, 0]
       mesh_show.EdgeColor            = [0, 0, 0.5]
       #mesh_show.BackfaceDiffuseColor = [0.3333333333333333, 0.6666666666666666, 1]
       #mesh_show.DiffuseColor         = [0.3333333333333333, 0.6666666666666666, 1]
@@ -831,7 +854,7 @@ def paraview_field_3d_surface_scalar (paraview, basename, option):
       iso_contour.ScalarOpacityFunction = color_fct
       iso_contour.LookupTable           = color_map
       iso_contour.AmbientColor         = [0, 0, 0]
-      iso_contour.CubeAxesColor        = [0, 0, 0]
+     #iso_contour.CubeAxesColor        = [0, 0, 0]
       iso_contour.EdgeColor            = [0, 0, 0.5]
       iso_contour.BackfaceDiffuseColor = [0.3333333333333333, 0.6666666666666666, 1]
       iso_contour.DiffuseColor         = [0.3333333333333333, 0.6666666666666666, 1]
@@ -903,7 +926,7 @@ def paraview_field_vector_deformation (paraview, basename, option):
     outline_show = Show()
     outline_show.DiffuseColor         = [0, 0, 0]
     outline_show.AmbientColor         = [0, 0, 0]
-    outline_show.CubeAxesColor        = [0, 0, 0]
+   #outline_show.CubeAxesColor        = [0, 0, 0]
     outline_show.BackfaceDiffuseColor = [0, 0, 0]
     outline_show.EdgeColor            = [0, 0, 0.5]
     
@@ -930,7 +953,7 @@ def paraview_field_vector_deformation (paraview, basename, option):
     deformation_show.ScalarOpacityUnitDistance = 0.05547965123845249
     deformation_show.DiffuseColor         = [0, 0, 0]
     deformation_show.AmbientColor         = [0, 0, 0]
-    deformation_show.CubeAxesColor        = [0, 0, 0]
+   #deformation_show.CubeAxesColor        = [0, 0, 0]
     deformation_show.BackfaceDiffuseColor = [0, 0, 0]
     deformation_show.EdgeColor            = [0, 0, 0.5]
     
@@ -944,7 +967,7 @@ def paraview_field_vector_deformation (paraview, basename, option):
 # --------------------------------------------------------------------------
 def paraview_field_vector_arrow    (paraview, basename, option):
     from paraview.simple import LegacyVTKReader, \
-        SetActiveSource, Show, Glyph, Outline, GetRenderView
+        SetActiveSource, Show, Glyph, Outline, GetRenderView, GetDisplayProperties
     
     paraview.simple._DisableFirstRenderCameraReset()
     data = LegacyVTKReader(FileNames=[basename+".vtk"])
@@ -974,19 +997,37 @@ def paraview_field_vector_arrow    (paraview, basename, option):
       data_show.ScalarOpacityUnitDistance = 0.05547965123845249
       data_show.DiffuseColor         = [0, 0, 0]
       data_show.AmbientColor         = [0, 0, 0]
-      data_show.CubeAxesColor        = [0, 0, 0]
+     #data_show.CubeAxesColor        = [0, 0, 0]
       data_show.BackfaceDiffuseColor = [0, 0, 0]
       data_show.EdgeColor            = [0, 0, 0.5]
 
-    arrow = Glyph(GlyphType="Arrow", GlyphTransform="Transform2")
+    arrow = Glyph()
     arrow.Scalars = 'vector_norm'
     arrow.Vectors = 'vector'
-    arrow.GlyphType      = "Arrow"
-    arrow.GlyphTransform = "Transform2"
+    arrow.ScaleMode = 'vector'
+    if option['view_2d'] == 1: 
+      arrow.GlyphType = '2D Glyph'
+      render = GetRenderView()
+      arrow_display = GetDisplayProperties(arrow, view=render)
+      arrow_display.LineWidth = 2.0
+    else:
+      arrow.GlyphType   = 'Arrow'
+
     h_average = 0.1; # TODO: compute element average length
-    arrow.SetScaleFactor = h_average*option['scale'];
-    arrow.RandomMode = 0
-    arrow.MaskPoints = 0
+    # old paraview-4.x:
+    try:
+      arrow.SetScaleFactor = h_average*option['scale']; # old paraview 4.x
+    except:
+      0;           
+    # new paraview-5.x:
+    try:
+      arrow.ScaleMode = 'vector'
+      #arrow.ScaleMode = 'vector_components';
+      arrow.ScaleFactor    = h_average*option['scale'];
+    except:
+      0;          
+    #arrow.RandomMode = 0
+    #arrow.MaskPoints = 0
 
     arrow_show = Show()
     arrow_show.SelectionPointFieldDataArrayName = 'vector_norm'
@@ -998,7 +1039,7 @@ def paraview_field_vector_arrow    (paraview, basename, option):
       arrow_show.ColorArrayName = 'vector_norm'
       arrow_show.DiffuseColor         = [0, 0, 0]
     arrow_show.AmbientColor         = [0, 0, 0]
-    arrow_show.CubeAxesColor        = [0, 0, 0]
+   #arrow_show.CubeAxesColor        = [0, 0, 0]
     arrow_show.BackfaceDiffuseColor = [0, 0, 0]
     arrow_show.EdgeColor            = [0, 0, 0.5]
     
@@ -1066,7 +1107,7 @@ def paraview_field_tensor (paraview, basename, option):
     tensor_norm.ScalarOpacityUnitDistance = 0.2418271175121958
     tensor_norm.ScaleFactor = 1
     tensor_norm.AmbientColor  = [0, 0, 0]
-    tensor_norm.CubeAxesColor = [0, 0, 0]
+   #tensor_norm.CubeAxesColor = [0, 0, 0]
     tensor_norm.EdgeColor     = [0, 0, 0.5]
     if option['view_2d'] != 1:
       tensor_norm.Visibility  = 0
@@ -1093,7 +1134,7 @@ def paraview_field_tensor (paraview, basename, option):
     tensor_glyph_show.DiffuseColor         = [gray, gray, gray]
     tensor_glyph_show.BackfaceDiffuseColor = [gray, gray, gray]
     tensor_glyph_show.AmbientColor         = [0, 0, 0]
-    tensor_glyph_show.CubeAxesColor        = [0, 0, 0]
+   #tensor_glyph_show.CubeAxesColor        = [0, 0, 0]
     tensor_glyph_show.EdgeColor            = [0, 0, 0.5]
     
     if option['label'] == 1: 
@@ -1127,7 +1168,145 @@ def geo_n_vertex (data):
 def paraview_geo_domain (paraview, option, filename, dom_name, idx):
     from paraview.simple import LegacyVTKReader, Show, \
 	ExtractEdges, Shrink, Text, ExtractCellsByRegion, Clip, \
-	SetActiveSource
+	SetActiveSource, GetRenderView, GetActiveViewOrCreate, GetColorTransferFunction
+  
+    data = LegacyVTKReader(FileNames=[filename])
+    render = GetActiveViewOrCreate('RenderView')
+
+    #get bbox of the whole mesh, not only the domain:
+    x_min = option['bbox'][0][0]
+    x_max = option['bbox'][1][0]
+    y_min = option['bbox'][0][1]
+    y_max = option['bbox'][1][1]
+    z_min = option['bbox'][0][2]
+    z_max = option['bbox'][1][2]
+    xg = [(x_max+x_min)/2., (y_max+y_min)/2., (z_max+z_min)/2.]
+    dx = [x_max-x_min, y_max-y_min, z_max-z_min]
+
+    color_map = GetColorTransferFunction('mesh')
+    color_map.RGBPoints = [0.0, 0.231373, 0.298039, 0.752941, 5e-17, 0.865003, 0.865003, 0.865003, 1e-16, 0.705882, 0.0156863, 0.14902]
+    color_map.ScalarRangeInitialized = 1.0
+    color_fct = get_color_fct (color_map, option)
+    if option['color'] == 'black_and_white':
+      color = [0, 0, 0]
+    else:
+      if option['shrink'] == 0 or idx > 0:
+        color = global_geo_color[idx % len(global_geo_color)]
+      else:
+        gray = 11./12.
+        color = [gray, gray, gray]
+
+    if option['label'] == 1 and option['color'] != 'black_and_white' and idx == 0:
+      # TODO: ne = ? how to get it ?
+      nv = geo_n_vertex(data)
+      title = Text()
+      import os.path
+      title.Text = "%s : %d vertices"%(os.path.basename(dom_name), nv)
+      title_show = Show()
+      title_show.Color      = [0,0,0]
+      title_show.FontFamily = 'Times'
+      title_show.FontSize   = 10
+      title_show.Justification = 'Left'
+      title_show.WindowLocation = 'AnyLocation'
+      title_show.Position   = [0.025, 0.955]
+    if option['label'] == 1 and option['color'] != 'black_and_white' and idx != 0:
+      title = Text()
+      title.Text = dom_name
+      title_show = Show()
+      title_show.Color = color
+      title_show.FontFamily = 'Times'
+      title_show.FontSize   = 10
+      title_show.Justification = 'Left'
+      title_show.WindowLocation = 'AnyLocation'
+      title_show.Position   = [0.025, 0.955 - 0.025*idx]
+
+    SetActiveSource(data)
+    if option['full'] == 0 and option['shrink'] == 0:
+      mesh_show = Show(data,render)
+      mesh_show.ColorArrayName = ''
+      mesh_show.SelectionPointFieldDataArrayName = 'mesh'
+      mesh_show.LookupTable           = color_map
+      mesh_show.ScalarOpacityFunction = color_fct
+      if ((option['color'] != 'black_and_white' and idx == 0 and option['label'] == 1) or option['fill'] == 0):
+        mesh_show.Representation     = 'Wireframe'
+        mesh_show.DiffuseColor       = [0,0,0]
+        mesh_show.AmbientColor       = color
+        if (idx != 0):
+          mesh_show.LineWidth        = 2
+      else:
+        mesh_show.Representation     = 'Surface With Edges'
+        mesh_show.DiffuseColor       = color
+        mesh_show.AmbientColor       = [0, 0, 0]
+      if option['cut'] == 1:
+        mesh_show.Visibility = 0
+        clip = Clip()
+        clip.Scalars = 'mesh'
+        clip.InsideOut = 1;    # normal goes out from selected region
+	try:
+          clip.Crinkleclip = 1;  # paraview-4 style: do not cut inside elements, eliminates them
+	except:
+          0;                     # paraview-3 style: cut inside elements
+        clip.ClipType = "Plane"
+        clip.ClipType.Origin = xg
+        clip.ClipType.Normal = [0.92, -0.25, 0.28]; # TODO: get normal
+        clip_show = Show()
+        clip_show.Representation = 'Surface With Edges'
+        clip_show.SelectionPointFieldDataArrayName = 'mesh'
+        clip_show.ColorArrayName = ''
+        clip_show.ScaleFactor = 1
+        clip_show.LookupTable = color_map
+        clip_show.ScalarOpacityFunction = []
+        clip_show.ScalarOpacityUnitDistance = 0.16539091500936676
+        clip_show.DiffuseColor         = [1, 1, 1]
+        clip_show.BackfaceDiffuseColor = [1, 1, 1]
+        clip_show.AmbientColor         = [0, 0, 0]
+        clip_show.EdgeColor            = [0, 0, 0]
+    elif option['shrink'] == 1:
+      shrink = Shrink()
+      shrink_show = Show()
+      shrink_show.ScaleFactor           = 0.0950000023469329
+      shrink_show.SelectionPointFieldDataArrayName = 'mesh'
+      shrink_show.ColorArrayName = ''
+      shrink_show.LookupTable           = color_map
+      shrink_show.ScalarOpacityFunction = color_fct
+      shrink_show.DiffuseColor          = color
+      shrink_show.AmbientColor          = [0, 0, 0]
+      shrink_show.BackfaceDiffuseColor  = [0, 0, 0]
+      shrink_show.EdgeColor             = [0, 0, 0.5]
+      shrink_show.ScalarOpacityUnitDistance = 0.1811050201435371
+      if option['cut'] == 1:
+        shrink_show.Visibility = 0
+        extract = ExtractCellsByRegion(IntersectWith="Plane")
+        extract.IntersectWith = "Plane"
+        extract.IntersectWith.Origin = xg
+        extract.IntersectWith.Normal = [0.92, -0.25, 0.28]; # TODO: get normal
+        extract_show = Show()
+        extract_show.ScaleFactor = 0.09669428616762162
+        extract_show.SelectionPointFieldDataArrayName = 'mesh'
+        extract_show.ColorArrayName        = ''
+        extract_show.LookupTable           = color_map
+        extract_show.ScalarOpacityFunction = color_fct
+        extract_show.DiffuseColor          = color
+        extract_show.AmbientColor  = [0, 0, 0]
+        extract_show.EdgeColor     = [0, 0, 0.5]
+        extract_show.ScalarOpacityUnitDistance = 0.1896561226641973
+    else: # option['full'] == 1:
+      extract_edges = ExtractEdges()
+      extract_edges_show = Show()
+      extract_edges_show.ColorArrayName = ''
+      extract_edges_show.SelectionPointFieldDataArrayName = 'mesh'
+      extract_edges_show.LookupTable          = color_map
+      extract_edges_show.DiffuseColor         = color
+      extract_edges_show.AmbientColor         = [0, 0, 0]
+      extract_edges_show.BackfaceDiffuseColor = [0, 0, 0]
+      extract_edges_show.EdgeColor            = [0, 0, 0.5]
+      if (idx != 0):
+        extract_edges_show.LineWidth          = 2
+
+def paraview_geo_domain_old (paraview, option, filename, dom_name, idx):
+    from paraview.simple import LegacyVTKReader, Show, \
+	ExtractEdges, Shrink, Text, ExtractCellsByRegion, Clip, \
+	SetActiveSource, GetRenderView, GetActiveViewOrCreate
   
     data = LegacyVTKReader(FileNames=[filename])
     #get bbox of the whole mesh, not only the domain:
@@ -1152,19 +1331,9 @@ def paraview_geo_domain (paraview, option, filename, dom_name, idx):
         gray = 11./12.
         color = [gray, gray, gray]
         #color = [0, 1, 1]; # petrol blue
-
-    if option['label'] == 1 and option['color'] != 'black_and_white' and idx > 0:
-      text = Text()
-      text.Text = dom_name
-      text_show = Show()
-      text_show.Color      = color
-      text_show.FontFamily = 'Times'
-      text_show.FontSize   = 10
-      text_show.Justification = 'Center'
-      text_hight = 0.005*text_show.FontSize; # TODO: how to quantify it clearly ?
-      y_pos = 0.75 - (idx-1)*text_hight
-      #print "y_pos(",idx,") = ", y_pos
-      text_show.Position   = [0.02, y_pos]
+      mesh_show.BackfaceDiffuseColor = [0, 0, 0]
+     #mesh_show.CubeAxesColor        = [0, 0, 0]
+      mesh_show.EdgeColor            = [0, 0, 0.5]
 
     if option['label'] == 1 and option['color'] != 'black_and_white' and idx == 0:
       # TODO: ne = ? how to get it ?
@@ -1177,11 +1346,13 @@ def paraview_geo_domain (paraview, option, filename, dom_name, idx):
       title_show.FontFamily = 'Times'
       title_show.FontSize   = 10
       title_show.Justification = 'Left'
+      title_show.WindowLocation = 'AnyLocation'
       title_show.Position   = [0.05, 0.05]
 
     SetActiveSource(data)
     if option['full'] == 0 and option['shrink'] == 0:
-      mesh_show = Show()
+      render = GetActiveViewOrCreate('RenderView')
+      mesh_show = Show(data,render)
       mesh_show.ColorArrayName = ''
       mesh_show.SelectionPointFieldDataArrayName = 'mesh'
       mesh_show.LookupTable           = color_map
@@ -1197,7 +1368,7 @@ def paraview_geo_domain (paraview, option, filename, dom_name, idx):
         mesh_show.DiffuseColor       = color
         mesh_show.AmbientColor       = [0, 0, 0]
       mesh_show.BackfaceDiffuseColor = [0, 0, 0]
-      mesh_show.CubeAxesColor        = [0, 0, 0]
+     #mesh_show.CubeAxesColor        = [0, 0, 0]
       mesh_show.EdgeColor            = [0, 0, 0.5]
       if option['cut'] == 1:
         mesh_show.Visibility = 0
@@ -1222,7 +1393,7 @@ def paraview_geo_domain (paraview, option, filename, dom_name, idx):
         clip_show.DiffuseColor         = [1, 1, 1]
         clip_show.BackfaceDiffuseColor = [1, 1, 1]
         clip_show.AmbientColor         = [0, 0, 0]
-        clip_show.CubeAxesColor        = [0, 0, 0]
+       #clip_show.CubeAxesColor        = [0, 0, 0]
         clip_show.EdgeColor            = [0, 0, 0]
     elif option['shrink'] == 1:
       shrink = Shrink()
@@ -1235,7 +1406,7 @@ def paraview_geo_domain (paraview, option, filename, dom_name, idx):
       shrink_show.DiffuseColor          = color
       shrink_show.AmbientColor          = [0, 0, 0]
       shrink_show.BackfaceDiffuseColor  = [0, 0, 0]
-      shrink_show.CubeAxesColor         = [0, 0, 0]
+     #shrink_show.CubeAxesColor         = [0, 0, 0]
       shrink_show.EdgeColor             = [0, 0, 0.5]
       shrink_show.ScalarOpacityUnitDistance = 0.1811050201435371
       if option['cut'] == 1:
@@ -1252,7 +1423,7 @@ def paraview_geo_domain (paraview, option, filename, dom_name, idx):
         extract_show.ScalarOpacityFunction = color_fct
         extract_show.DiffuseColor          = color
         extract_show.AmbientColor  = [0, 0, 0]
-        extract_show.CubeAxesColor = [0, 0, 0]
+       #extract_show.CubeAxesColor = [0, 0, 0]
         extract_show.EdgeColor     = [0, 0, 0.5]
         extract_show.ScalarOpacityUnitDistance = 0.1896561226641973
     else: # option['full'] == 1:
@@ -1264,7 +1435,7 @@ def paraview_geo_domain (paraview, option, filename, dom_name, idx):
       extract_edges_show.DiffuseColor         = color
       extract_edges_show.AmbientColor         = [0, 0, 0]
       extract_edges_show.BackfaceDiffuseColor = [0, 0, 0]
-      extract_edges_show.CubeAxesColor        = [0, 0, 0]
+     #extract_edges_show.CubeAxesColor        = [0, 0, 0]
       extract_edges_show.EdgeColor            = [0, 0, 0.5]
       if (idx != 0):
         extract_edges_show.LineWidth          = 2
