@@ -267,13 +267,13 @@ template <class T, class M> class csr_concat_line;
 // -------------------------------------------------------------
 /*Class:csr
 NAME:  @code{csr} - compressed sparse row matrix (@PACKAGE@-@VERSION@)
-SYNOPSYS:       
+SYNOPSIS:       
   Distributed compressed sparse matrix container stored row by row.
 DESCRIPTION:
   Sparse matrix are compressed by rows. In distributed environment, the
   distribution follows the row distributor (see @ref{distributor class}).
 ALGEBRA:
-  Adding or substracting two matrices writes @code{a+b} and @code{a-b}, respectively,
+  Adding or subtracting two matrices writes @code{a+b} and @code{a-b}, respectively,
   and multiplying a matrix by a scalar writes @code{lambda*x}.
   Thus, any linear combination of sparse matrices is available.
  
