@@ -47,7 +47,7 @@ csr_concat_line<T,M>::set_sizes (
     check_macro (row_sizes.first == new_row_sizes.first,
 	    "matrix initializer list: matrix row argument [0:"
                << new_row_sizes.first << "|" << new_row_sizes.second << "["
-	       << " has incomptible size: expect [0:"
+	       << " has incompatible size: expect [0:"
                << row_sizes.first  << "|" << row_sizes.second << "[");
   }
   if (col_sizes.first == undef) {
@@ -56,7 +56,7 @@ csr_concat_line<T,M>::set_sizes (
     check_macro (col_sizes.first == new_col_sizes.first,
 	    "matrix initializer list: matrix col argument [0:"
                << new_col_sizes.first << "|" << new_col_sizes.second << "["
-	       << " has incomptible size: expect [0:"
+	       << " has incompatible size: expect [0:"
                << col_sizes.first  << "|" << col_sizes.second << "[");
   }
 }
