@@ -687,18 +687,26 @@ csr_rep<T,distributed>::assign_mult (
 // ----------------------------------------------------------------------------
 // instanciation in library
 // ----------------------------------------------------------------------------
-#define _RHEOLEF_istanciate(T) 							\
+#ifdef _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+#define _RHEOLEF_instanciate_class(T) \
+template void csr_rep<T,distributed>::build_from_asr (const asr<T,distributed,std::allocator<T> >&); 
+#else  // _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+#define _RHEOLEF_instanciate_class(T) \
+template void csr_rep<T,distributed>::build_from_asr (const asr<T,distributed,std::allocator<T> >&); \
+template void csr_rep<T,distributed>::build_from_asr (const asr<T,distributed,heap_allocator<T> >&);
+#endif // _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+
+#define _RHEOLEF_istanciate(T) 								\
 template class csr_rep<T,distributed>;							\
 template void csr_rep<T,distributed>::assign_add (					\
 	const csr_rep<T,distributed>&,							\
         const csr_rep<T,distributed>&, 							\
-              std::plus<T>);							\
+              std::plus<T>);								\
 template void csr_rep<T,distributed>::assign_add (					\
 	const csr_rep<T,distributed>&,							\
         const csr_rep<T,distributed>&,							\
-              std::minus<T>);							\
-template void csr_rep<T,distributed>::build_from_asr (const asr<T,distributed,std::allocator<T> >&); \
-template void csr_rep<T,distributed>::build_from_asr (const asr<T,distributed,heap_allocator<T> >&);
+              std::minus<T>);								\
+_RHEOLEF_instanciate_class(T) 
 
 _RHEOLEF_istanciate(Float)
 
