@@ -473,18 +473,26 @@ csr_rep<T,sequential>::assign_mult (
 // ----------------------------------------------------------------------------
 // instanciation in library
 // ----------------------------------------------------------------------------
+#ifdef _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+#define _RHEOLEF_instanciate_class(T) \
+template void csr_rep<T,sequential>::build_from_asr (const asr<T,sequential,std::allocator<T> >&);
+#else // _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+#define _RHEOLEF_instanciate_class(T) \
+template void csr_rep<T,sequential>::build_from_asr (const asr<T,sequential,std::allocator<T> >&);	\
+template void csr_rep<T,sequential>::build_from_asr (const asr<T,sequential,heap_allocator<T> >&);
+#endif // _RHEOLEF_DO_NOT_USE_HEAP_ALLOCATOR
+
 #define _RHEOLEF_instanciate(T) \
 template class csr_rep<T,sequential>;					\
 template void csr_rep<T,sequential>::assign_add (			\
 	const csr_rep<T,sequential>&,					\
 	const csr_rep<T,sequential>&,					\
-	      std::plus<T>);					\
+	      std::plus<T>);						\
 template void csr_rep<T,sequential>::assign_add (			\
 	const csr_rep<T,sequential>&,					\
 	const csr_rep<T,sequential>&,					\
-	std::minus<T>);						\
-template void csr_rep<T,sequential>::build_from_asr (const asr<T,sequential,std::allocator<T> >&);	\
-template void csr_rep<T,sequential>::build_from_asr (const asr<T,sequential,heap_allocator<T> >&);
+	std::minus<T>);							\
+_RHEOLEF_instanciate_class(T)
 
 _RHEOLEF_instanciate(Float)
 
