@@ -32,12 +32,12 @@ NAME: @code{dia} - diagonal matrix
 @cindex diagonal matrix
 DESCRIPTION:       
   The class implements a diagonal matrix.
-  A declaration whithout any parametrers correspond to a null size matrix:
+  A declaration without any parametrers correspond to a null size matrix:
   @example
      	dia<Float> d;
   @end example
   @noindent
-  The constructor can be invocated whith a @code{ownership} parameter
+  The constructor can be invocated with a @code{ownership} parameter
   (see @ref{distributor class}):
   @example
      	dia<Float> d(ownership);
@@ -66,7 +66,7 @@ PRECONDITIONER INTERFACE:
   The class presents a preconditioner interface, 
   as the @ref{solver class}, 
   so that it can be used as preconditioner to the iterative solvers
-  suite (see @ref{pcg algorithm}).
+  suite (see @ref{cg algorithm}).
 End:
 */
 //<dia:
