@@ -295,7 +295,7 @@ protected:
 // -------------------------------------------------------------
 /*Class:disarray
 NAME:  @code{disarray} - container in distributed environment (@PACKAGE@-@VERSION@)
-SYNOPSYS:       
+SYNOPSIS:       
   STL-like vector container for a distributed memory machine model.
 EXAMPLE:
    A sample usage of the class is:
@@ -345,7 +345,7 @@ DISTRIBUTED READ ACCESS:
 NOTE:
   The class takes two template parameters: one for the type T and the second
   for the memory model M, that could be either M=distributed or M=sequential.
-  The two cases are associated to two diferent implementations, but proposes
+  The two cases are associated to two different implementations, but proposes
   exactly the same interface. The sequential interface propose also a supplementary
   constructor:
    @example
