@@ -29,7 +29,7 @@ namespace rheolef {
 
 /*Class:distributor
 NAME:  @code{distributor} - data distribution table (@PACKAGE@-@VERSION@)
-SYNOPSYS:
+SYNOPSIS:
    Used by "disarray"(1), "asr"(1) and "csr"(1).
    and such classes that distribute data as chunk.
 SEE ALSO: "disarray"(1), "asr"(1), "csr"(1).
