@@ -31,10 +31,10 @@ DESCRIPTION:
   Following @code{octave}, the name @code{eye_rep} class is used in place of I to denote identity matrices
   because I is often used as a subscript or as sqrt(-1). The dimensions of @code{eye_rep} are
   determined by the context.
-  This class is here usefull in the context of preconditioner interfaces: it allows
+  This class is here useful in the context of preconditioner interfaces: it allows
   calls of algorithms without any preconditioners, e.g.
   @example
-    int status = pcg (a, x, b, eye_rep<Float>(), 100, 1e-7);
+    int status = cg (a, x, b, eye_rep<Float>(), 100, 1e-7);
   @end example
 AUTHOR: 
     Pierre Saramito
@@ -48,7 +48,7 @@ End:
 template<class T, class M = rheo_default_memory_model>
 class eye_rep : public solver_abstract_rep<T,M> {
 public:
-  eye_rep (const solver_option_type& opt = solver_option_type());
+  eye_rep (const solver_option& opt = solver_option());
   void update_values (const csr<T,M>&) {}
   vec<T,M> operator*   (const vec<T,M>& x) const { return x; }
   vec<T,M> solve       (const vec<T,M>& x) const { return x; }
@@ -58,7 +58,7 @@ public:
 
 template<class T, class M>
 inline
-eye_rep<T,M>::eye_rep (const solver_option_type& opt)
+eye_rep<T,M>::eye_rep (const solver_option& opt)
  : solver_abstract_rep<T,M>(opt)
 {
 }
