@@ -47,7 +47,7 @@ namespace rheolef {
 
 /*Class:
 NAME:  pair_set - a set of (index,value) pair (@PACKAGE@-@VERSION@)
-SYNOPSYS:       
+SYNOPSIS:       
     A class for: l = @{(0,3.3),...(7,8.2)@} i.e. a wrapper for STL @code{map<size_t,T>} with 
     some assignment operators, such as l1 += l2.
     This class is suitable for use with the @code{disarray<T>} class,
