@@ -31,11 +31,11 @@
 #include "rheolef/csr_concat.h"
 #include "rheolef/dis_inner_product.h"
 #include "rheolef/solver.h"
-#include "rheolef/pcg.h"
-#include "rheolef/pgmres.h"
+#include "rheolef/gmres.h"
 #include "rheolef/dia.h"
 #include "rheolef/diag.h"
 #include "rheolef/eye.h"
 #include "rheolef/solver_abtb.h"
-#include "rheolef/dis_time.h"
+#include "rheolef/dis_cpu_time.h"
+#include "rheolef/dis_memory_usage.h"
 #endif // _RHEOLEF_SKIT_H
