@@ -23,7 +23,7 @@
 // direct & iterative solver interface
 //
 #include "rheolef/csr.h"
-#include "rheolef/solver_option_type.h"
+#include "rheolef/solver_option.h"
 
 namespace rheolef {
 
@@ -38,16 +38,16 @@ class solver_abstract_rep {
 public:
   typedef typename csr<T,M>::size_type                 size_type;
   struct determinant_type;
-  solver_abstract_rep (const solver_option_type& opt) : _opt(opt) {}
+  solver_abstract_rep (const solver_option& opt) : _opt(opt) {}
   virtual ~solver_abstract_rep () {}
-  const solver_option_type& option() const { return _opt; }
+  const solver_option& option() const { return _opt; }
   virtual void update_values (const csr<T,M>& a) = 0;
   virtual vec<T,M> trans_solve (const vec<T,M>& b) const = 0;
   virtual vec<T,M> solve       (const vec<T,M>& b) const = 0;
   virtual void set_preconditionner (const solver_basic<T,M>&);
   virtual determinant_type det() const;
 // data:
-  mutable solver_option_type _opt;
+  mutable solver_option _opt;
 };
 // det = mantissa*2^(exp2)
 template <class T, class M>
@@ -64,14 +64,14 @@ public:
   typedef typename solver_abstract_rep<T,M>::size_type size_type;
   typedef typename solver_abstract_rep<T,M>::determinant_type determinant_type;
   explicit solver_rep   ();
-  explicit solver_rep   (const csr<T,M>& a, const solver_option_type& opt = solver_option_type());
+  explicit solver_rep   (const csr<T,M>& a, const solver_option& opt = solver_option());
   void set_preconditionner (const solver_basic<T,M>&);
   determinant_type det() const;
   void build_eye ();
-  void build_lu  (const csr<T,M>& a, const solver_option_type& opt);
-  void build_ilu (const csr<T,M>& a, const solver_option_type& opt);
+  void build_lu  (const csr<T,M>& a, const solver_option& opt);
+  void build_ilu (const csr<T,M>& a, const solver_option& opt);
   ~solver_rep ();
-  const solver_option_type& option() const;
+  const solver_option& option() const;
   void update_values (const csr<T,M>& a);
   vec<T,M> trans_solve (const vec<T,M>& b) const;
   vec<T,M> solve       (const vec<T,M>& b) const;
@@ -123,11 +123,11 @@ AUTOMATIC CHOICE AND CUSTOMIZATION:
   (@pxref{csr class}) while the choice between direct or iterative solver
   is switched by default from the a.pattern_dimension() value. When the pattern
   is 3D, an iterative method is faster and less memory consuming.
-  Otherwhise, for 1D or 2D problems, the direct method is prefered.
+  Otherwise, for 1D or 2D problems, the direct method is preferred.
  
   These default choices can be supersetted by using explicit options:
   @example
-	solver_option_type opt;
+	solver_option opt;
 	opt.iterative = true;
      	solver sa (a, opt);
   @end example
@@ -140,14 +140,14 @@ COMPUTATION OF THE DETERMINANT:
   When using a direct method, the determinant of the @code{a} matrix
   can be computed as:
   @example
-	solver_option_type opt;
+	solver_option opt;
 	opt.iterative = false;
      	solver sa (a, opt);
         cout << sa.det().mantissa << "*2^" << sa.det().exponant << endl;
   @end example
   The @code{sa.det()} method returns an object of type @code{solver::determinant_type}
   that contains a mantissa and an exponent in base 2.
-  This feature is usefull e.g. when tracking a change of sign in the determinant
+  This feature is useful e.g. when tracking a change of sign in the determinant
   of a matrix.
  
 PRECONDITIONNERS FOR ITERATIVE SOLVER:
@@ -155,7 +155,7 @@ PRECONDITIONNERS FOR ITERATIVE SOLVER:
   When using an iterative method, the default is to do no preconditionning.
   A suitable preconditionner can be supplied via:
   @example
-	solver_option_type opt;
+	solver_option opt;
 	opt.iterative = true;
      	solver sa (a, opt);
         sa.set_preconditionner (pa);
@@ -182,8 +182,8 @@ public:
 // allocator:
 
   solver_basic ();
-  explicit solver_basic (const csr<T,M>& a, const solver_option_type& opt = solver_option_type());
-  const solver_option_type& option() const;
+  explicit solver_basic (const csr<T,M>& a, const solver_option& opt = solver_option());
+  const solver_option& option() const;
   void update_values (const csr<T,M>& a);
   void set_preconditionner (const solver_basic<T,M>&);
 
@@ -195,22 +195,22 @@ public:
 };
 // factorizations:
 template <class T, class M>
-solver_basic<T,M> ldlt(const csr<T,M>& a, const solver_option_type& opt = solver_option_type());
+solver_basic<T,M> ldlt(const csr<T,M>& a, const solver_option& opt = solver_option());
 template <class T, class M>
-solver_basic<T,M> lu  (const csr<T,M>& a, const solver_option_type& opt = solver_option_type());
+solver_basic<T,M> lu  (const csr<T,M>& a, const solver_option& opt = solver_option());
 
 // preconditionners:
 template <class T, class M = rheo_default_memory_model>
 solver_basic<T,M> eye_basic();
 inline solver_basic<Float> eye() { return eye_basic<Float>(); }
 template <class T, class M>
-solver_basic<T,M> ic0 (const csr<T,M>& a, const solver_option_type& opt = solver_option_type());
+solver_basic<T,M> ic0 (const csr<T,M>& a, const solver_option& opt = solver_option());
 template <class T, class M>
-solver_basic<T,M> ilu0(const csr<T,M>& a, const solver_option_type& opt = solver_option_type());
+solver_basic<T,M> ilu0(const csr<T,M>& a, const solver_option& opt = solver_option());
 template <class T, class M>
-solver_basic<T,M> ldlt_seq(const csr<T,M>& a, const solver_option_type& opt = solver_option_type());
+solver_basic<T,M> ldlt_seq(const csr<T,M>& a, const solver_option& opt = solver_option());
 template <class T, class M>
-solver_basic<T,M> lu_seq  (const csr<T,M>& a, const solver_option_type& opt = solver_option_type());
+solver_basic<T,M> lu_seq  (const csr<T,M>& a, const solver_option& opt = solver_option());
 
 typedef solver_basic<Float> solver;
 //>verbatim:
@@ -226,13 +226,13 @@ solver_basic<T,M>::solver_basic ()
 }
 template <class T, class M>
 inline
-solver_basic<T,M>::solver_basic (const csr<T,M>& a, const solver_option_type& opt)
+solver_basic<T,M>::solver_basic (const csr<T,M>& a, const solver_option& opt)
  : base (new_macro(rep(a,opt)))
 {
 }
 template <class T, class M>
 inline
-const solver_option_type&
+const solver_option&
 solver_basic<T,M>::option() const
 {
   return base::data().option();
@@ -240,7 +240,7 @@ solver_basic<T,M>::option() const
 template <class T, class M>
 inline
 solver_basic<T,M>
-lu (const csr<T,M>& a, const solver_option_type& opt)
+lu (const csr<T,M>& a, const solver_option& opt)
 {
   solver_basic<T,M> sa;
   sa.data().build_lu (a, opt);
@@ -249,7 +249,7 @@ lu (const csr<T,M>& a, const solver_option_type& opt)
 template <class T, class M>
 inline
 solver_basic<T,M>
-ldlt (const csr<T,M>& a, const solver_option_type& opt)
+ldlt (const csr<T,M>& a, const solver_option& opt)
 {
   return lu(a,opt); // symmetry flag is indicated in the matrix a
 }
@@ -265,7 +265,7 @@ eye_basic ()
 template <class T, class M>
 inline
 solver_basic<T,M>
-ilu0 (const csr<T,M>& a, const solver_option_type& opt)
+ilu0 (const csr<T,M>& a, const solver_option& opt)
 {
   solver_basic<T,M> sa;
   sa.data().build_ilu (a, opt);
@@ -274,23 +274,23 @@ ilu0 (const csr<T,M>& a, const solver_option_type& opt)
 template <class T, class M>
 inline
 solver_basic<T,M>
-ic0 (const csr<T,M>& a, const solver_option_type& opt)
+ic0 (const csr<T,M>& a, const solver_option& opt)
 {
   return ilu0(a,opt); // symmetry flag is indicated in the matrix a
 }
 template <class T, class M>
 inline
 solver_basic<T,M>
-lu_seq (const csr<T,M>& a, const solver_option_type& opt)
+lu_seq (const csr<T,M>& a, const solver_option& opt)
 {
-  solver_option_type opt1 = opt;
+  solver_option opt1 = opt;
   opt1.force_seq = true;
   return lu (a,opt1);
 }
 template <class T, class M>
 inline
 solver_basic<T,M>
-ldlt_seq (const csr<T,M>& a, const solver_option_type& opt)
+ldlt_seq (const csr<T,M>& a, const solver_option& opt)
 {
   return lu_seq(a,opt); // symmetry flag is indicated in the matrix a
 }
