@@ -27,7 +27,7 @@
 namespace rheolef {
 
 /*Class:solver_abtb
-NAME: @code{solver_abtb} -- direct or iterative solver iterface for mixed linear systems
+NAME: @code{solver_abtb} -- direct or iterative solver interface for mixed linear systems
 @cindex mixed linear problem
 @cindex conjugate gradien algorithm
 @cindex finite element method
@@ -90,22 +90,23 @@ public:
 
   solver_abtb_basic ();
   solver_abtb_basic (const csr<T,M>& a, const csr<T,M>& b, const csr<T,M>& mp,
-       const solver_option_type& opt     = solver_option_type(), 
-       const solver_option_type& sub_opt = solver_option_type());
+       const solver_option& opt     = solver_option(), 
+       const solver_option& sub_opt = solver_option());
   solver_abtb_basic (const csr<T,M>& a, const csr<T,M>& b, const csr<T,M>& c, const csr<T,M>& mp,
-       const solver_option_type& opt     = solver_option_type(),
-       const solver_option_type& sub_opt = solver_option_type());
+       const solver_option& opt     = solver_option(),
+       const solver_option& sub_opt = solver_option());
 
 // accessors:
 
   void solve (const vec<T,M>& f, const vec<T,M>& g, vec<T,M>& u, vec<T,M>& p) const;
+  const solver_option& option() const { return _opt; }
 
 protected:
 // internal
   void init();
 // data:
-  mutable solver_option_type _opt;
-  mutable solver_option_type _sub_opt;
+  mutable solver_option _opt;
+  mutable solver_option _sub_opt;
   csr<T,M>          _a;
   csr<T,M>          _b;
   csr<T,M>          _c;
