@@ -221,7 +221,7 @@ csr2mumps_values_dis (const csr<T,distributed>& a, vector<T>& val, bool use_symm
 // 2. the class interface
 // =========================================================================
 template<class T, class M>
-solver_mumps_rep<T,M>::solver_mumps_rep (const csr<T,M>& a, const solver_option_type& opt)
+solver_mumps_rep<T,M>::solver_mumps_rep (const csr<T,M>& a, const solver_option& opt)
  : solver_abstract_rep<T,M>(opt),
    _has_mumps_instance(false),
    _drop_ext_nnz(false),
@@ -285,7 +285,7 @@ solver_mumps_rep<T,M>::solver_mumps_rep (const csr<T,M>& a, const solver_option_
   }
   _mumps_par.job = -1;
   dmumps_c(&_mumps_par);
-  check_macro (_mumps_par.infog[1-1] == 0, "mumps: an error has occured");
+  check_macro (_mumps_par.infog[1-1] == 0, "mumps: an error has occurred");
   // ----------------------------------
   //  step 1 : symbolic factorization
   // ----------------------------------
@@ -359,7 +359,7 @@ solver_mumps_rep<T,M>::solver_mumps_rep (const csr<T,M>& a, const solver_option_
   _mumps_par.job = 1;
   dmumps_c(&_mumps_par);
   trace_macro ("symbolic: ordering effectively used = " << _mumps_par.infog[7-1]); // 3=scoth, etc
-  check_macro (_mumps_par.infog[1-1] == 0, "mumps: error infog(1)="<<_mumps_par.infog[1-1]<<" has occured (see mumps/infog(1) documentation; infog(2)="<<_mumps_par.infog[2-1]<<")");
+  check_macro (_mumps_par.infog[1-1] == 0, "mumps: error infog(1)="<<_mumps_par.infog[1-1]<<" has occurred (see mumps/infog(1) documentation; infog(2)="<<_mumps_par.infog[2-1]<<")");
   update_values (a);
 }
 template<class T, class M>
@@ -405,7 +405,9 @@ solver_mumps_rep<T,M>::update_values (const csr<T,M>& a)
       // not enought working space:
       // default 20 seems to be insufficient in some cases (periodic,surfacic,p-laplacian)
       _mumps_par.icntl[14-1] += 10;
-      dis_warning_macro ("numeric factorization: increase working space of "<<_mumps_par.icntl[14-1]<< "% and retry...");
+      if (_mumps_par.icntl[14-1] > 100) {
+        dis_warning_macro ("numeric factorization: increase working space of "<<_mumps_par.icntl[14-1]<< "% and retry...");
+      }
     } else {
       finished = true;
     }
@@ -516,7 +518,7 @@ solver_mumps_rep<T,M>::~solver_mumps_rep ()
   // ----------------------------------
   _mumps_par.job = -2;
   dmumps_c(&_mumps_par);
-  check_macro (_mumps_par.infog[1-1] == 0, "mumps: an error has occured");
+  check_macro (_mumps_par.infog[1-1] == 0, "mumps: an error has occurred");
 }
 // ----------------------------------------------------------------------------
 // instanciation in library
