@@ -47,7 +47,7 @@ public:
 // allocator:
 
   solver_mumps_rep()
-   : solver_abstract_rep<T,M>(solver_option_type()),
+   : solver_abstract_rep<T,M>(solver_option()),
      _has_mumps_instance(false),
      _drop_ext_nnz(false),
      _mumps_par(),
@@ -56,7 +56,7 @@ public:
      _a00(0),
      _det()
     {}
-  explicit solver_mumps_rep (const csr<T,M>& a, const solver_option_type& opt = solver_option_type());
+  explicit solver_mumps_rep (const csr<T,M>& a, const solver_option& opt = solver_option());
   void update_values (const csr<T,M>& a);
   ~solver_mumps_rep ();
 
