@@ -156,7 +156,7 @@ solver_no_trilinos_ifpack_rep<T,M>::update_values (const csr<T,M>& a)
   inplace_ic0   (_ic0);
 }
 template<class T, class M>
-solver_no_trilinos_ifpack_rep<T,M>::solver_no_trilinos_ifpack_rep (const csr<T,M>& a, const solver_option_type& opt)
+solver_no_trilinos_ifpack_rep<T,M>::solver_no_trilinos_ifpack_rep (const csr<T,M>& a, const solver_option& opt)
  : solver_abstract_rep<T,M>(opt),
    _ic0()
 {
