@@ -52,7 +52,7 @@ public:
 // allocator:
 
   solver_pastix_base_rep ();
-  explicit solver_pastix_base_rep (const csr<T,M>& a, const solver_option_type& opt = solver_option_type());
+  explicit solver_pastix_base_rep (const csr<T,M>& a, const solver_option& opt = solver_option());
   void update_values         (const csr<T,M>& a);
   ~solver_pastix_base_rep ();
 
@@ -64,7 +64,7 @@ public:
 // internal accessors & modifiers:
 protected:
 
-  void load (const csr<T,M>& a, const solver_option_type& opt = solver_option_type());
+  void load (const csr<T,M>& a, const solver_option& opt = solver_option());
   bool is_symmetric () const { return _is_sym; }
   void resize (pastix_int_t n, pastix_int_t nnz);
   void load_symmetric      (const csr<T,M>& a);
@@ -90,7 +90,7 @@ public: // TODO: protected
   mutable T                 _dparm [DPARM_SIZE];  // floating parameters for pastix
   distributor               _csr_row_ownership;
   distributor               _csr_col_ownership;
-  solver_option_type        _opt;
+  solver_option        _opt;
   mutable std::vector<T>    _new_rhs;
   mutable std::vector<pastix_int_t> _new_i2dis_i_base;
   mutable std::vector<pastix_int_t> _i2new_dis_i; // permutation
@@ -118,7 +118,7 @@ public:
 // allocator:
 
   solver_pastix_rep () : base() {}
-  explicit solver_pastix_rep (const csr<T,sequential>& a, const solver_option_type& opt = solver_option_type())
+  explicit solver_pastix_rep (const csr<T,sequential>& a, const solver_option& opt = solver_option())
     : base(a,opt) {}
   void update_values         (const csr<T,sequential>& a) { base::update_values(a); }
 
@@ -130,7 +130,7 @@ public:
 // internal accessors & modifiers:
 protected:
 
-  void load (const csr<T,sequential>& a, const solver_option_type& opt = solver_option_type()) { load(a,opt); }
+  void load (const csr<T,sequential>& a, const solver_option& opt = solver_option()) { load(a,opt); }
   bool is_symmetric () const                            { return base::is_symmetric(); }
   void resize (pastix_int_t n, pastix_int_t nnz)        { resize (n,nnz); }
   void load_symmetric      (const csr<T,sequential>& a) { load_symmetric(a); }
@@ -153,7 +153,7 @@ public:
 // allocator:
 
   solver_pastix_rep ();
-  explicit solver_pastix_rep (const csr<T,distributed>& a, const solver_option_type& opt = solver_option_type());
+  explicit solver_pastix_rep (const csr<T,distributed>& a, const solver_option& opt = solver_option());
   void update_values         (const csr<T,distributed>& a);
   ~solver_pastix_rep ();
 
@@ -166,7 +166,7 @@ public:
 // internal accessors & modifiers:
 protected:
 
-  void load (const csr<T,distributed>& a, const solver_option_type& opt = solver_option_type());
+  void load (const csr<T,distributed>& a, const solver_option& opt = solver_option());
   bool is_symmetric () const { return base::_is_sym; }
   void resize (pastix_int_t n, pastix_int_t nnz);
   void load_symmetric      (const csr<T,distributed>& a);
