@@ -23,14 +23,14 @@
 #include "rheolef/config.h"
 #if defined(_RHEOLEF_HAVE_PASTIX) && defined(_RHEOLEF_HAVE_MPI)
 #include "solver_pastix.h"
-#include "rheolef/pcg.h"
+#include "rheolef/cg.h"
 #include "rheolef/eye.h"
 
 namespace rheolef {
 using namespace std;
 
 template<class T>
-solver_pastix_rep<T,distributed>::solver_pastix_rep (const csr<T>& a, const solver_option_type& opt)
+solver_pastix_rep<T,distributed>::solver_pastix_rep (const csr<T>& a, const solver_option& opt)
  : base(),
    _comm(),
    _i2dis_i_base(),
@@ -45,7 +45,7 @@ warning_macro ("return load...");
 }
 template<class T>
 void
-solver_pastix_rep<T,distributed>::load (const csr<T>& a, const solver_option_type& opt)
+solver_pastix_rep<T,distributed>::load (const csr<T>& a, const solver_option& opt)
 {
 warning_macro ("load...");
    base::_is_sym = a.is_symmetric(); 
@@ -298,7 +298,7 @@ solver_pastix_rep<T,distributed>::symbolic_factorization ()
   base::_iparm[IPARM_VERBOSE]             = base::_opt.verbose_level;
   base::_iparm[IPARM_ORDERING]            = ordering;
   bool do_incomplete;
-  if (base::_opt.iterative != solver_option_type::decide) {
+  if (base::_opt.iterative != solver_option::decide) {
     do_incomplete = (base::_opt.iterative != 0);
   } else {
     do_incomplete = (base::_pattern_dimension > 2); // 3d-pattern => iterative & IC(k) precond
@@ -469,7 +469,7 @@ solver_pastix_rep<T,distributed>::solve (const vec<T>& rhs) const
     T tol = std::numeric_limits<T>::epsilon();
     size_t max_iter = 1000; // TODO: use _opt to get tol & max_iter
     vec<T> x (base::_a_when_bug.col_ownership(), 0);
-    int status = pcg (base::_a_when_bug, x, rhs, eye<T>(), max_iter, tol, &derr);
+    int status = cg (base::_a_when_bug, x, rhs, eye<T>(), max_iter, tol, &derr);
     check_macro (tol < std::numeric_limits<T>::epsilon(), "solver(cg): machine precision not reached: "<<tol);
     return x;
   }
