@@ -23,7 +23,7 @@
 #include "rheolef/config.h"
 #ifdef _RHEOLEF_HAVE_PASTIX
 #include "solver_pastix.h"
-#include "rheolef/pcg.h"
+#include "rheolef/cg.h"
 #include "rheolef/eye.h"
 
 namespace rheolef {
@@ -164,7 +164,7 @@ solver_pastix_base_rep<T,M>::symbolic_factorization ()
   _iparm[IPARM_VERBOSE]             = _opt.verbose_level;
   _iparm[IPARM_ORDERING]            = ordering;
   bool do_incomplete;
-  if (_opt.iterative != solver_option_type::decide) {
+  if (_opt.iterative != solver_option::decide) {
     do_incomplete = (_opt.iterative != 0);
   } else {
     do_incomplete = (_pattern_dimension > 2); // 3d-pattern => iterative & IC(k) precond
@@ -236,7 +236,7 @@ solver_pastix_base_rep<T,M>::numeric_factorization ()
 }
 template<class T, class M>
 void
-solver_pastix_base_rep<T,M>::load (const csr<T,M>& a, const solver_option_type& opt)
+solver_pastix_base_rep<T,M>::load (const csr<T,M>& a, const solver_option& opt)
 {
 warning_macro ("load...");
 #define _RHEOLEF_SEQ_PASTIX_HAVE_SYM_BUG
@@ -268,7 +268,7 @@ warning_macro ("load done");
 }
 template<class T, class M>
 solver_pastix_base_rep<T,M>::solver_pastix_base_rep ()
- : solver_abstract_rep<T,M>(solver_option_type()),
+ : solver_abstract_rep<T,M>(solver_option()),
    _n(),
    _nnz(),
    _ptr(),
@@ -290,7 +290,7 @@ solver_pastix_base_rep<T,M>::solver_pastix_base_rep ()
 {
 }
 template<class T, class M>
-solver_pastix_base_rep<T,M>::solver_pastix_base_rep (const csr<T,M>& a, const solver_option_type& opt)
+solver_pastix_base_rep<T,M>::solver_pastix_base_rep (const csr<T,M>& a, const solver_option& opt)
  : solver_abstract_rep<T,M>(opt),
    _n(),
    _nnz(),
