@@ -78,7 +78,7 @@ umfpack_check_error (int status)
 // =========================================================================
 template<class T, class M>
 solver_umfpack_rep<T,M>::solver_umfpack_rep ()
- : solver_abstract_rep<T,M>(solver_option_type()),
+ : solver_abstract_rep<T,M>(solver_option()),
    _n(0),
    _numeric(0),
    _ia_p(0),
@@ -90,7 +90,7 @@ solver_umfpack_rep<T,M>::solver_umfpack_rep ()
 {
 }
 template<class T, class M>
-solver_umfpack_rep<T,M>::solver_umfpack_rep (const csr<T,M>& a, const solver_option_type& opt)
+solver_umfpack_rep<T,M>::solver_umfpack_rep (const csr<T,M>& a, const solver_option& opt)
  : solver_abstract_rep<T,M>(opt),
    _n(0),
    _numeric(0),
