@@ -48,7 +48,7 @@ public:
 // allocator:
 
   solver_umfpack_rep();
-  explicit solver_umfpack_rep (const csr<T,M>& a, const solver_option_type& opt = solver_option_type());
+  explicit solver_umfpack_rep (const csr<T,M>& a, const solver_option& opt = solver_option());
   void update_values (const csr<T,M>& a);
   ~solver_umfpack_rep ();
 
