@@ -20,24 +20,26 @@
 /// =========================================================================
 // solver wrapper: direct or iterative
 //
+#include "rheolef/cg.h"
+#include "rheolef/gmres.h"
+#include "rheolef/vec_expr_v2.h"
+
 #include "solver_wrapper.h"
-#include "rheolef/pcg.h"
-#include "rheolef/pgmres.h"
 #include <boost/numeric/ublas/matrix.hpp>
 
 namespace rheolef {
 using namespace std;
 
 template<class T, class M>
-solver_wrapper_rep<T,M>::solver_wrapper_rep (const csr<T,M>& a, const solver_option_type& opt)
+solver_wrapper_rep<T,M>::solver_wrapper_rep (const csr<T,M>& a, const solver_option& opt)
  : solver_abstract_rep<T,M>(opt),
   _is_direct((opt.iterative == 0) ||
-             (opt.iterative == solver_option_type::decide && a.pattern_dimension() <= 2)),
+             (opt.iterative == solver_option::decide && a.pattern_dimension() <= 2)),
   _is_sym    (a.is_symmetric()),
   _sa(),
   _a()
 {
-#if defined(_RHEOLEF_HAVE_QD) || defined(_RHEOLEF_HAVE_FLOAT128)
+#if defined(_RHEOLEF_HAVE_FLOAT128)
   // only ldlt available yet, for sym matrix
   if (!_is_sym) { _is_direct = false; }
 #elif !defined(_RHEOLEF_HAVE_TRILINOS) && !defined(_RHEOLEF_HAVE_PASTIX)
@@ -64,26 +66,26 @@ vec<T,M>
 solver_wrapper_rep<T,M>::solve (const vec<T,M>& b) const
 {
   if (_is_direct) { return _sa.solve (b); }
-
+#ifdef TO_CLEAN
   size_type max_iter = option().max_iter;
   T tol              = option().tol;
   T tol_reached      = tol;
+#endif // TO_CLEAN
   vec<T,M> x (b.ownership(), 0);
   if (_is_sym) {
-    int status = pcg (_a, x, b, _sa, max_iter, tol_reached, &derr);
+    int status = cg (_a, x, b, _sa, option());
   } else {
-    size_type m = 6;
+    size_type m = option().krylov_dimension;
     boost::numeric::ublas::matrix<T> h(m+1,m+1);
-    //boost::numeric::ublas::vector<T> dummy(m);
     vec<T,sequential> dummy(m,0.0);
-    int status = pgmres (_a, x, b, _sa, h, dummy, m, max_iter, tol_reached, &derr);
+    int status = gmres (_a, x, b, _sa, h, dummy, option());
   }
-  check_macro (tol_reached < sqrt(tol),
-	"solver: precision "<<tol<<" not reached: get "<<tol_reached
-	<< " after " << max_iter << " iterations");
-  if (tol_reached > tol) warning_macro (
-	"solver: precision "<<tol<<" not reached: get "<<tol_reached
-	<< " after " << max_iter << " iterations");
+  check_macro (option().residue <= sqrt(option().tol),
+	"solver: precision "<<option().tol<<" not reached: get "<<option().residue
+	<< " after " << option().max_iter << " iterations");
+  if (option().residue > option().tol) warning_macro (
+	"solver: precision "<<option().tol<<" not reached: get "<<option().residue
+	<< " after " << option().max_iter << " iterations");
   return x;
 }
 template<class T, class M>
