@@ -39,13 +39,13 @@ public:
 // allocator:
 
   solver_wrapper_rep ()
-   : solver_abstract_rep<T,M>(solver_option_type()),
+   : solver_abstract_rep<T,M>(solver_option()),
     _is_direct(),
     _is_sym(),
     _sa(),
     _a()
    {}
-  explicit solver_wrapper_rep (const csr<T,M>& a, const solver_option_type& opt = solver_option_type());
+  explicit solver_wrapper_rep (const csr<T,M>& a, const solver_option& opt = solver_option());
   void update_values          (const csr<T,M>& a);
   void set_preconditionner    (const solver_basic<T,M>& sa) { _sa = sa; }
   ~solver_wrapper_rep ();
@@ -55,7 +55,7 @@ public:
   vec<T,M> trans_solve (const vec<T,M>& rhs) const;
   vec<T,M> solve       (const vec<T,M>& rhs) const;
   determinant_type det() const;
-  const solver_option_type& option() const { return solver_abstract_rep<T,M>::option(); }
+  const solver_option& option() const { return solver_abstract_rep<T,M>::option(); }
 
 // data:
 protected:
