@@ -42,7 +42,7 @@ template <class T, class M> class vec_concat_value;
 
 /*Class:vec
 NAME: @code{vec} - vector in distributed environment (@PACKAGE@-@VERSION@)
-SYNOPSYS:       
+SYNOPSIS:       
   STL-like vector container for a sequential or
   distributed memory machine model.
   Additional operation fom classical algebra.
