@@ -24,8 +24,9 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"7"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
-#echo "      not yet (skipped)"
-#exit 0
+# full check too slow: use "runtime"
+export DMALLOC_OPTIONS="debug=0x4000503,log=a.log"
+echo "DMALLOC_OPTIONS=$DMALLOC_OPTIONS"
 
 status=0
 
