@@ -37,10 +37,11 @@ int main (int argc, char **argv) {
   }
   // compute the rhs and solve
   vec<Float> b = a*x_ex ;
-  Float tol = std::numeric_limits<Float>::epsilon();
-  size_t max_iter = 1000;
+  solver_option sopt;
+  sopt.tol = std::numeric_limits<Float>::epsilon();
+  sopt.max_iter = 1000;
   vec<Float> x (a.col_ownership(), 0);
-  int status = pcg (a, x, b, eye(), max_iter, tol, &derr);
+  int status = cg (a, x, b, eye(), sopt);
 
   // check the result
   Float err = sqrt(dot (x-x_ex,x-x_ex));
