@@ -34,7 +34,7 @@ int main (int argc, char **argv) {
   a.set_symmetry(true);
 
   // convert csr a to csc trans(a) pastix format (with a transpose)
-  solver_option_type opt;
+  solver_option opt;
   opt.verbose_level = 5;
   solver sa = ic0(a, opt); 
   // set x(dis_i) = dis_i
@@ -45,9 +45,10 @@ int main (int argc, char **argv) {
   // compute the rhs and solve
   vec<Float> b = a*x_ex ;
   vec<Float> x (b.ownership(), 0.);
-  size_t max_iter = 10000;
-  Float tol = 1e-15;
-  int status = pcg (a, x, b, sa, max_iter, tol, &derr);
+  solver_option sopt;
+  sopt.max_iter = 10000;
+  sopt.tol = 1e-15;
+  int status = cg (a, x, b, sa, sopt);
 
   // check the result
   Float err = sqrt(dot (x-x_ex,x-x_ex));
@@ -57,10 +58,10 @@ int main (int argc, char **argv) {
   csr<Float> a2 = a+a;
   sa.update_values (a2); 
   vec<Float> b2 = a2*x_ex ;
-  max_iter = 10000;
-  tol = 1e-15;
+  sopt.max_iter = 10000;
+  sopt.tol = 1e-15;
   x = 0;
-  status = pcg (a, x, b, sa, max_iter, tol, &derr);
+  status = cg (a, x, b, sa, sopt);
   Float err2 = sqrt(dot (x-x_ex,x-x_ex));
   warning_macro ("error2=|x-x_ex|=" << err2);
   
