@@ -24,6 +24,10 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"3"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
+# full check too slow: use "runtime"
+export DMALLOC_OPTIONS="debug=0x4000503,log=a.log"
+echo "DMALLOC_OPTIONS=$DMALLOC_OPTIONS"
+
 status=0
 loop_mpirun "./solver_ic0_tst < $SRCDIR/solver_tst.mtx 2>/dev/null >/dev/null"
 if test $? -ne 0; then status=1; fi
