@@ -35,7 +35,7 @@ int main (int argc, char **argv) {
   a.set_symmetry (is_sym);
 
   // convert csr a to csc trans(a) pastix format (with a transpose)
-  solver_option_type opt;
+  solver_option opt;
   opt.verbose_level = 0;
   //opt.do_check      = 1; // BUG...?
   solver sa = lu(a, opt); 
