@@ -36,7 +36,7 @@ int main (int argc, char **argv) {
   if (is_sym)     a.set_symmetry(true);
 
   // convert csr a to csc trans(a) pastix format (with a transpose)
-  solver_option_type opt;
+  solver_option opt;
   opt.verbose_level = 5;
   opt.compute_determinant = true;
   solver sa (a, opt);
