@@ -24,6 +24,11 @@ SRCDIR=${SRCDIR-"$TOP_SRCDIR/skit/ptst2"}
 NPROC_MAX=${NPROC_MAX-"3"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
+# full check too slow: use "runtime"
+export DMALLOC_OPTIONS="debug=0x4000503,log=a.log"
+echo "DMALLOC_OPTIONS=$DMALLOC_OPTIONS"
+
+
 status=0
 
 for algo in direct iterative; do
