@@ -24,4 +24,6 @@ TOP_SRCDIR=${TOP_SRCDIR-"../.."}
 NPROC_MAX=${NPROC_MAX-"7"}
 . "${TOP_SRCDIR}/config/loop_mpirun.sh"
 
-loop_mpirun "./vec_dot_tst 2> /dev/null | diff ${SRCDIR}/vec_dot_tst${DD_EXT}.out.valid - >/dev/null" 
+if test "$QD_EXT" = ".float128"; then QD_EXT=""; fi
+
+loop_mpirun "./vec_dot_tst 2> /dev/null | diff ${SRCDIR}/vec_dot_tst${QD_EXT}.out.valid - >/dev/null" 
