@@ -11,6 +11,8 @@
  
  This file is part of Freefem++
  
+ Copyright (C) 1998-2018 F. Hecht <Frederic.Hecht@Inria.fr>
+ 
  Freefem++ is free software; you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation; either version 2.1 of the License, or
@@ -57,7 +59,7 @@ void Triangles::Read(MeshIstream & f_in,int Version,Real8 cutoffradian)
   Int4 ifgeom=0;
   Metric M1(1);
   if (verbosity>1)
-    cout << " -- ReadMesh " << f_in.CurrentFile  << " Version = " << Version << endl;
+    cout << "  -- ReadMesh " << f_in.CurrentFile  << " Version = " << Version << endl;
   int field=0;
   int showfield=0;
   while (f_in.cm()) 
@@ -119,7 +121,7 @@ void Triangles::Read(MeshIstream & f_in,int Version,Real8 cutoffradian)
 	   nbvx=nbv;
 	   vertices=new Vertex[nbvx];
 	   assert(vertices);
-	   ordre=new (Vertex* [this->nbvx]);
+	   ordre=new Vertex* [nbvx];
 	   assert(ordre);
 	   
 	   nbiv = nbv;
@@ -360,7 +362,7 @@ void Triangles::Read(MeshIstream & f_in,int Version,Real8 cutoffradian)
 	      }
 	}
       else
-	{ // unkown field
+	{ // unknown field
 	  field = ++showfield;
 	  if(showfield==1) // just to show one time 
 	    if (verbosity>5)
@@ -387,19 +389,19 @@ void Triangles::Read_am_fmt(MeshIstream & f_in)
   Metric M1(1);
 
   if (verbosity>1)
-    cout << " -- ReadMesh .am_fmt file " <<  f_in.CurrentFile  << endl;
+    cout << "  -- ReadMesh .am_fmt file " <<  f_in.CurrentFile  << endl;
    	
      Int4 i;
      f_in.cm() >> nbv >> nbt ;
      if (verbosity>3)
-       cout << "    nbv = |" << nbv  << "|; nbt = " << nbt << endl;
+       cout << "    nbv = " << nbv  << " nbt = " << nbt << endl;
      f_in.eol() ;// 
      nbvx = nbv;
      nbtx =  2*nbv-2; // for filling The Holes and quadrilaterals 
      triangles =new Triangle[nbtx];
      assert(triangles);
      vertices=new Vertex[nbvx];
-     ordre=new (Vertex* [this->nbvx]);
+     ordre=new Vertex* [nbvx];
      
      for (     i=0;i<nbt;i++)
        {
@@ -430,7 +432,7 @@ void Triangles::Read_am_fmt(MeshIstream & f_in)
 void  Triangles::Read_am(MeshIstream &ff)
 {
   if (verbosity>1)
-    cout << " -- ReadMesh .am_fmt file " <<  ff.CurrentFile  << endl;
+    cout << "  -- ReadMesh .am_fmt file " <<  ff.CurrentFile  << endl;
     Metric M1(1);	
   
   IFortranUnFormattedFile f_in(ff);
@@ -448,7 +450,7 @@ void  Triangles::Read_am(MeshIstream &ff)
   triangles =new Triangle[nbtx];
   assert(triangles);
   vertices=new Vertex[nbvx];
-  ordre=new (Vertex* [this->nbvx]);
+  ordre=new Vertex* [nbvx];
   
 
   Int4 i;
@@ -481,7 +483,7 @@ void  Triangles::Read_nopo(MeshIstream & ff)
 {
 
  if (verbosity>1)
-    cout << " -- ReadMesh .nopo file " <<  ff.CurrentFile  << endl;
+    cout << "  -- ReadMesh .nopo file " <<  ff.CurrentFile  << endl;
  IFortranUnFormattedFile f_in(ff);
  
  
@@ -547,7 +549,7 @@ void  Triangles::Read_nopo(MeshIstream & ff)
   triangles =new Triangle[nbtx];
   assert(triangles);
   vertices=new Vertex[nbvx];
-  ordre=new (Vertex* [this->nbvx]);
+  ordre=new Vertex* [nbvx];
 
 
  f_in >> l;
@@ -697,7 +699,7 @@ void  Triangles::Read_nopo(MeshIstream & ff)
 {
   //  
   if (verbosity>1)
-    cout << " -- ReadMesh .ftq file " <<  f_in.CurrentFile  << endl;
+    cout << "  -- ReadMesh .ftq file " <<  f_in.CurrentFile  << endl;
   
   Int4 i,ne,nt,nq;
   f_in.cm() >> nbv >> ne >> nt >> nq ;
@@ -711,7 +713,7 @@ void  Triangles::Read_nopo(MeshIstream & ff)
   triangles =new Triangle[nbtx];
   assert(triangles);
   vertices=new Vertex[nbvx];
-  ordre=new (Vertex* [this->nbvx]);
+  ordre=new Vertex* [nbvx];
   Int4 k=0;
   
   for ( i=0;i<ne;i++) 
@@ -759,7 +761,7 @@ void  Triangles::Read_msh(MeshIstream &f_in)
 {
     Metric M1(1.);
   if (verbosity>1)
-    cout << " -- ReadMesh .msh file " <<  f_in.CurrentFile  << endl;
+    cout << "  -- ReadMesh .msh file " <<  f_in.CurrentFile  << endl;
    	
      Int4 i;
      f_in.cm() >> nbv >> nbt ;
@@ -774,7 +776,7 @@ void  Triangles::Read_msh(MeshIstream &f_in)
      triangles =new Triangle[nbtx];
      assert(triangles);
      vertices=new Vertex[nbvx];
-     ordre=new (Vertex* [this->nbvx]);
+     ordre=new Vertex* [nbvx];
       edges = new Edge[nbe];
      for ( i=0;i<nbv;i++)
 	{
@@ -810,7 +812,7 @@ void  Triangles::Read_amdba(MeshIstream &f_in )
 {
   Metric M1(1);
   if (verbosity>1)
-    cout << " -- ReadMesh .amdba file " <<  f_in.CurrentFile  << endl;
+    cout << "  -- ReadMesh .amdba file " <<  f_in.CurrentFile  << endl;
    	
      Int4 i;
      f_in.cm() >> nbv >> nbt ;
@@ -822,7 +824,7 @@ void  Triangles::Read_amdba(MeshIstream &f_in )
      triangles =new Triangle[nbtx];
      assert(triangles);
      vertices=new Vertex[nbvx];
-     ordre=new (Vertex* [this->nbvx]);
+     ordre=new Vertex* [nbvx];
      Int4 j;
       for ( i=0;i<nbv;i++)
 	{
@@ -896,7 +898,7 @@ Triangles::Triangles(const char * filename,Real8 cutoffradian)
     else if (ftq) Read_ftq(f_in);
     else 
       { 
-	cerr << " Unkown type mesh " << filename << endl;
+	cerr << " Unknown type mesh " << filename << endl;
 	MeshError(2);
       }
       ConsGeometry(cutoffradian);
@@ -913,7 +915,7 @@ void Geometry::ReadGeometry(const char * filename)
 {
   OnDisk = 1;
   if(verbosity>1)
-      cout << " -- ReadGeometry " << filename << endl;
+      cout << "  -- ReadGeometry " << filename << endl;
   MeshIstream f_in (filename);
   ReadGeometry(f_in,filename);
 }
@@ -923,7 +925,7 @@ void Geometry::ReadGeometry(const char * filename)
 void Geometry::ReadGeometry(MeshIstream & f_in,const char * filename)  
 {
   if(verbosity>1)
-    cout << " -- ReadGeometry " << filename << endl;
+    cout << "  -- ReadGeometry " << filename << endl;
   assert(empty());
   nbiv=nbv=nbvx=0;
   nbe=nbt=nbtx=0;
@@ -1149,7 +1151,6 @@ void Geometry::ReadGeometry(MeshIstream & f_in,const char * filename)
           
           for (i=0;i<n;i++) {     
             f_in  >>  j ;
-	    cout << "BUG TRACE: j="<<j<<", nbv="<<nbv<<endl;
             assert( j <= nbv );
             assert( j > 0 );
             j--;
@@ -1201,7 +1202,7 @@ void Geometry::ReadGeometry(MeshIstream & f_in,const char * filename)
 	  }
       }
       else
-	{ // unkown field
+	{ // unknown field
 	  field = ++showfield;
 	  if(showfield==1) // just to show one time 
 	    if (verbosity>3)
