@@ -283,7 +283,7 @@ FILE FORMAT MANIPULATORS:
 	Tridimensional mesh rendering is performed
 	as a chemical molecule: nodes as balls and
 	edges as tubes.
-	The @code{PlotM} tool is developped
+	The @code{PlotM} tool is developed
 	at Cornell University Laboratory of Atomic and Solid
 	State Physics (LASSP) in a Joint Study with IBM, with support by
 	the Materials Science Center and Corning Glassworks.
@@ -302,7 +302,7 @@ COLOR MANIPULATORS:
 
 VALUATED MANIPULATORS:
 @pindex mfield
-    Some manipulators takes an agument that specifies a value. 
+    Some manipulators takes an argument that specifies a value. 
     @example
         cout << geomview << bezieradapt << subdivide(5) << my_cad_boundary;
     	cout << vtk << iso << isovalue(2.5) << my_mesh;
@@ -316,12 +316,16 @@ VALUATED MANIPULATORS:
     @itemx n_isovalue_negative @var{int}
     @itemx vectorscale @var{float}
     @itemx subdivide @var{float}
+    @itemx rounding_precision @var{float}
+	This manipulator set a rounding precision that could be used
+	by some output functions, e.g. by the @code{geo} class.
+	By default, the rounding value is zero and there is no rounding.
 @cindex image file format
 @cindex graphic render
 @fiindex @file{.png} image 
 @fiindex @file{.jpg} image
 @fiindex @file{.pdf} image
-    @itemx image_format @var{string}
+    @item image_format @var{string}
 	The argument is any valid image format, such as @code{png}, @code{jpg} or @code{pdf},
 	that could be handled by the corresponding graphic render.
     @end table
