@@ -21,6 +21,8 @@
 #include "rheolef/rheostream.h"
 #include "rheolef/iorheo.h"
 
+#include "scatch.icc" // compile this code here, but is reused in field2bb
+
 #ifdef _RHEOLEF_HAVE_CLIMITS
 #include <climits>   // PATH_MAX ?
 #else
@@ -55,13 +57,6 @@ get_tmpdir() {
  return (c_tmpdir == 0) ? "/tmp" : c_tmpdir;
 }
 string
-itos (string::size_type i)
-{
-    char buffer [100];
-    sprintf (buffer, "%d", int(i));
-    return buffer;
-}
-string
 ftos (const Float& x)
 {
   std::ostringstream out;
@@ -87,7 +82,7 @@ orheostream::open (const string& name, const string& suffix, io::mode_type mode)
 {
     _mode = mode;
     // append the '.gz' suffix:
-    if (suffix == "") {
+    if (suffix.length() == 0) {
         _full_name = delete_suffix(name, "gz");
     } else {
         _full_name = delete_suffix(delete_suffix(name, "gz"), suffix) 
@@ -217,12 +212,12 @@ irheostream::~irheostream ()
 bool
 has_suffix (const string& name, const string& suffix)
 {
-    unsigned int ln = name.length();
-    unsigned int ls = suffix.length();
+    size_t ln = name.length();
+    size_t ls = suffix.length();
     if (ln <= ls+1) return false;
 
     if (name[ln-ls-1] != '.') return false;
-    for (unsigned int i = ln-ls, j = 0; i < ln; i++, j++)
+    for (size_t i = ln-ls, j = 0; i < ln; i++, j++)
         if (name [i] != suffix [j]) return false;
 
     return true;
@@ -234,6 +229,32 @@ delete_suffix (const string& name, const string& suffix)
     if (!has_suffix(name, suffix)) return name;
     return string(name, 0, name.length() - suffix.length() - 1);
 }
+// has_any_suffix("toto.any_suffix") -> true
+bool
+has_any_suffix (const string& name)
+{
+    size_t ln = name.length();
+    if (ln == 0) return false;
+    for (size_t i = ln-1; i > 0 && name[i] != '/'; --i)
+        if (name [i] == '.') return true;
+    return false;
+}
+// delete_any_suffix("toto.any_suffix") --> "toto"
+string
+delete_any_suffix (const string& name)
+{
+    size_t ln = name.length();
+    if (ln == 0) return name;
+    size_t i_dot = 0;
+    for (size_t i = ln-1; i > 0 && name[i] != '/'; --i) {
+        if (name [i] == '.') {
+	  i_dot = i;
+	  break;
+        }
+    }
+    if (i_dot == 0) return name;
+    return string(name, 0, i_dot);
+}
 string
 get_basename (const string& name)
 {
@@ -252,55 +273,6 @@ get_dirname (const string& name)
     string d = string(name, 0, i);
     return d;
 }
-bool 
-scatch (istream& in, const string& ch, bool full_match)
-{
-  // null string case
-  unsigned int l = ch.length();
-  if (l == 0) return true;
-  
-  // check file
-  char c = '\0';
-  unsigned int state = 0;
-  const char *p = ch.c_str();
-  do {
-    in.get(c);
-    if (*p == '\n') {
-	// begining of stream <==> begining of a line, e.g. 
-	//   we look at "\nfield" while file starts 
-	//   with string "field"; it's ok
-	state++;
-        p++;
-    }
-    do {
- 
-        if (*p == c) {
-            // advance in the string
-            state++;
-            p++;
-        } else if (state != 0 && ch[0] == c) {
-            // come back to the second position
-            state = 1;
-            p = ch.c_str() + 1;
-        } else if (state != 0) {
-            // come back to the begining of the string
-            state = 0;
-            p = ch.c_str();
-        }
-    }
-    while (state < l && in.get(c) && in.good());
-    // here: either state == l or end-of-file is reached
-    if (!full_match) return (state == l);
-    if (state != l) return false; // reaches end-of-file whithout finding the string
-    // here: state == l and we want a full match: check also that next char is a space, tab, end-of-line, or end-of-file
-    // => otherwise ambiguity with scatch("u") that reaches either "uh" or "u_exact"...!
-    c = in.peek();
-    if (!c || !in.good()) return true; // end-of-file just after the string: ok...
-    if (isspace(c)) return true; // nice! the expected situation
-  } while (true);
-  // stops when reaching either the string or end-of-file: the next statement is not reached
-  return false;
-}
 //
 // NOTE: path could have an iterator that points to
 //       a directory name...
@@ -377,15 +349,6 @@ prepend_dir_to_rheo_path (const string& dir)
     rheo_path = new_tab_macro(char, strlen(tmp.c_str())+1);
     strcpy (rheo_path, tmp.c_str());
 }
-bool 
-file_exists (const string& filename)
-{
-    struct stat s;
-    if (stat(filename.c_str(), &s) != 0) {
-        return false;
-    }
-    return true;
-}
 static
 bool
 have_name_in_dir (const string& dir, const string& name, string& full_path)
