@@ -45,7 +45,7 @@ ABSTRACT:
   This class provides a stream interface for large
   data management.
   File decompresion is assumed using
-  @code{gzip} and a recursive seach in a directory list
+  @code{gzip} and a recursive search in a directory list
   is provided for input.
   @example
      orheostream foo("NAME", "suffix");
@@ -99,7 +99,7 @@ DESCRIPTION:
   @end example
   @noindent
   will recursively look for a @file{results[.data[.gz]]} file in the
-  directory mentionned by the @code{RHEOPATH} environment variable.
+  directory mentioned by the @code{RHEOPATH} environment variable.
 
   @noindent
   For instance, if you insert in our ".cshrc" something like:
@@ -138,7 +138,7 @@ DESCRIPTION:
   will be created.
 
   @noindent
-  File loading and storing are mentionned by a message,
+  File loading and storing are mentioned by a message,
   either:
   @example
  	! load "./results.data.gz"
@@ -211,7 +211,7 @@ protected:
 std::string itos (std::string::size_type i);
 std::string ftos (const Float& x);
 
-// catch first occurence of string in file
+// catch first occurrence of string in file
 bool scatch (std::istream& in, const std::string& ch, bool full_match = true);
 
 // has_suffix("toto.suffix", "suffix") -> true
@@ -220,6 +220,12 @@ bool has_suffix (const std::string& name, const std::string& suffix);
 // "toto.suffix" --> "toto"
 std::string delete_suffix (const std::string& name, const std::string& suffix);
 
+// has_any_suffix("toto.any_suffix") -> true
+bool has_any_suffix (const std::string& name);
+
+// delete_any_suffix("toto.any_suffix") --> "toto"
+std::string delete_any_suffix (const std::string& name);
+
 // "/usr/local/dir/toto.suffix" --> "toto.suffix"
 std::string get_basename (const std::string& name);
 
