@@ -24,8 +24,8 @@ using namespace std;
 
 void
 usage() {
-   cerr << "orheostream_tst: usage: orheostream_tst "
-	<< " filename suffix"
+   cerr << "orheostream_append_tst: usage: orheostream_append_tst "
+	<< " filename suffix [app]"
 	<< endl;
    
    cerr << " ex: orheostream_tst toto txt\n";
@@ -34,8 +34,8 @@ usage() {
 int main(int argc, char** argv)
 {
     if (argc < 3) usage();
-
-    orheostream data(argv[1], argv[2]);
+    io::mode_type mode = (argc < 4) ? io::out : io::app;
+    orheostream data(argv[1], argv[2], mode);
     if (!data) 
       fatal_macro("orheostream_tst: \"" 
 	<< argv[1] << "." << argv[2] << ".gz\" creation failed.");
@@ -45,5 +45,4 @@ int main(int argc, char** argv)
         if (c != EOF) data.put(c);
     }
     data.close();
-    return 0;
 }
